Class: UspsApi::AddressesAddressAdditionalInformation1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/addresses_address_additional_information1.rb

Overview

Extra information about the request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(delivery_point: SKIP, carrier_route: SKIP, county_name: SKIP, footnotes: SKIP, record_type: SKIP, secondary_info: SKIP, return_code: SKIP, return_code_text: SKIP, dpv_confirmation: SKIP, dpv_enhanced_confirmation: SKIP, dpv_footnotes: SKIP, dpv_business: SKIP, dpvcmra: SKIP, dpv_drop: SKIP, dpv_educational: SKIP, dpv_drop_count: SKIP, dpvlacs: SKIP, dpv_no_door_delivery: SKIP, dpvpbsa: SKIP, dpv_nostat_reason_code: SKIP, dpv_nostat_reason_code_desc: SKIP, business: SKIP, central_delivery_point: SKIP, vacant: SKIP, dpv_seasonal: SKIP, dpv_throwback: SKIP, dpv_no_secure_location: SKIP, dpv_vacant: SKIP, dpv_nostat: SKIP, dpv_non_delivery_days_flag: SKIP, dpv_non_delivery_days_values: SKIP, dpv_curb_delivery: SKIP, dpv_central_box_delivery: SKIP, dpvndcbu_delivery: SKIP, dpv_other_delivery: SKIP, dpv_delivery_type: SKIP, post_office_city: SKIP, post_office_state: SKIP, county_number: SKIP, auto_zone_indicator: SKIP, lacs_link_return_code: SKIP, lacs_link_indicator: SKIP, misc_line: SKIP, zip5_valid: SKIP, po_box_only_zip: SKIP, default_flag: SKIP, matched_primary_number: SKIP, matched_secondary_number: SKIP, parsed_pmb_designator: SKIP, parsed_pmb_number: SKIP, suite_link_indicator: SKIP, finance_number: SKIP, base_alternate_code: SKIP, e_lot_code: SKIP, e_lot_number: SKIP) ⇒ AddressesAddressAdditionalInformation1

Returns a new instance of AddressesAddressAdditionalInformation1.



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 471

def initialize(delivery_point: SKIP, carrier_route: SKIP, county_name: SKIP,
               footnotes: SKIP, record_type: SKIP, secondary_info: SKIP,
               return_code: SKIP, return_code_text: SKIP,
               dpv_confirmation: SKIP, dpv_enhanced_confirmation: SKIP,
               dpv_footnotes: SKIP, dpv_business: SKIP, dpvcmra: SKIP,
               dpv_drop: SKIP, dpv_educational: SKIP, dpv_drop_count: SKIP,
               dpvlacs: SKIP, dpv_no_door_delivery: SKIP, dpvpbsa: SKIP,
               dpv_nostat_reason_code: SKIP,
               dpv_nostat_reason_code_desc: SKIP, business: SKIP,
               central_delivery_point: SKIP, vacant: SKIP,
               dpv_seasonal: SKIP, dpv_throwback: SKIP,
               dpv_no_secure_location: SKIP, dpv_vacant: SKIP,
               dpv_nostat: SKIP, dpv_non_delivery_days_flag: SKIP,
               dpv_non_delivery_days_values: SKIP, dpv_curb_delivery: SKIP,
               dpv_central_box_delivery: SKIP, dpvndcbu_delivery: SKIP,
               dpv_other_delivery: SKIP, dpv_delivery_type: SKIP,
               post_office_city: SKIP, post_office_state: SKIP,
               county_number: SKIP, auto_zone_indicator: SKIP,
               lacs_link_return_code: SKIP, lacs_link_indicator: SKIP,
               misc_line: SKIP, zip5_valid: SKIP, po_box_only_zip: SKIP,
               default_flag: SKIP, matched_primary_number: SKIP,
               matched_secondary_number: SKIP, parsed_pmb_designator: SKIP,
               parsed_pmb_number: SKIP, suite_link_indicator: SKIP,
               finance_number: SKIP, base_alternate_code: SKIP,
               e_lot_code: SKIP, e_lot_number: SKIP)
  @delivery_point = delivery_point unless delivery_point == SKIP
  @carrier_route = carrier_route unless carrier_route == SKIP
  @county_name = county_name unless county_name == SKIP
  @footnotes = footnotes unless footnotes == SKIP
  @record_type = record_type unless record_type == SKIP
  @secondary_info = secondary_info unless secondary_info == SKIP
  @return_code = return_code unless return_code == SKIP
  @return_code_text = return_code_text unless return_code_text == SKIP
  @dpv_confirmation = dpv_confirmation unless dpv_confirmation == SKIP
  unless dpv_enhanced_confirmation == SKIP
    @dpv_enhanced_confirmation =
      dpv_enhanced_confirmation
  end
  @dpv_footnotes = dpv_footnotes unless dpv_footnotes == SKIP
  @dpv_business = dpv_business unless dpv_business == SKIP
  @dpvcmra = dpvcmra unless dpvcmra == SKIP
  @dpv_drop = dpv_drop unless dpv_drop == SKIP
  @dpv_educational = dpv_educational unless dpv_educational == SKIP
  @dpv_drop_count = dpv_drop_count unless dpv_drop_count == SKIP
  @dpvlacs = dpvlacs unless dpvlacs == SKIP
  @dpv_no_door_delivery = dpv_no_door_delivery unless dpv_no_door_delivery == SKIP
  @dpvpbsa = dpvpbsa unless dpvpbsa == SKIP
  @dpv_nostat_reason_code = dpv_nostat_reason_code unless dpv_nostat_reason_code == SKIP
  unless dpv_nostat_reason_code_desc == SKIP
    @dpv_nostat_reason_code_desc =
      dpv_nostat_reason_code_desc
  end
  @business = business unless business == SKIP
  @central_delivery_point = central_delivery_point unless central_delivery_point == SKIP
  @vacant = vacant unless vacant == SKIP
  @dpv_seasonal = dpv_seasonal unless dpv_seasonal == SKIP
  @dpv_throwback = dpv_throwback unless dpv_throwback == SKIP
  @dpv_no_secure_location = dpv_no_secure_location unless dpv_no_secure_location == SKIP
  @dpv_vacant = dpv_vacant unless dpv_vacant == SKIP
  @dpv_nostat = dpv_nostat unless dpv_nostat == SKIP
  unless dpv_non_delivery_days_flag == SKIP
    @dpv_non_delivery_days_flag =
      dpv_non_delivery_days_flag
  end
  unless dpv_non_delivery_days_values == SKIP
    @dpv_non_delivery_days_values =
      dpv_non_delivery_days_values
  end
  @dpv_curb_delivery = dpv_curb_delivery unless dpv_curb_delivery == SKIP
  @dpv_central_box_delivery = dpv_central_box_delivery unless dpv_central_box_delivery == SKIP
  @dpvndcbu_delivery = dpvndcbu_delivery unless dpvndcbu_delivery == SKIP
  @dpv_other_delivery = dpv_other_delivery unless dpv_other_delivery == SKIP
  @dpv_delivery_type = dpv_delivery_type unless dpv_delivery_type == SKIP
  @post_office_city = post_office_city unless post_office_city == SKIP
  @post_office_state = post_office_state unless post_office_state == SKIP
  @county_number = county_number unless county_number == SKIP
  @auto_zone_indicator = auto_zone_indicator unless auto_zone_indicator == SKIP
  @lacs_link_return_code = lacs_link_return_code unless lacs_link_return_code == SKIP
  @lacs_link_indicator = lacs_link_indicator unless lacs_link_indicator == SKIP
  @misc_line = misc_line unless misc_line == SKIP
  @zip5_valid = zip5_valid unless zip5_valid == SKIP
  @po_box_only_zip = po_box_only_zip unless po_box_only_zip == SKIP
  @default_flag = default_flag unless default_flag == SKIP
  @matched_primary_number = matched_primary_number unless matched_primary_number == SKIP
  @matched_secondary_number = matched_secondary_number unless matched_secondary_number == SKIP
  @parsed_pmb_designator = parsed_pmb_designator unless parsed_pmb_designator == SKIP
  @parsed_pmb_number = parsed_pmb_number unless parsed_pmb_number == SKIP
  @suite_link_indicator = suite_link_indicator unless suite_link_indicator == SKIP
  @finance_number = finance_number unless finance_number == SKIP
  @base_alternate_code = base_alternate_code unless base_alternate_code == SKIP
  @e_lot_code = e_lot_code unless e_lot_code == SKIP
  @e_lot_number = e_lot_number unless e_lot_number == SKIP
end

Instance Attribute Details

#auto_zone_indicatorAutoZoneIndicator

The automated zone indicator for the delivery unit. * ‘A` - Carrier Route Sort Rates Apply - Merge Allowed. * `B` - Carrier Route Sort Rates Apply - Merge Not Allowed. * `C` - Carrier Route Sort Rates Do Not Apply - Merge Allowed. * `D` - Carrier Route Sort Rates Do Not Apply - Merge Not Allowed.

Returns:



267
268
269
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 267

def auto_zone_indicator
  @auto_zone_indicator
end

#base_alternate_codeBaseAlternateCode

Base/Alternate code associated with ZIP + 4® record. * ‘A` - Alternate record. * `B` - Base record.

Returns:



333
334
335
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 333

def base_alternate_code
  @base_alternate_code
end

#businessBusiness

Indicates whether this is a business address.

  • ‘Y` - The address is a business address.

  • ‘N` - The address is not a business address.

Returns:



170
171
172
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 170

def business
  @business
end

#carrier_routeString

This is the carrier route code (values unspecified).

Returns:

  • (String)


23
24
25
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 23

def carrier_route
  @carrier_route
end

#central_delivery_pointBusiness

Central Delivery is for all business office buildings and/or industrial/professional parks. This may include call windows, horizontal locked mail receptacles, and cluster box units.

  • ‘Y` - The address is a central delivery point.

  • ‘N` - The address is not a central delivery point.

Returns:



178
179
180
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 178

def central_delivery_point
  @central_delivery_point
end

#county_nameString

This is the county name associated with the delivery point (values unspecified).

Returns:

  • (String)


28
29
30
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 28

def county_name
  @county_name
end

#county_numberString

The county number for the address.

Returns:

  • (String)


259
260
261
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 259

def county_number
  @county_number
end

#default_flagBusiness

Indicates the address matched is a default. * ‘Y` - The address matched is a default. * `N` - The address matched is not a default.

Returns:



303
304
305
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 303

def default_flag
  @default_flag
end

#delivery_pointString

A specific set of digits between 00 and 99 is assigned to every address that is combined with the ZIP + 4® Code to provide a unique identifier for every delivery address. A street address does not necessarily represent a single delivery point because a street address such as one for an apartment building may have several delivery points.

Returns:

  • (String)


19
20
21
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 19

def delivery_point
  @delivery_point
end

#dpv_businessBusiness

Indicates whePrimary number not confirmed.ther this is a business address.

  • ‘Y` - The address is a business address.

  • ‘N` - The address is not a business address.

Returns:



105
106
107
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 105

def dpv_business
  @dpv_business
end

#dpv_central_box_deliveryBusiness

Indicates the address mail delivery is central box. * ‘Y` - The address has central box delivery. * `N` - The address doesn’t have central box delivery.

Returns:



231
232
233
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 231

def dpv_central_box_delivery
  @dpv_central_box_delivery
end

#dpv_confirmationDpvConfirmation

The DPV Confirmation indicator identifies whether the address provided maps to a known USPS address record, whether the USPS delivers to the address or not. If the USPS does not deliver to the address, the USPS may deliver to a PO Box instead. ‘carrierRoute` values of `R777` and `R779`, for example, may require the shipper to ask the recipient where they receive their USPS mail, which may be different than their physical address.

  • ‘Y` - Address was DPV confirmed for both primary and (if present)

secondary numbers. A value of ‘Y` does not necessarily imply that USPS delivers to that address.

  • ‘D` - Address was DPV confirmed for the primary number only, and the

secondary number information was missing.

  • ‘S` - Address was DPV confirmed for the primary number only, and the

secondary number information was present but not confirmed.

  • ‘N` - Both primary and (if present) secondary number information failed

to DPV confirm.

Returns:



83
84
85
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 83

def dpv_confirmation
  @dpv_confirmation
end

#dpv_curb_deliveryBusiness

Indicates the address mail delivery is curb. * ‘Y` - The address has curb delivery. * `N` - The address doesn’t have curb delivery.

Returns:



225
226
227
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 225

def dpv_curb_delivery
  @dpv_curb_delivery
end

#dpv_delivery_typeDpvDeliveryType

Indicates the delivery type. * ‘1` - The address has curb delivery. * `2`

  • The address has NDCBU delivery. * ‘3` - The address has central box

delivery. * ‘4` - The address has other delivery.

Returns:



247
248
249
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 247

def dpv_delivery_type
  @dpv_delivery_type
end

#dpv_dropBusiness

Indicates whether the address is a drop (mail is dropped off for more than 1 customer). * ‘Y` - Address is a drop. * `N` - Address is not a drop.

Returns:



118
119
120
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 118

def dpv_drop
  @dpv_drop
end

#dpv_drop_countString

Indicates how many customers receive mail at a drop address or CMRA.

Returns:

  • (String)


127
128
129
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 127

def dpv_drop_count
  @dpv_drop_count
end

#dpv_educationalBusiness

Indicates whether the address is educational location. * ‘Y` - Address is educational. * `N` - Address is not educational.

Returns:



123
124
125
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 123

def dpv_educational
  @dpv_educational
end

#dpv_enhanced_confirmationDpvEnhancedConfirmation

The DPV Confirmation indicator identifies whether the address is delivered to by the USPS.

  • ‘Y` - All components confirmed.

  • ‘D` - Secondary was dropped or trailing alpha on primary was dropped to

confirm.

  • ‘S` - Address confirmed on primary number but secondary number required

for complete address.

  • ‘R` - Address DPV Confirmed but USPS does not deliver to the address.

  • ‘N` - Primary number not confirmed.



95
96
97
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 95

def dpv_enhanced_confirmation
  @dpv_enhanced_confirmation
end

#dpv_footnotesString

The footnotes associated with the DPV information.

Returns:

  • (String)


99
100
101
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 99

def dpv_footnotes
  @dpv_footnotes
end

#dpv_no_door_deliveryBusiness

Indicates whether the address does not allow delivery at the door. * ‘Y` - Address does not allow door delivery. * `N` - Address allows door delivery.

Returns:



138
139
140
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 138

def dpv_no_door_delivery
  @dpv_no_door_delivery
end

#dpv_no_secure_locationBusiness

Indicates the address is flagged as not a secure location. * ‘Y` - The address is flagged as not a secure location. * `N` - The address is not flagged as not a secure location.

Returns:



200
201
202
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 200

def dpv_no_secure_location
  @dpv_no_secure_location
end

#dpv_non_delivery_days_flagBusiness

Indicates the address doesn’t have mail delivered on one or more days. * ‘Y` - The address has non-delivery days. * `N` - The address doesn’t have non-delivery days.

Returns:



216
217
218
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 216

def dpv_non_delivery_days_flag
  @dpv_non_delivery_days_flag
end

#dpv_non_delivery_days_valuesArray[DpvNonDeliveryDaysValue]

Delivery Point Validation on non delivery days

Returns:



220
221
222
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 220

def dpv_non_delivery_days_values
  @dpv_non_delivery_days_values
end

#dpv_nostatBusiness

Indicates the address is not counted for statistical purpoes. * ‘Y` - The address is a nostat. * `N` - The address is not a nostat.

Returns:



210
211
212
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 210

def dpv_nostat
  @dpv_nostat
end

#dpv_nostat_reason_codeDpvNostatReasonCode

Indicates the reason code for nostat flag. * ‘1` - IDA (Internal Drop Address) - Addresses that do not receive mail directly from the USPS but are delivered to a drop address that services them (e.g., gated community). * `2` - CDS Nostat - Addresses that have not yet become deliverable. For example, a new subdivision where lots and primary numbers have been determined, but no structure exists yet for occupancy. * `4` - CMZ Nostat - College, military, and other types. ZIP + 4® records USPS has incorporated into the data. * `5` - Regular nostat - Indicates addresses not receiving delivery and the addresses are not counted as possible deliveries. * `6` - Secondary Required - The address requires secondary information (unconfirmed secondary entered or secondary missing).

Returns:



158
159
160
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 158

def dpv_nostat_reason_code
  @dpv_nostat_reason_code
end

#dpv_nostat_reason_code_descDpvNostatReasonCodeDesc

Indicates the reason description for nostat flag. * “IDA (Internal Drop Address)” * “CDS Nostat” * “CMZ Nostat” * “Regular Nostat” * “Secondary Required”



164
165
166
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 164

def dpv_nostat_reason_code_desc
  @dpv_nostat_reason_code_desc
end

#dpv_other_deliveryBusiness

Indicates the address mail delivery is other. * ‘Y` - The address has other delivery. * `N` - The address doesn’t have other delivery.

Returns:



241
242
243
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 241

def dpv_other_delivery
  @dpv_other_delivery
end

#dpv_seasonalBusiness

Indicates the address is seasonal. * ‘Y` - The address is seasonal. * `N`

  • The address is not seasonal.

Returns:



189
190
191
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 189

def dpv_seasonal
  @dpv_seasonal
end

#dpv_throwbackBusiness

Indicates the address is a throwback (actual deivery is to a PO Box). * ‘Y` - The address is a throwback. * `N` - The address is not a throwback.

Returns:



194
195
196
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 194

def dpv_throwback
  @dpv_throwback
end

#dpv_vacantBusiness

Indicates whether the location designated by the address is occupied. * ‘Y` - The address is not occupied. * `N` - The address is occupied.

Returns:



205
206
207
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 205

def dpv_vacant
  @dpv_vacant
end

#dpvcmraBusiness

Indicates if the location is a [Commercial Mail Receiving Agency (CMRA)](faq.usps.com/s/article/Commercial-Mail-Receiving-Agency-CM RA).

* `Y` - Address was found in the CMRA table.
* `N` - Address was not found in the CMRA table.

Returns:



113
114
115
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 113

def dpvcmra
  @dpvcmra
end

#dpvlacsBusiness

Indicates whether the address is an old side LACS address. * ‘Y` - Address is a LACS address. * `N` - Address is not a LACS address.

Returns:



132
133
134
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 132

def dpvlacs
  @dpvlacs
end

#dpvndcbu_deliveryBusiness

Indicates the address mail delivery is NDCBU. * ‘Y` - The address has NDCBU delivery. * `N` - The address doesn’t have NDCBU delivery.

Returns:



236
237
238
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 236

def dpvndcbu_delivery
  @dpvndcbu_delivery
end

#dpvpbsaBusiness

Indicates whether the address is a PO Box street address. * ‘Y` - Address is a PBSA. * `N` - Address is not a PBSA.

Returns:



143
144
145
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 143

def dpvpbsa
  @dpvpbsa
end

#e_lot_codeElotCode

eLOT Ascending/Descending Code * ‘A` - eLOT Number Ascending * `D` - eLOT Number Descending

Returns:



338
339
340
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 338

def e_lot_code
  @e_lot_code
end

#e_lot_numberString

eLOT Number

Returns:

  • (String)


342
343
344
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 342

def e_lot_number
  @e_lot_number
end

#finance_numberString

Finance number associated with address.

Returns:

  • (String)


328
329
330
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 328

def finance_number
  @finance_number
end

#footnotesString

The address footnotes.

Returns:

  • (String)


32
33
34
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 32

def footnotes
  @footnotes
end

Indicates if a match was found from LACSLink. * ‘Y` - LACSLink address found. * `N` - LACSLink address not found. * `S` - LACSLink address converted but secondary dropped. * `F` - LACSLink false positive address encountered.

Returns:



281
282
283
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 281

def lacs_link_indicator
  @lacs_link_indicator
end

The return code from the LACSLink inquiry. * ‘00` - LACSLink no match. * `14` - Multiple LACSLink addresses found, unable to break tie. * `A` - LACSLink address converted without modifications. * `92` - LACSLink address converted but secondary dropped.

Returns:



274
275
276
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 274

def lacs_link_return_code
  @lacs_link_return_code
end

#matched_primary_numberString

The value of the matched primary number.

Returns:

  • (String)


307
308
309
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 307

def matched_primary_number
  @matched_primary_number
end

#matched_secondary_numberString

The value of the matched secondary number.

Returns:

  • (String)


311
312
313
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 311

def matched_secondary_number
  @matched_secondary_number
end

#misc_lineString

Extraneous information removed from the address line not used to match the address.

Returns:

  • (String)


286
287
288
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 286

def misc_line
  @misc_line
end

#parsed_pmb_designatorString

The value of the parsed PMB Designator.

Returns:

  • (String)


315
316
317
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 315

def parsed_pmb_designator
  @parsed_pmb_designator
end

#parsed_pmb_numberString

The value of the PMB number.

Returns:

  • (String)


319
320
321
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 319

def parsed_pmb_number
  @parsed_pmb_number
end

#po_box_only_zipBusiness

Indicates if the returned ZIP Code only serves PO Box addresses. * ‘Y` - The ZIP Code only serves PO Box addresses. * `N` - The ZIP Code serves non-PO Box addresses.

Returns:



298
299
300
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 298

def po_box_only_zip
  @po_box_only_zip
end

#post_office_cityString

The city associated with the delivery post office.

Returns:

  • (String)


251
252
253
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 251

def post_office_city
  @post_office_city
end

#post_office_stateString

The state associated with the delivery post office.

Returns:

  • (String)


255
256
257
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 255

def post_office_state
  @post_office_state
end

#record_typeRecordType

The record type of the ZIP + 4® match. * ‘G` - General Delivery * `P`

  • PO Box * ‘R` - Rural Route/Highway Contract * `H` - Highrise * `F` -

Firm * ‘S` - Street

Returns:



38
39
40
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 38

def record_type
  @record_type
end

#return_codeReturnCode

The return code from the address match. * ‘32` - Default Match * `31` - Single Match * `22` - Multiple Response Match * `21` - Address Not Found * `13` - Invalid City * `12` - Invalid State Code * `11` - Invalid ZIP Code

  • ‘10` - Invalid Address

Returns:



49
50
51
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 49

def return_code
  @return_code
end

#return_code_textString

This is a description of the return code

  • “Default address: The address you entered was found but more information

is needed (such as an apartment, suite, or box number) to match to a specific address“

  • “Single Response – exact match”

  • “Multiple addresses were found for the information you entered, and no

default exists.“

  • “Address Not Found”

  • “Invalid City”

  • “Invalid State Code”

  • “Invalid ZIP Code”

  • “Invalid Address”

Returns:

  • (String)


64
65
66
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 64

def return_code_text
  @return_code_text
end

#secondary_infoString

The extracted secondary information of the returned address.

Returns:

  • (String)


42
43
44
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 42

def secondary_info
  @secondary_info
end

Indicates if a match was found from SuiteLink. * ‘00` - SuiteLink no match. * `A` - SuiteLink match.

Returns:



324
325
326
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 324

def suite_link_indicator
  @suite_link_indicator
end

#vacantBusiness

Indicates whether the location designated by the address is occupied.

  • ‘Y` - The address is not occupied.

  • ‘N` - The address is occupied.

Returns:



184
185
186
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 184

def vacant
  @vacant
end

#zip5_validBusiness

Indicates if the returned ZIP Code corresponds to the returned City/State.

  • ‘Y` - The ZIP Code matches the City/State. * `N` - The ZIP Code doesn’t

match the City/State.

Returns:



292
293
294
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 292

def zip5_valid
  @zip5_valid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 566

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  delivery_point = hash.key?('deliveryPoint') ? hash['deliveryPoint'] : SKIP
  carrier_route = hash.key?('carrierRoute') ? hash['carrierRoute'] : SKIP
  county_name = hash.key?('countyName') ? hash['countyName'] : SKIP
  footnotes = hash.key?('footnotes') ? hash['footnotes'] : SKIP
  record_type = hash.key?('recordType') ? hash['recordType'] : SKIP
  secondary_info = hash.key?('secondaryInfo') ? hash['secondaryInfo'] : SKIP
  return_code = hash.key?('returnCode') ? hash['returnCode'] : SKIP
  return_code_text =
    hash.key?('returnCodeText') ? hash['returnCodeText'] : SKIP
  dpv_confirmation =
    hash.key?('DPVConfirmation') ? hash['DPVConfirmation'] : SKIP
  dpv_enhanced_confirmation =
    hash.key?('DPVEnhancedConfirmation') ? hash['DPVEnhancedConfirmation'] : SKIP
  dpv_footnotes = hash.key?('DPVFootnotes') ? hash['DPVFootnotes'] : SKIP
  dpv_business = hash.key?('DPVBusiness') ? hash['DPVBusiness'] : SKIP
  dpvcmra = hash.key?('DPVCMRA') ? hash['DPVCMRA'] : SKIP
  dpv_drop = hash.key?('DPVDrop') ? hash['DPVDrop'] : SKIP
  dpv_educational =
    hash.key?('DPVEducational') ? hash['DPVEducational'] : SKIP
  dpv_drop_count = hash.key?('DPVDropCount') ? hash['DPVDropCount'] : SKIP
  dpvlacs = hash.key?('DPVLACS') ? hash['DPVLACS'] : SKIP
  dpv_no_door_delivery =
    hash.key?('DPVNoDoorDelivery') ? hash['DPVNoDoorDelivery'] : SKIP
  dpvpbsa = hash.key?('DPVPBSA') ? hash['DPVPBSA'] : SKIP
  dpv_nostat_reason_code =
    hash.key?('DPVNostatReasonCode') ? hash['DPVNostatReasonCode'] : SKIP
  dpv_nostat_reason_code_desc =
    hash.key?('DPVNostatReasonCodeDesc') ? hash['DPVNostatReasonCodeDesc'] : SKIP
  business = hash.key?('business') ? hash['business'] : SKIP
  central_delivery_point =
    hash.key?('centralDeliveryPoint') ? hash['centralDeliveryPoint'] : SKIP
  vacant = hash.key?('vacant') ? hash['vacant'] : SKIP
  dpv_seasonal = hash.key?('DPVSeasonal') ? hash['DPVSeasonal'] : SKIP
  dpv_throwback = hash.key?('DPVThrowback') ? hash['DPVThrowback'] : SKIP
  dpv_no_secure_location =
    hash.key?('DPVNoSecureLocation') ? hash['DPVNoSecureLocation'] : SKIP
  dpv_vacant = hash.key?('DPVVacant') ? hash['DPVVacant'] : SKIP
  dpv_nostat = hash.key?('DPVNostat') ? hash['DPVNostat'] : SKIP
  dpv_non_delivery_days_flag =
    hash.key?('DPVNonDeliveryDaysFlag') ? hash['DPVNonDeliveryDaysFlag'] : SKIP
  # Parameter is an array, so we need to iterate through it
  dpv_non_delivery_days_values = nil
  unless hash['DPVNonDeliveryDaysValues'].nil?
    dpv_non_delivery_days_values = []
    hash['DPVNonDeliveryDaysValues'].each do |structure|
      dpv_non_delivery_days_values << (DpvNonDeliveryDaysValue.from_hash(structure) if structure)
    end
  end

  dpv_non_delivery_days_values = SKIP unless hash.key?('DPVNonDeliveryDaysValues')
  dpv_curb_delivery =
    hash.key?('DPVCurbDelivery') ? hash['DPVCurbDelivery'] : SKIP
  dpv_central_box_delivery =
    hash.key?('DPVCentralBoxDelivery') ? hash['DPVCentralBoxDelivery'] : SKIP
  dpvndcbu_delivery =
    hash.key?('DPVNDCBUDelivery') ? hash['DPVNDCBUDelivery'] : SKIP
  dpv_other_delivery =
    hash.key?('DPVOtherDelivery') ? hash['DPVOtherDelivery'] : SKIP
  dpv_delivery_type =
    hash.key?('DPVDeliveryType') ? hash['DPVDeliveryType'] : SKIP
  post_office_city =
    hash.key?('postOfficeCity') ? hash['postOfficeCity'] : SKIP
  post_office_state =
    hash.key?('postOfficeState') ? hash['postOfficeState'] : SKIP
  county_number = hash.key?('countyNumber') ? hash['countyNumber'] : SKIP
  auto_zone_indicator =
    hash.key?('autoZoneIndicator') ? hash['autoZoneIndicator'] : SKIP
  lacs_link_return_code =
    hash.key?('LACSLinkReturnCode') ? hash['LACSLinkReturnCode'] : SKIP
  lacs_link_indicator =
    hash.key?('LACSLinkIndicator') ? hash['LACSLinkIndicator'] : SKIP
  misc_line = hash.key?('miscLine') ? hash['miscLine'] : SKIP
  zip5_valid = hash.key?('ZIP5Valid') ? hash['ZIP5Valid'] : SKIP
  po_box_only_zip = hash.key?('POBoxOnlyZIP') ? hash['POBoxOnlyZIP'] : SKIP
  default_flag = hash.key?('defaultFlag') ? hash['defaultFlag'] : SKIP
  matched_primary_number =
    hash.key?('matchedPrimaryNumber') ? hash['matchedPrimaryNumber'] : SKIP
  matched_secondary_number =
    hash.key?('matchedSecondaryNumber') ? hash['matchedSecondaryNumber'] : SKIP
  parsed_pmb_designator =
    hash.key?('parsedPMBDesignator') ? hash['parsedPMBDesignator'] : SKIP
  parsed_pmb_number =
    hash.key?('parsedPMBNumber') ? hash['parsedPMBNumber'] : SKIP
  suite_link_indicator =
    hash.key?('suiteLinkIndicator') ? hash['suiteLinkIndicator'] : SKIP
  finance_number = hash.key?('financeNumber') ? hash['financeNumber'] : SKIP
  base_alternate_code =
    hash.key?('baseAlternateCode') ? hash['baseAlternateCode'] : SKIP
  e_lot_code = hash.key?('eLOTCode') ? hash['eLOTCode'] : SKIP
  e_lot_number = hash.key?('eLOTNumber') ? hash['eLOTNumber'] : SKIP

  # Create object from extracted values.
  AddressesAddressAdditionalInformation1.new(delivery_point: delivery_point,
                                             carrier_route: carrier_route,
                                             county_name: county_name,
                                             footnotes: footnotes,
                                             record_type: record_type,
                                             secondary_info: secondary_info,
                                             return_code: return_code,
                                             return_code_text: return_code_text,
                                             dpv_confirmation: dpv_confirmation,
                                             dpv_enhanced_confirmation: dpv_enhanced_confirmation,
                                             dpv_footnotes: dpv_footnotes,
                                             dpv_business: dpv_business,
                                             dpvcmra: dpvcmra,
                                             dpv_drop: dpv_drop,
                                             dpv_educational: dpv_educational,
                                             dpv_drop_count: dpv_drop_count,
                                             dpvlacs: dpvlacs,
                                             dpv_no_door_delivery: dpv_no_door_delivery,
                                             dpvpbsa: dpvpbsa,
                                             dpv_nostat_reason_code: dpv_nostat_reason_code,
                                             dpv_nostat_reason_code_desc: dpv_nostat_reason_code_desc,
                                             business: business,
                                             central_delivery_point: central_delivery_point,
                                             vacant: vacant,
                                             dpv_seasonal: dpv_seasonal,
                                             dpv_throwback: dpv_throwback,
                                             dpv_no_secure_location: dpv_no_secure_location,
                                             dpv_vacant: dpv_vacant,
                                             dpv_nostat: dpv_nostat,
                                             dpv_non_delivery_days_flag: dpv_non_delivery_days_flag,
                                             dpv_non_delivery_days_values: dpv_non_delivery_days_values,
                                             dpv_curb_delivery: dpv_curb_delivery,
                                             dpv_central_box_delivery: dpv_central_box_delivery,
                                             dpvndcbu_delivery: dpvndcbu_delivery,
                                             dpv_other_delivery: dpv_other_delivery,
                                             dpv_delivery_type: dpv_delivery_type,
                                             post_office_city: post_office_city,
                                             post_office_state: post_office_state,
                                             county_number: county_number,
                                             auto_zone_indicator: auto_zone_indicator,
                                             lacs_link_return_code: lacs_link_return_code,
                                             lacs_link_indicator: lacs_link_indicator,
                                             misc_line: misc_line,
                                             zip5_valid: zip5_valid,
                                             po_box_only_zip: po_box_only_zip,
                                             default_flag: default_flag,
                                             matched_primary_number: matched_primary_number,
                                             matched_secondary_number: matched_secondary_number,
                                             parsed_pmb_designator: parsed_pmb_designator,
                                             parsed_pmb_number: parsed_pmb_number,
                                             suite_link_indicator: suite_link_indicator,
                                             finance_number: finance_number,
                                             base_alternate_code: base_alternate_code,
                                             e_lot_code: e_lot_code,
                                             e_lot_number: e_lot_number)
end

.namesObject

A mapping from model property names to API property names.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 345

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['delivery_point'] = 'deliveryPoint'
  @_hash['carrier_route'] = 'carrierRoute'
  @_hash['county_name'] = 'countyName'
  @_hash['footnotes'] = 'footnotes'
  @_hash['record_type'] = 'recordType'
  @_hash['secondary_info'] = 'secondaryInfo'
  @_hash['return_code'] = 'returnCode'
  @_hash['return_code_text'] = 'returnCodeText'
  @_hash['dpv_confirmation'] = 'DPVConfirmation'
  @_hash['dpv_enhanced_confirmation'] = 'DPVEnhancedConfirmation'
  @_hash['dpv_footnotes'] = 'DPVFootnotes'
  @_hash['dpv_business'] = 'DPVBusiness'
  @_hash['dpvcmra'] = 'DPVCMRA'
  @_hash['dpv_drop'] = 'DPVDrop'
  @_hash['dpv_educational'] = 'DPVEducational'
  @_hash['dpv_drop_count'] = 'DPVDropCount'
  @_hash['dpvlacs'] = 'DPVLACS'
  @_hash['dpv_no_door_delivery'] = 'DPVNoDoorDelivery'
  @_hash['dpvpbsa'] = 'DPVPBSA'
  @_hash['dpv_nostat_reason_code'] = 'DPVNostatReasonCode'
  @_hash['dpv_nostat_reason_code_desc'] = 'DPVNostatReasonCodeDesc'
  @_hash['business'] = 'business'
  @_hash['central_delivery_point'] = 'centralDeliveryPoint'
  @_hash['vacant'] = 'vacant'
  @_hash['dpv_seasonal'] = 'DPVSeasonal'
  @_hash['dpv_throwback'] = 'DPVThrowback'
  @_hash['dpv_no_secure_location'] = 'DPVNoSecureLocation'
  @_hash['dpv_vacant'] = 'DPVVacant'
  @_hash['dpv_nostat'] = 'DPVNostat'
  @_hash['dpv_non_delivery_days_flag'] = 'DPVNonDeliveryDaysFlag'
  @_hash['dpv_non_delivery_days_values'] = 'DPVNonDeliveryDaysValues'
  @_hash['dpv_curb_delivery'] = 'DPVCurbDelivery'
  @_hash['dpv_central_box_delivery'] = 'DPVCentralBoxDelivery'
  @_hash['dpvndcbu_delivery'] = 'DPVNDCBUDelivery'
  @_hash['dpv_other_delivery'] = 'DPVOtherDelivery'
  @_hash['dpv_delivery_type'] = 'DPVDeliveryType'
  @_hash['post_office_city'] = 'postOfficeCity'
  @_hash['post_office_state'] = 'postOfficeState'
  @_hash['county_number'] = 'countyNumber'
  @_hash['auto_zone_indicator'] = 'autoZoneIndicator'
  @_hash['lacs_link_return_code'] = 'LACSLinkReturnCode'
  @_hash['lacs_link_indicator'] = 'LACSLinkIndicator'
  @_hash['misc_line'] = 'miscLine'
  @_hash['zip5_valid'] = 'ZIP5Valid'
  @_hash['po_box_only_zip'] = 'POBoxOnlyZIP'
  @_hash['default_flag'] = 'defaultFlag'
  @_hash['matched_primary_number'] = 'matchedPrimaryNumber'
  @_hash['matched_secondary_number'] = 'matchedSecondaryNumber'
  @_hash['parsed_pmb_designator'] = 'parsedPMBDesignator'
  @_hash['parsed_pmb_number'] = 'parsedPMBNumber'
  @_hash['suite_link_indicator'] = 'suiteLinkIndicator'
  @_hash['finance_number'] = 'financeNumber'
  @_hash['base_alternate_code'] = 'baseAlternateCode'
  @_hash['e_lot_code'] = 'eLOTCode'
  @_hash['e_lot_number'] = 'eLOTNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



467
468
469
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 467

def self.nullables
  []
end

.optionalsObject

An array for optional fields



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 406

def self.optionals
  %w[
    delivery_point
    carrier_route
    county_name
    footnotes
    record_type
    secondary_info
    return_code
    return_code_text
    dpv_confirmation
    dpv_enhanced_confirmation
    dpv_footnotes
    dpv_business
    dpvcmra
    dpv_drop
    dpv_educational
    dpv_drop_count
    dpvlacs
    dpv_no_door_delivery
    dpvpbsa
    dpv_nostat_reason_code
    dpv_nostat_reason_code_desc
    business
    central_delivery_point
    vacant
    dpv_seasonal
    dpv_throwback
    dpv_no_secure_location
    dpv_vacant
    dpv_nostat
    dpv_non_delivery_days_flag
    dpv_non_delivery_days_values
    dpv_curb_delivery
    dpv_central_box_delivery
    dpvndcbu_delivery
    dpv_other_delivery
    dpv_delivery_type
    post_office_city
    post_office_state
    county_number
    auto_zone_indicator
    lacs_link_return_code
    lacs_link_indicator
    misc_line
    zip5_valid
    po_box_only_zip
    default_flag
    matched_primary_number
    matched_secondary_number
    parsed_pmb_designator
    parsed_pmb_number
    suite_link_indicator
    finance_number
    base_alternate_code
    e_lot_code
    e_lot_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 752

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} delivery_point: #{@delivery_point.inspect}, carrier_route:"\
  " #{@carrier_route.inspect}, county_name: #{@county_name.inspect}, footnotes:"\
  " #{@footnotes.inspect}, record_type: #{@record_type.inspect}, secondary_info:"\
  " #{@secondary_info.inspect}, return_code: #{@return_code.inspect}, return_code_text:"\
  " #{@return_code_text.inspect}, dpv_confirmation: #{@dpv_confirmation.inspect},"\
  " dpv_enhanced_confirmation: #{@dpv_enhanced_confirmation.inspect}, dpv_footnotes:"\
  " #{@dpv_footnotes.inspect}, dpv_business: #{@dpv_business.inspect}, dpvcmra:"\
  " #{@dpvcmra.inspect}, dpv_drop: #{@dpv_drop.inspect}, dpv_educational:"\
  " #{@dpv_educational.inspect}, dpv_drop_count: #{@dpv_drop_count.inspect}, dpvlacs:"\
  " #{@dpvlacs.inspect}, dpv_no_door_delivery: #{@dpv_no_door_delivery.inspect}, dpvpbsa:"\
  " #{@dpvpbsa.inspect}, dpv_nostat_reason_code: #{@dpv_nostat_reason_code.inspect},"\
  " dpv_nostat_reason_code_desc: #{@dpv_nostat_reason_code_desc.inspect}, business:"\
  " #{@business.inspect}, central_delivery_point: #{@central_delivery_point.inspect}, vacant:"\
  " #{@vacant.inspect}, dpv_seasonal: #{@dpv_seasonal.inspect}, dpv_throwback:"\
  " #{@dpv_throwback.inspect}, dpv_no_secure_location: #{@dpv_no_secure_location.inspect},"\
  " dpv_vacant: #{@dpv_vacant.inspect}, dpv_nostat: #{@dpv_nostat.inspect},"\
  " dpv_non_delivery_days_flag: #{@dpv_non_delivery_days_flag.inspect},"\
  " dpv_non_delivery_days_values: #{@dpv_non_delivery_days_values.inspect}, dpv_curb_delivery:"\
  " #{@dpv_curb_delivery.inspect}, dpv_central_box_delivery:"\
  " #{@dpv_central_box_delivery.inspect}, dpvndcbu_delivery: #{@dpvndcbu_delivery.inspect},"\
  " dpv_other_delivery: #{@dpv_other_delivery.inspect}, dpv_delivery_type:"\
  " #{@dpv_delivery_type.inspect}, post_office_city: #{@post_office_city.inspect},"\
  " post_office_state: #{@post_office_state.inspect}, county_number:"\
  " #{@county_number.inspect}, auto_zone_indicator: #{@auto_zone_indicator.inspect},"\
  " lacs_link_return_code: #{@lacs_link_return_code.inspect}, lacs_link_indicator:"\
  " #{@lacs_link_indicator.inspect}, misc_line: #{@misc_line.inspect}, zip5_valid:"\
  " #{@zip5_valid.inspect}, po_box_only_zip: #{@po_box_only_zip.inspect}, default_flag:"\
  " #{@default_flag.inspect}, matched_primary_number: #{@matched_primary_number.inspect},"\
  " matched_secondary_number: #{@matched_secondary_number.inspect}, parsed_pmb_designator:"\
  " #{@parsed_pmb_designator.inspect}, parsed_pmb_number: #{@parsed_pmb_number.inspect},"\
  " suite_link_indicator: #{@suite_link_indicator.inspect}, finance_number:"\
  " #{@finance_number.inspect}, base_alternate_code: #{@base_alternate_code.inspect},"\
  " e_lot_code: #{@e_lot_code.inspect}, e_lot_number: #{@e_lot_number.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
# File 'lib/usps_api/models/addresses_address_additional_information1.rb', line 720

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} delivery_point: #{@delivery_point}, carrier_route: #{@carrier_route},"\
  " county_name: #{@county_name}, footnotes: #{@footnotes}, record_type: #{@record_type},"\
  " secondary_info: #{@secondary_info}, return_code: #{@return_code}, return_code_text:"\
  " #{@return_code_text}, dpv_confirmation: #{@dpv_confirmation}, dpv_enhanced_confirmation:"\
  " #{@dpv_enhanced_confirmation}, dpv_footnotes: #{@dpv_footnotes}, dpv_business:"\
  " #{@dpv_business}, dpvcmra: #{@dpvcmra}, dpv_drop: #{@dpv_drop}, dpv_educational:"\
  " #{@dpv_educational}, dpv_drop_count: #{@dpv_drop_count}, dpvlacs: #{@dpvlacs},"\
  " dpv_no_door_delivery: #{@dpv_no_door_delivery}, dpvpbsa: #{@dpvpbsa},"\
  " dpv_nostat_reason_code: #{@dpv_nostat_reason_code}, dpv_nostat_reason_code_desc:"\
  " #{@dpv_nostat_reason_code_desc}, business: #{@business}, central_delivery_point:"\
  " #{@central_delivery_point}, vacant: #{@vacant}, dpv_seasonal: #{@dpv_seasonal},"\
  " dpv_throwback: #{@dpv_throwback}, dpv_no_secure_location: #{@dpv_no_secure_location},"\
  " dpv_vacant: #{@dpv_vacant}, dpv_nostat: #{@dpv_nostat}, dpv_non_delivery_days_flag:"\
  " #{@dpv_non_delivery_days_flag}, dpv_non_delivery_days_values:"\
  " #{@dpv_non_delivery_days_values}, dpv_curb_delivery: #{@dpv_curb_delivery},"\
  " dpv_central_box_delivery: #{@dpv_central_box_delivery}, dpvndcbu_delivery:"\
  " #{@dpvndcbu_delivery}, dpv_other_delivery: #{@dpv_other_delivery}, dpv_delivery_type:"\
  " #{@dpv_delivery_type}, post_office_city: #{@post_office_city}, post_office_state:"\
  " #{@post_office_state}, county_number: #{@county_number}, auto_zone_indicator:"\
  " #{@auto_zone_indicator}, lacs_link_return_code: #{@lacs_link_return_code},"\
  " lacs_link_indicator: #{@lacs_link_indicator}, misc_line: #{@misc_line}, zip5_valid:"\
  " #{@zip5_valid}, po_box_only_zip: #{@po_box_only_zip}, default_flag: #{@default_flag},"\
  " matched_primary_number: #{@matched_primary_number}, matched_secondary_number:"\
  " #{@matched_secondary_number}, parsed_pmb_designator: #{@parsed_pmb_designator},"\
  " parsed_pmb_number: #{@parsed_pmb_number}, suite_link_indicator: #{@suite_link_indicator},"\
  " finance_number: #{@finance_number}, base_alternate_code: #{@base_alternate_code},"\
  " e_lot_code: #{@e_lot_code}, e_lot_number: #{@e_lot_number}>"
end