Class: UspsApi::AddressesCityAndState

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/addresses_city_and_state.rb

Overview

City, State and ZIPCode

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(city: SKIP, state: SKIP, zip_code: SKIP, additional_properties: nil) ⇒ AddressesCityAndState

Returns a new instance of AddressesCityAndState.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 47

def initialize(city: SKIP, state: SKIP, zip_code: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @city = city unless city == SKIP
  @state = state unless state == SKIP
  @zip_code = zip_code unless zip_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

This is the city name of the address.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 14

def city
  @city
end

#stateString

This is two-character state code of the address.

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 18

def state
  @state
end

#zip_codeString

This is the ZIP Code of the address.

Returns:

  • (String)


22
23
24
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 22

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  city = hash.key?('city') ? hash['city'] : SKIP
  state = hash.key?('state') ? hash['state'] : SKIP
  zip_code = hash.key?('ZIPCode') ? hash['ZIPCode'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddressesCityAndState.new(city: city,
                            state: state,
                            zip_code: zip_code,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['city'] = 'city'
  @_hash['state'] = 'state'
  @_hash['zip_code'] = 'ZIPCode'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 34

def self.optionals
  %w[
    city
    state
    zip_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} city: #{@city.inspect}, state: #{@state.inspect}, zip_code:"\
  " #{@zip_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/usps_api/models/addresses_city_and_state.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} city: #{@city}, state: #{@state}, zip_code: #{@zip_code},"\
  " additional_properties: #{@additional_properties}>"
end