Class: UspsApi::BillOfLadingNumberArray
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::BillOfLadingNumberArray
- Defined in:
- lib/usps_api/models/bill_of_lading_number_array.rb
Overview
BillOfLadingNumberArray Model.
Instance Attribute Summary collapse
-
#bill_of_lading_number ⇒ String
Bill of lading number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bill_of_lading_number: SKIP, additional_properties: nil) ⇒ BillOfLadingNumberArray
constructor
A new instance of BillOfLadingNumberArray.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bill_of_lading_number: SKIP, additional_properties: nil) ⇒ BillOfLadingNumberArray
Returns a new instance of BillOfLadingNumberArray.
35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 35 def initialize(bill_of_lading_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bill_of_lading_number = bill_of_lading_number unless bill_of_lading_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bill_of_lading_number ⇒ String
Bill of lading number.
14 15 16 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 14 def bill_of_lading_number @bill_of_lading_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bill_of_lading_number = hash.key?('billOfLadingNumber') ? hash['billOfLadingNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BillOfLadingNumberArray.new(bill_of_lading_number: bill_of_lading_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['bill_of_lading_number'] = 'billOfLadingNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 24 def self.optionals %w[ bill_of_lading_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} bill_of_lading_number: #{@bill_of_lading_number.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/usps_api/models/bill_of_lading_number_array.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} bill_of_lading_number: #{@bill_of_lading_number}, additional_properties:"\ " #{@additional_properties}>" end |