Class: UspsApi::ClosePmodMetadata

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/close_pmod_metadata.rb

Overview

ClosePmodMetadata Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(package_count: SKIP, total_weight: SKIP, additional_properties: nil) ⇒ ClosePmodMetadata

Returns a new instance of ClosePmodMetadata.



41
42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 41

def initialize(package_count: SKIP, total_weight: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @package_count = package_count unless package_count == SKIP
  @total_weight = total_weight unless total_weight == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#package_countInteger

Number of packages in the container

Returns:

  • (Integer)


14
15
16
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 14

def package_count
  @package_count
end

#total_weightFloat

Total weight of all the packages enclosed

Returns:

  • (Float)


18
19
20
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 18

def total_weight
  @total_weight
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  package_count = hash.key?('packageCount') ? hash['packageCount'] : SKIP
  total_weight = hash.key?('totalWeight') ? hash['totalWeight'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ClosePmodMetadata.new(package_count: package_count,
                        total_weight: total_weight,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['package_count'] = 'packageCount'
  @_hash['total_weight'] = 'totalWeight'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 29

def self.optionals
  %w[
    package_count
    total_weight
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} package_count: #{@package_count.inspect}, total_weight:"\
  " #{@total_weight.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/usps_api/models/close_pmod_metadata.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} package_count: #{@package_count}, total_weight: #{@total_weight},"\
  " additional_properties: #{@additional_properties}>"
end