Class: UspsApi::ContainersContainerWarnings

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/containers_container_warnings.rb

Overview

ContainersContainerWarnings Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(warning_code: SKIP, warning_description: SKIP, additional_properties: nil) ⇒ ContainersContainerWarnings

Returns a new instance of ContainersContainerWarnings.



41
42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/containers_container_warnings.rb', line 41

def initialize(warning_code: SKIP, warning_description: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @warning_code = warning_code unless warning_code == SKIP
  @warning_description = warning_description unless warning_description == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#warning_codeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/containers_container_warnings.rb', line 14

def warning_code
  @warning_code
end

#warning_descriptionString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/containers_container_warnings.rb', line 18

def warning_description
  @warning_description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/usps_api/models/containers_container_warnings.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  warning_code = hash.key?('warningCode') ? hash['warningCode'] : SKIP
  warning_description =
    hash.key?('warningDescription') ? hash['warningDescription'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ContainersContainerWarnings.new(warning_code: warning_code,
                                  warning_description: warning_description,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/containers_container_warnings.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['warning_code'] = 'warningCode'
  @_hash['warning_description'] = 'warningDescription'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/containers_container_warnings.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/containers_container_warnings.rb', line 29

def self.optionals
  %w[
    warning_code
    warning_description
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



75
76
77
78
79
80
81
# File 'lib/usps_api/models/containers_container_warnings.rb', line 75

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/usps_api/models/containers_container_warnings.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} warning_code: #{@warning_code.inspect}, warning_description:"\
  " #{@warning_description.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/usps_api/models/containers_container_warnings.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} warning_code: #{@warning_code}, warning_description:"\
  " #{@warning_description}, additional_properties: #{@additional_properties}>"
end