Class: UspsApi::CutOffTimesPickup

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/cut_off_times_pickup.rb

Overview

The latest supported carrier pickup time to receive Connect Local® Same Day service.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(day_of_week: SKIP, cut_off_time: SKIP) ⇒ CutOffTimesPickup

Returns a new instance of CutOffTimesPickup.



42
43
44
45
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 42

def initialize(day_of_week: SKIP, cut_off_time: SKIP)
  @day_of_week = day_of_week unless day_of_week == SKIP
  @cut_off_time = cut_off_time unless cut_off_time == SKIP
end

Instance Attribute Details

#cut_off_timeString

The cut off time represented in military time.

Returns:

  • (String)


19
20
21
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 19

def cut_off_time
  @cut_off_time
end

#day_of_weekDayOfWeek1

The day of the week for the cut off time.

Returns:



15
16
17
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 15

def day_of_week
  @day_of_week
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  day_of_week = hash.key?('dayOfWeek') ? hash['dayOfWeek'] : SKIP
  cut_off_time = hash.key?('cutOffTime') ? hash['cutOffTime'] : SKIP

  # Create object from extracted values.
  CutOffTimesPickup.new(day_of_week: day_of_week,
                        cut_off_time: cut_off_time)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['day_of_week'] = 'dayOfWeek'
  @_hash['cut_off_time'] = 'cutOffTime'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 30

def self.optionals
  %w[
    day_of_week
    cut_off_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
71
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} day_of_week: #{@day_of_week.inspect}, cut_off_time:"\
  " #{@cut_off_time.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/usps_api/models/cut_off_times_pickup.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} day_of_week: #{@day_of_week}, cut_off_time: #{@cut_off_time}>"
end