Class: UspsApi::DisputeSubscription
- Defined in:
- lib/usps_api/models/dispute_subscription.rb
Overview
ABC
Instance Attribute Summary collapse
-
#crid ⇒ String
Specify the Customer Registration ID that should be included in the subscription.
-
#event_types ⇒ Array[EventType3]
Specify what Dispute events should be include in the subscription: </p> ALL - All Below Updates </p> DISPUTE - Description for a Dispute.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(crid: SKIP, event_types: SKIP, additional_properties: nil) ⇒ DisputeSubscription
constructor
A new instance of DisputeSubscription.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(crid: SKIP, event_types: SKIP, additional_properties: nil) ⇒ DisputeSubscription
Returns a new instance of DisputeSubscription.
48 49 50 51 52 53 54 55 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 48 def initialize(crid: SKIP, event_types: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @crid = crid unless crid == SKIP @event_types = event_types unless event_types == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#crid ⇒ String
Specify the Customer Registration ID that should be included in the subscription. Once a subscription is created this field cannot be changed through a future edit, instead the subscription should be deleted and a new subscription should be created.
17 18 19 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 17 def crid @crid end |
#event_types ⇒ Array[EventType3]
Specify what Dispute events should be include in the subscription: </p> ALL - All Below Updates </p> DISPUTE - Description for a Dispute. JOINT_REVIEW - Description for Joint Review. UNUSED_LABEL - Description for Unused Label.
25 26 27 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 25 def event_types @event_types end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. crid = hash.key?('CRID') ? hash['CRID'] : SKIP event_types = hash.key?('eventTypes') ? hash['eventTypes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DisputeSubscription.new(crid: crid, event_types: event_types, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['crid'] = 'CRID' @_hash['event_types'] = 'eventTypes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 36 def self.optionals %w[ crid event_types ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} crid: #{@crid.inspect}, event_types: #{@event_types.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/usps_api/models/dispute_subscription.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} crid: #{@crid}, event_types: #{@event_types}, additional_properties:"\ " #{@additional_properties}>" end |