Class: UspsApi::EnrollmentStatuses
- Defined in:
- lib/usps_api/models/enrollment_statuses.rb
Overview
A list of enrollment status information for one or more MIDs.
Instance Attribute Summary collapse
-
#mi_ds ⇒ Array[EnrollmentStatus]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mi_ds: SKIP, additional_properties: nil) ⇒ EnrollmentStatuses
constructor
A new instance of EnrollmentStatuses.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mi_ds: SKIP, additional_properties: nil) ⇒ EnrollmentStatuses
Returns a new instance of EnrollmentStatuses.
35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 35 def initialize(mi_ds: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mi_ds = mi_ds unless mi_ds == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mi_ds ⇒ Array[EnrollmentStatus]
TODO: Write general description for this method
14 15 16 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 14 def mi_ds @mi_ds end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it mi_ds = nil unless hash['MIDs'].nil? mi_ds = [] hash['MIDs'].each do |structure| mi_ds << (EnrollmentStatus.from_hash(structure) if structure) end end mi_ds = SKIP unless hash.key?('MIDs') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EnrollmentStatuses.new(mi_ds: mi_ds, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['mi_ds'] = 'MIDs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 24 def self.optionals %w[ mi_ds ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} mi_ds: #{@mi_ds.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/usps_api/models/enrollment_statuses.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} mi_ds: #{@mi_ds}, additional_properties: #{@additional_properties}>" end |