Class: UspsApi::Error4
- Defined in:
- lib/usps_api/models/error4.rb
Overview
Error4 Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
Details of the error.
-
#quantity ⇒ Float
Quantity of items affected by the error.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(detail: SKIP, quantity: SKIP, additional_properties: nil) ⇒ Error4
constructor
A new instance of Error4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(detail: SKIP, quantity: SKIP, additional_properties: nil) ⇒ Error4
Returns a new instance of Error4.
41 42 43 44 45 46 47 48 |
# File 'lib/usps_api/models/error4.rb', line 41 def initialize(detail: SKIP, quantity: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @detail = detail unless detail == SKIP @quantity = quantity unless quantity == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ String
Details of the error.
14 15 16 |
# File 'lib/usps_api/models/error4.rb', line 14 def detail @detail end |
#quantity ⇒ Float
Quantity of items affected by the error.
18 19 20 |
# File 'lib/usps_api/models/error4.rb', line 18 def quantity @quantity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/usps_api/models/error4.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. detail = hash.key?('detail') ? hash['detail'] : SKIP quantity = hash.key?('quantity') ? hash['quantity'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Error4.new(detail: detail, quantity: quantity, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/error4.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['detail'] = 'detail' @_hash['quantity'] = 'quantity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/error4.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/error4.rb', line 29 def self.optionals %w[ detail quantity ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/usps_api/models/error4.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail.inspect}, quantity: #{@quantity.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/usps_api/models/error4.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail}, quantity: #{@quantity}, additional_properties:"\ " #{@additional_properties}>" end |