Class: UspsApi::ExtraService7
- Defined in:
- lib/usps_api/models/extra_service7.rb
Overview
ExtraService7 Model.
Instance Attribute Summary collapse
-
#extra_service_amount ⇒ Float
Extra Service Amount.
-
#extra_service_code ⇒ String
Extra Service Code.
-
#extra_service_name ⇒ String
Extra Service Name.
-
#extra_service_sku ⇒ String
Extra Service SKU.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(extra_service_name: SKIP, extra_service_sku: SKIP, extra_service_amount: SKIP, extra_service_code: SKIP, additional_properties: nil) ⇒ ExtraService7
constructor
A new instance of ExtraService7.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(extra_service_name: SKIP, extra_service_sku: SKIP, extra_service_amount: SKIP, extra_service_code: SKIP, additional_properties: nil) ⇒ ExtraService7
Returns a new instance of ExtraService7.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/usps_api/models/extra_service7.rb', line 53 def initialize(extra_service_name: SKIP, extra_service_sku: SKIP, extra_service_amount: SKIP, extra_service_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @extra_service_name = extra_service_name unless extra_service_name == SKIP @extra_service_sku = extra_service_sku unless extra_service_sku == SKIP @extra_service_amount = extra_service_amount unless extra_service_amount == SKIP @extra_service_code = extra_service_code unless extra_service_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#extra_service_amount ⇒ Float
Extra Service Amount
22 23 24 |
# File 'lib/usps_api/models/extra_service7.rb', line 22 def extra_service_amount @extra_service_amount end |
#extra_service_code ⇒ String
Extra Service Code
26 27 28 |
# File 'lib/usps_api/models/extra_service7.rb', line 26 def extra_service_code @extra_service_code end |
#extra_service_name ⇒ String
Extra Service Name
14 15 16 |
# File 'lib/usps_api/models/extra_service7.rb', line 14 def extra_service_name @extra_service_name end |
#extra_service_sku ⇒ String
Extra Service SKU
18 19 20 |
# File 'lib/usps_api/models/extra_service7.rb', line 18 def extra_service_sku @extra_service_sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/usps_api/models/extra_service7.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. extra_service_name = hash.key?('extraServiceName') ? hash['extraServiceName'] : SKIP extra_service_sku = hash.key?('extraServiceSku') ? hash['extraServiceSku'] : SKIP extra_service_amount = hash.key?('extraServiceAmount') ? hash['extraServiceAmount'] : SKIP extra_service_code = hash.key?('extraServiceCode') ? hash['extraServiceCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ExtraService7.new(extra_service_name: extra_service_name, extra_service_sku: extra_service_sku, extra_service_amount: extra_service_amount, extra_service_code: extra_service_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/usps_api/models/extra_service7.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['extra_service_name'] = 'extraServiceName' @_hash['extra_service_sku'] = 'extraServiceSku' @_hash['extra_service_amount'] = 'extraServiceAmount' @_hash['extra_service_code'] = 'extraServiceCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/usps_api/models/extra_service7.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/usps_api/models/extra_service7.rb', line 39 def self.optionals %w[ extra_service_name extra_service_sku extra_service_amount extra_service_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 110 |
# File 'lib/usps_api/models/extra_service7.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} extra_service_name: #{@extra_service_name.inspect}, extra_service_sku:"\ " #{@extra_service_sku.inspect}, extra_service_amount: #{@extra_service_amount.inspect},"\ " extra_service_code: #{@extra_service_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/usps_api/models/extra_service7.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} extra_service_name: #{@extra_service_name}, extra_service_sku:"\ " #{@extra_service_sku}, extra_service_amount: #{@extra_service_amount}, extra_service_code:"\ " #{@extra_service_code}, additional_properties: #{@additional_properties}>" end |