Class: UspsApi::Fee
- Defined in:
- lib/usps_api/models/fee.rb
Overview
Fee Model.
Instance Attribute Summary collapse
-
#assessed_postage ⇒ Float
The census value for the ingredient.
-
#claimed_postage ⇒ Float
Manifest value of the ingredient for postage.
-
#name ⇒ Name
Name of the fee.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, claimed_postage: SKIP, assessed_postage: SKIP, additional_properties: nil) ⇒ Fee
constructor
A new instance of Fee.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, claimed_postage: SKIP, assessed_postage: SKIP, additional_properties: nil) ⇒ Fee
Returns a new instance of Fee.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/fee.rb', line 47 def initialize(name: SKIP, claimed_postage: SKIP, assessed_postage: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @claimed_postage = claimed_postage unless claimed_postage == SKIP @assessed_postage = assessed_postage unless assessed_postage == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#assessed_postage ⇒ Float
The census value for the ingredient
22 23 24 |
# File 'lib/usps_api/models/fee.rb', line 22 def assessed_postage @assessed_postage end |
#claimed_postage ⇒ Float
Manifest value of the ingredient for postage
18 19 20 |
# File 'lib/usps_api/models/fee.rb', line 18 def claimed_postage @claimed_postage end |
#name ⇒ Name
Name of the fee
14 15 16 |
# File 'lib/usps_api/models/fee.rb', line 14 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/usps_api/models/fee.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP claimed_postage = hash.key?('claimedPostage') ? hash['claimedPostage'] : SKIP assessed_postage = hash.key?('assessedPostage') ? hash['assessedPostage'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Fee.new(name: name, claimed_postage: claimed_postage, assessed_postage: assessed_postage, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/fee.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['claimed_postage'] = 'claimedPostage' @_hash['assessed_postage'] = 'assessedPostage' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/fee.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/fee.rb', line 34 def self.optionals %w[ name claimed_postage assessed_postage ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 96 |
# File 'lib/usps_api/models/fee.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, claimed_postage: #{@claimed_postage.inspect},"\ " assessed_postage: #{@assessed_postage.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/usps_api/models/fee.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, claimed_postage: #{@claimed_postage}, assessed_postage:"\ " #{@assessed_postage}, additional_properties: #{@additional_properties}>" end |