Class: UspsApi::HoursOfOperation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/hours_of_operation.rb

Overview

Facility hours of operation intervals of a day.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(day_of_week: SKIP, times: SKIP) ⇒ HoursOfOperation

Returns a new instance of HoursOfOperation.



41
42
43
44
# File 'lib/usps_api/models/hours_of_operation.rb', line 41

def initialize(day_of_week: SKIP, times: SKIP)
  @day_of_week = day_of_week unless day_of_week == SKIP
  @times = times unless times == SKIP
end

Instance Attribute Details

#day_of_weekDayOfWeek

The day of the week for the set of hours.

Returns:



14
15
16
# File 'lib/usps_api/models/hours_of_operation.rb', line 14

def day_of_week
  @day_of_week
end

#timesArray[Time]

Hours

Returns:



18
19
20
# File 'lib/usps_api/models/hours_of_operation.rb', line 18

def times
  @times
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/usps_api/models/hours_of_operation.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  day_of_week = hash.key?('dayOfWeek') ? hash['dayOfWeek'] : SKIP
  # Parameter is an array, so we need to iterate through it
  times = nil
  unless hash['times'].nil?
    times = []
    hash['times'].each do |structure|
      times << (Time.from_hash(structure) if structure)
    end
  end

  times = SKIP unless hash.key?('times')

  # Create object from extracted values.
  HoursOfOperation.new(day_of_week: day_of_week,
                       times: times)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/hours_of_operation.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['day_of_week'] = 'dayOfWeek'
  @_hash['times'] = 'times'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/hours_of_operation.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/hours_of_operation.rb', line 29

def self.optionals
  %w[
    day_of_week
    times
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/usps_api/models/hours_of_operation.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} day_of_week: #{@day_of_week.inspect}, times: #{@times.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/usps_api/models/hours_of_operation.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} day_of_week: #{@day_of_week}, times: #{@times}>"
end