Class: UspsApi::Imb

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/imb.rb

Overview

Imb Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(imb: SKIP, piece_id: SKIP, additional_properties: nil) ⇒ Imb

Returns a new instance of Imb.



42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/imb.rb', line 42

def initialize(imb: SKIP, piece_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @imb = imb unless imb == SKIP
  @piece_id = piece_id unless piece_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#imbString

The IMB successfully added to the campaign.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/imb.rb', line 14

def imb
  @imb
end

#piece_idInteger

The unique pieceID of the IMB for the campaign. This pieceID will be unique if an IMB is added to multiple campaigns.

Returns:

  • (Integer)


19
20
21
# File 'lib/usps_api/models/imb.rb', line 19

def piece_id
  @piece_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/usps_api/models/imb.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  imb = hash.key?('IMB') ? hash['IMB'] : SKIP
  piece_id = hash.key?('pieceID') ? hash['pieceID'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Imb.new(imb: imb,
          piece_id: piece_id,
          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/usps_api/models/imb.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['imb'] = 'IMB'
  @_hash['piece_id'] = 'pieceID'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/usps_api/models/imb.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/usps_api/models/imb.rb', line 30

def self.optionals
  %w[
    imb
    piece_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/usps_api/models/imb.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} imb: #{@imb.inspect}, piece_id: #{@piece_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/usps_api/models/imb.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} imb: #{@imb}, piece_id: #{@piece_id}, additional_properties:"\
  " #{@additional_properties}>"
end