Class: UspsApi::InformedDeliveryPackageCampaignsErrorException

Inherits:
APIException
  • Object
show all
Defined in:
lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb

Overview

Informed Delivery Package Campaigns Error class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ InformedDeliveryPackageCampaignsErrorException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



23
24
25
26
27
# File 'lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb', line 23

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#api_versionString

The version of the API that was used and that raised the error.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb', line 14

def api_version
  @api_version
end

#errorError2

The version of the API that was used and that raised the error.

Returns:



18
19
20
# File 'lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb', line 18

def error
  @error
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



46
47
48
49
# File 'lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb', line 46

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} api_version: #{@api_version.inspect}, error: #{@error.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



40
41
42
43
# File 'lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb', line 40

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} api_version: #{@api_version}, error: #{@error}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



32
33
34
35
36
37
# File 'lib/usps_api/exceptions/informed_delivery_package_campaigns_error_exception.rb', line 32

def unbox(hash)
  return nil unless hash

  @api_version = hash.key?('apiVersion') ? hash['apiVersion'] : SKIP
  @error = Error2.from_hash(hash['error']) if hash['error']
end