Class: UspsApi::InternationalLabelsCancelLabelResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/international_labels_cancel_label_response.rb

Overview

Response information for a label cancellation request including the tracking number, status, and dispute ID if applicable.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tracking_number: SKIP, status: SKIP, dispute_id: SKIP, additional_properties: nil) ⇒ InternationalLabelsCancelLabelResponse

Returns a new instance of InternationalLabelsCancelLabelResponse.



50
51
52
53
54
55
56
57
58
59
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 50

def initialize(tracking_number: SKIP, status: SKIP, dispute_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tracking_number = tracking_number unless tracking_number == SKIP
  @status = status unless status == SKIP
  @dispute_id = dispute_id unless dispute_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dispute_idString

The Id of the submitted refund request.

Returns:

  • (String)


25
26
27
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 25

def dispute_id
  @dispute_id
end

#statusStatus2

  • CANCELED indicates that the label has been successfully canceled.

  • DISPUTED indicates that a refund request has been submitted.

Returns:



21
22
23
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 21

def status
  @status
end

#tracking_numberString

The tracking number associated with the label that has been canceled or for which a refund request has been submitted.

Returns:

  • (String)


16
17
18
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 16

def tracking_number
  @tracking_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tracking_number =
    hash.key?('trackingNumber') ? hash['trackingNumber'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  dispute_id = hash.key?('disputeId') ? hash['disputeId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InternationalLabelsCancelLabelResponse.new(tracking_number: tracking_number,
                                             status: status,
                                             dispute_id: dispute_id,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tracking_number'] = 'trackingNumber'
  @_hash['status'] = 'status'
  @_hash['dispute_id'] = 'disputeId'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
40
41
42
43
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 37

def self.optionals
  %w[
    tracking_number
    status
    dispute_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_number: #{@tracking_number.inspect}, status: #{@status.inspect},"\
  " dispute_id: #{@dispute_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/usps_api/models/international_labels_cancel_label_response.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_number: #{@tracking_number}, status: #{@status}, dispute_id:"\
  " #{@dispute_id}, additional_properties: #{@additional_properties}>"
end