Class: UspsApi::InternationalLabelsCustomerReference

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/international_labels_customer_reference.rb

Overview

User-assigned reference numbers for internal tracking purposes such as order, invoice, or customer numbers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reference_number: SKIP, additional_properties: nil) ⇒ InternationalLabelsCustomerReference

Returns a new instance of InternationalLabelsCustomerReference.



40
41
42
43
44
45
46
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 40

def initialize(reference_number: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reference_number = reference_number unless reference_number == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reference_numberString

A user-assigned number for internal use, such as Order, Invoice, Customer, or Return Merchandise Authorization Numbers. These values will be included in the Shipping Services File. Note:

  • Customer Reference numbers are not displayed with Customs Forms.

Returns:

  • (String)


19
20
21
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 19

def reference_number
  @reference_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reference_number =
    hash.key?('referenceNumber') ? hash['referenceNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InternationalLabelsCustomerReference.new(reference_number: reference_number,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reference_number'] = 'referenceNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 29

def self.optionals
  %w[
    reference_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reference_number: #{@reference_number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/usps_api/models/international_labels_customer_reference.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reference_number: #{@reference_number}, additional_properties:"\
  " #{@additional_properties}>"
end