Class: UspsApi::InternationalLabelsIndiciaRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::InternationalLabelsIndiciaRequest
- Defined in:
- lib/usps_api/models/international_labels_indicia_request.rb
Overview
Indicia request for letters, flats, and cards First-Class Mail International mailings.
Instance Attribute Summary collapse
-
#image_info ⇒ ImageInfo
Additional details used to determine how to generate the indicia image.
-
#indicia_description ⇒ InternationalLabelsIndiciaRequestDescription
The ‘IndiciaRequestDescription` object defines the physical dimensions, mailing date, processing category, and weight required for processing a First-Class Mail International letter, flat, or card.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(indicia_description:, image_info: SKIP, additional_properties: nil) ⇒ InternationalLabelsIndiciaRequest
constructor
A new instance of InternationalLabelsIndiciaRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(indicia_description:, image_info: SKIP, additional_properties: nil) ⇒ InternationalLabelsIndiciaRequest
Returns a new instance of InternationalLabelsIndiciaRequest.
43 44 45 46 47 48 49 50 51 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 43 def initialize(indicia_description:, image_info: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @indicia_description = indicia_description @image_info = image_info unless image_info == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#image_info ⇒ ImageInfo
Additional details used to determine how to generate the indicia image.
21 22 23 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 21 def image_info @image_info end |
#indicia_description ⇒ InternationalLabelsIndiciaRequestDescription
The ‘IndiciaRequestDescription` object defines the physical dimensions, mailing date, processing category, and weight required for processing a First-Class Mail International letter, flat, or card.
17 18 19 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 17 def indicia_description @indicia_description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['indiciaDescription'] indicia_description = InternationalLabelsIndiciaRequestDescription.from_hash(hash['indiciaDescription']) end image_info = ImageInfo.from_hash(hash['imageInfo']) if hash['imageInfo'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InternationalLabelsIndiciaRequest.new(indicia_description: indicia_description, image_info: image_info, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['indicia_description'] = 'indiciaDescription' @_hash['image_info'] = 'imageInfo' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 32 def self.optionals %w[ image_info ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} indicia_description: #{@indicia_description.inspect}, image_info:"\ " #{@image_info.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/usps_api/models/international_labels_indicia_request.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} indicia_description: #{@indicia_description}, image_info: #{@image_info},"\ " additional_properties: #{@additional_properties}>" end |