Class: UspsApi::InternationalPricesBaseRatesQueryResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::InternationalPricesBaseRatesQueryResult
- Defined in:
- lib/usps_api/models/international_prices_base_rates_query_result.rb
Overview
The prices that match the search criteria.
Instance Attribute Summary collapse
-
#rates ⇒ Array[InternationalPricesRateDetails]
List of rate details, including SKU, description and rate ingredients.
-
#total_base_price ⇒ Float
The total price, including the rate, fees and pound postage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total_base_price: SKIP, rates: SKIP, additional_properties: nil) ⇒ InternationalPricesBaseRatesQueryResult
constructor
A new instance of InternationalPricesBaseRatesQueryResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total_base_price: SKIP, rates: SKIP, additional_properties: nil) ⇒ InternationalPricesBaseRatesQueryResult
Returns a new instance of InternationalPricesBaseRatesQueryResult.
41 42 43 44 45 46 47 48 49 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 41 def initialize(total_base_price: SKIP, rates: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @total_base_price = total_base_price unless total_base_price == SKIP @rates = rates unless rates == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#rates ⇒ Array[InternationalPricesRateDetails]
List of rate details, including SKU, description and rate ingredients
18 19 20 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 18 def rates @rates end |
#total_base_price ⇒ Float
The total price, including the rate, fees and pound postage.
14 15 16 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 14 def total_base_price @total_base_price end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total_base_price = hash.key?('totalBasePrice') ? hash['totalBasePrice'] : SKIP # Parameter is an array, so we need to iterate through it rates = nil unless hash['rates'].nil? rates = [] hash['rates'].each do |structure| rates << (InternationalPricesRateDetails.from_hash(structure) if structure) end end rates = SKIP unless hash.key?('rates') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InternationalPricesBaseRatesQueryResult.new(total_base_price: total_base_price, rates: rates, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['total_base_price'] = 'totalBasePrice' @_hash['rates'] = 'rates' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 29 def self.optionals %w[ total_base_price rates ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} total_base_price: #{@total_base_price.inspect}, rates: #{@rates.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/usps_api/models/international_prices_base_rates_query_result.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} total_base_price: #{@total_base_price}, rates: #{@rates},"\ " additional_properties: #{@additional_properties}>" end |