Class: UspsApi::ItemQuote

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/item_quote.rb

Overview

ItemQuote Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(duty_price: SKIP, tax_price: SKIP, item_id: SKIP, additional_properties: nil) ⇒ ItemQuote

Returns a new instance of ItemQuote.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/item_quote.rb', line 47

def initialize(duty_price: SKIP, tax_price: SKIP, item_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @duty_price = duty_price unless duty_price == SKIP
  @tax_price = tax_price unless tax_price == SKIP
  @item_id = item_id unless item_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#duty_priceFloat

The value of the duties associated with the item.

Returns:

  • (Float)


14
15
16
# File 'lib/usps_api/models/item_quote.rb', line 14

def duty_price
  @duty_price
end

#item_idString

The corresponding ‘itemId` provided in the request.

Returns:

  • (String)


22
23
24
# File 'lib/usps_api/models/item_quote.rb', line 22

def item_id
  @item_id
end

#tax_priceFloat

The value of the taxes associated with the item.

Returns:

  • (Float)


18
19
20
# File 'lib/usps_api/models/item_quote.rb', line 18

def tax_price
  @tax_price
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/usps_api/models/item_quote.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  duty_price = hash.key?('dutyPrice') ? hash['dutyPrice'] : SKIP
  tax_price = hash.key?('taxPrice') ? hash['taxPrice'] : SKIP
  item_id = hash.key?('itemId') ? hash['itemId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemQuote.new(duty_price: duty_price,
                tax_price: tax_price,
                item_id: item_id,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/item_quote.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['duty_price'] = 'dutyPrice'
  @_hash['tax_price'] = 'taxPrice'
  @_hash['item_id'] = 'itemId'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/item_quote.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/item_quote.rb', line 34

def self.optionals
  %w[
    duty_price
    tax_price
    item_id
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ItemQuote | Hash)

    value against the validation is performed.



83
84
85
86
87
88
89
# File 'lib/usps_api/models/item_quote.rb', line 83

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/usps_api/models/item_quote.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} duty_price: #{@duty_price.inspect}, tax_price: #{@tax_price.inspect},"\
  " item_id: #{@item_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/usps_api/models/item_quote.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} duty_price: #{@duty_price}, tax_price: #{@tax_price}, item_id: #{@item_id},"\
  " additional_properties: #{@additional_properties}>"
end