Class: UspsApi::LabelBrandingImageDeleteResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/label_branding_image_delete_response.rb

Overview

Label Branding Image Delete Response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(image_name: SKIP, image_uuid: SKIP) ⇒ LabelBrandingImageDeleteResponse

Returns a new instance of LabelBrandingImageDeleteResponse.



41
42
43
44
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 41

def initialize(image_name: SKIP, image_uuid: SKIP)
  @image_name = image_name unless image_name == SKIP
  @image_uuid = image_uuid unless image_uuid == SKIP
end

Instance Attribute Details

#image_nameString

The name of the image that was successfully deleted.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 14

def image_name
  @image_name
end

#image_uuidString

The UUID of the image that was successfully deleted.

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 18

def image_uuid
  @image_uuid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  image_name = hash.key?('imageName') ? hash['imageName'] : SKIP
  image_uuid = hash.key?('imageUUID') ? hash['imageUUID'] : SKIP

  # Create object from extracted values.
  LabelBrandingImageDeleteResponse.new(image_name: image_name,
                                       image_uuid: image_uuid)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['image_name'] = 'imageName'
  @_hash['image_uuid'] = 'imageUUID'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 29

def self.optionals
  %w[
    image_name
    image_uuid
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



66
67
68
69
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 66

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} image_name: #{@image_name.inspect}, image_uuid: #{@image_uuid.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
# File 'lib/usps_api/models/label_branding_image_delete_response.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} image_name: #{@image_name}, image_uuid: #{@image_uuid}>"
end