Class: UspsApi::LabelShipment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/label_shipment.rb

Overview

label shipment

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tracking_numbers:, additional_properties: nil) ⇒ LabelShipment

Returns a new instance of LabelShipment.



33
34
35
36
37
38
39
# File 'lib/usps_api/models/label_shipment.rb', line 33

def initialize(tracking_numbers:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tracking_numbers = tracking_numbers
  @additional_properties = additional_properties
end

Instance Attribute Details

#tracking_numbersArray[String]

Tracking numbers to be added to the SCAN Form.

Returns:

  • (Array[String])


14
15
16
# File 'lib/usps_api/models/label_shipment.rb', line 14

def tracking_numbers
  @tracking_numbers
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/usps_api/models/label_shipment.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tracking_numbers =
    hash.key?('trackingNumbers') ? hash['trackingNumbers'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LabelShipment.new(tracking_numbers: tracking_numbers,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/usps_api/models/label_shipment.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tracking_numbers'] = 'trackingNumbers'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/usps_api/models/label_shipment.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/usps_api/models/label_shipment.rb', line 24

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (LabelShipment | Hash)

    value against the validation is performed.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/usps_api/models/label_shipment.rb', line 63

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.tracking_numbers,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['trackingNumbers'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/usps_api/models/label_shipment.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_numbers: #{@tracking_numbers.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/usps_api/models/label_shipment.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_numbers: #{@tracking_numbers}, additional_properties:"\
  " #{@additional_properties}>"
end