Class: UspsApi::LabelsContainer

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/labels_container.rb

Overview

containers

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(container_id:, sort_type:) ⇒ LabelsContainer

Returns a new instance of LabelsContainer.



38
39
40
41
# File 'lib/usps_api/models/labels_container.rb', line 38

def initialize(container_id:, sort_type:)
  @container_id = container_id
  @sort_type = sort_type
end

Instance Attribute Details

#container_idString

Unique identifier for a container.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/labels_container.rb', line 14

def container_id
  @container_id
end

#sort_typeSortType1

Sort Types requested.

Returns:



18
19
20
# File 'lib/usps_api/models/labels_container.rb', line 18

def sort_type
  @sort_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/usps_api/models/labels_container.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  container_id = hash.key?('containerID') ? hash['containerID'] : nil
  sort_type = hash.key?('sortType') ? hash['sortType'] : nil

  # Create object from extracted values.
  LabelsContainer.new(container_id: container_id,
                      sort_type: sort_type)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/labels_container.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['container_id'] = 'containerID'
  @_hash['sort_type'] = 'sortType'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/usps_api/models/labels_container.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/usps_api/models/labels_container.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (LabelsContainer | Hash)

    value against the validation is performed.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/usps_api/models/labels_container.rb', line 58

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.container_id,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.sort_type,
                              ->(val) { SortType1.validate(val) })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['containerID'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['sortType'],
                            ->(val) { SortType1.validate(val) })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
# File 'lib/usps_api/models/labels_container.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} container_id: #{@container_id.inspect}, sort_type: #{@sort_type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/usps_api/models/labels_container.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} container_id: #{@container_id}, sort_type: #{@sort_type}>"
end