Class: UspsApi::Levelers

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/levelers.rb

Overview

The amount of levelers, by leveler type, available at a facility.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(manual_levelers: SKIP, hydraulic_levelers: SKIP, scissor_levelers: SKIP, additional_properties: nil) ⇒ Levelers

Returns a new instance of Levelers.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/levelers.rb', line 47

def initialize(manual_levelers: SKIP, hydraulic_levelers: SKIP,
               scissor_levelers: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @manual_levelers = manual_levelers unless manual_levelers == SKIP
  @hydraulic_levelers = hydraulic_levelers unless hydraulic_levelers == SKIP
  @scissor_levelers = scissor_levelers unless scissor_levelers == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#hydraulic_levelersInteger

The number of hydraulic levelers available at the facility.

Returns:

  • (Integer)


18
19
20
# File 'lib/usps_api/models/levelers.rb', line 18

def hydraulic_levelers
  @hydraulic_levelers
end

#manual_levelersInteger

The number of manual levelers available at the facility.

Returns:

  • (Integer)


14
15
16
# File 'lib/usps_api/models/levelers.rb', line 14

def manual_levelers
  @manual_levelers
end

#scissor_levelersInteger

The number of scissor levelers available at the facility.

Returns:

  • (Integer)


22
23
24
# File 'lib/usps_api/models/levelers.rb', line 22

def scissor_levelers
  @scissor_levelers
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/usps_api/models/levelers.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  manual_levelers =
    hash.key?('manualLevelers') ? hash['manualLevelers'] : SKIP
  hydraulic_levelers =
    hash.key?('hydraulicLevelers') ? hash['hydraulicLevelers'] : SKIP
  scissor_levelers =
    hash.key?('scissorLevelers') ? hash['scissorLevelers'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Levelers.new(manual_levelers: manual_levelers,
               hydraulic_levelers: hydraulic_levelers,
               scissor_levelers: scissor_levelers,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/levelers.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['manual_levelers'] = 'manualLevelers'
  @_hash['hydraulic_levelers'] = 'hydraulicLevelers'
  @_hash['scissor_levelers'] = 'scissorLevelers'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/levelers.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/levelers.rb', line 34

def self.optionals
  %w[
    manual_levelers
    hydraulic_levelers
    scissor_levelers
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/usps_api/models/levelers.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} manual_levelers: #{@manual_levelers.inspect}, hydraulic_levelers:"\
  " #{@hydraulic_levelers.inspect}, scissor_levelers: #{@scissor_levelers.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
90
# File 'lib/usps_api/models/levelers.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} manual_levelers: #{@manual_levelers}, hydraulic_levelers:"\
  " #{@hydraulic_levelers}, scissor_levelers: #{@scissor_levelers}, additional_properties:"\
  " #{@additional_properties}>"
end