Class: UspsApi::MailerResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/mailer_response.rb

Overview

Response back to the customer when Mailer List insert was created successfully

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(number_of_records_added: SKIP, additional_properties: nil) ⇒ MailerResponse

Returns a new instance of MailerResponse.



36
37
38
39
40
41
42
# File 'lib/usps_api/models/mailer_response.rb', line 36

def initialize(number_of_records_added: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @number_of_records_added = number_of_records_added unless number_of_records_added == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#number_of_records_addedInteger

Number of Mailer records added.

Returns:

  • (Integer)


15
16
17
# File 'lib/usps_api/models/mailer_response.rb', line 15

def number_of_records_added
  @number_of_records_added
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/usps_api/models/mailer_response.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  number_of_records_added =
    hash.key?('numberOfRecordsAdded') ? hash['numberOfRecordsAdded'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MailerResponse.new(number_of_records_added: number_of_records_added,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/usps_api/models/mailer_response.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['number_of_records_added'] = 'numberOfRecordsAdded'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/usps_api/models/mailer_response.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/usps_api/models/mailer_response.rb', line 25

def self.optionals
  %w[
    number_of_records_added
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/usps_api/models/mailer_response.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} number_of_records_added: #{@number_of_records_added.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
69
# File 'lib/usps_api/models/mailer_response.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} number_of_records_added: #{@number_of_records_added},"\
  " additional_properties: #{@additional_properties}>"
end