Class: UspsApi::Next
- Defined in:
- lib/usps_api/models/mnext.rb
Overview
Link to the next page of results.
Instance Attribute Summary collapse
-
#body ⇒ Object
Request body for this page.
-
#href ⇒ String
Endpoint URL (always /reporter).
-
#method ⇒ Method1
HTTP method to use (POST).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(href: SKIP, method: SKIP, body: SKIP, additional_properties: nil) ⇒ Next
constructor
A new instance of Next.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(href: SKIP, method: SKIP, body: SKIP, additional_properties: nil) ⇒ Next
Returns a new instance of Next.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/mnext.rb', line 47 def initialize(href: SKIP, method: SKIP, body: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @href = href unless href == SKIP @method = method unless method == SKIP @body = body unless body == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#body ⇒ Object
Request body for this page
22 23 24 |
# File 'lib/usps_api/models/mnext.rb', line 22 def body @body end |
#href ⇒ String
Endpoint URL (always /reporter)
14 15 16 |
# File 'lib/usps_api/models/mnext.rb', line 14 def href @href end |
#method ⇒ Method1
HTTP method to use (POST)
18 19 20 |
# File 'lib/usps_api/models/mnext.rb', line 18 def method @method end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/usps_api/models/mnext.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. href = hash.key?('href') ? hash['href'] : SKIP method = hash.key?('method') ? hash['method'] : SKIP body = hash.key?('body') ? hash['body'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Next.new(href: href, method: method, body: body, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/mnext.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['href'] = 'href' @_hash['method'] = 'method' @_hash['body'] = 'body' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/mnext.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/mnext.rb', line 34 def self.optionals %w[ href method body ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/usps_api/models/mnext.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} href: #{@href.inspect}, method: #{@method.inspect}, body: #{@body.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/usps_api/models/mnext.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} href: #{@href}, method: #{@method}, body: #{@body}, additional_properties:"\ " #{@additional_properties}>" end |