Class: UspsApi::OauthAuthorizationApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/usps_api/apis/oauth_authorization_api.rb

Overview

OauthAuthorizationApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from UspsApi::BaseApi

Instance Method Details

#refresh_token_oauth_authorization_code(authorization, refresh_token, scope: nil, _field_parameters: nil) ⇒ ApiResponse

Obtain a new access token using a refresh token Basic auth format space-delimited list. supported by this endpoint.

Parameters:

  • authorization (String)

    Required parameter: Authorization header in

  • refresh_token (String)

    Required parameter: Refresh token

  • scope (String) (defaults to: nil)

    Optional parameter: Requested scopes as a

  • _field_parameters (Hash) (defaults to: nil)

    Additional optional form parameters are

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/usps_api/apis/oauth_authorization_api.rb', line 57

def refresh_token_oauth_authorization_code(authorization,
                                           refresh_token,
                                           scope: nil,
                                           _field_parameters: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/token',
                                 Server::AUTH_SERVER)
               .form_param(new_parameter('refresh_token', key: 'grant_type'))
               .header_param(new_parameter(authorization, key: 'Authorization')
                              .is_required(true))
               .form_param(new_parameter(refresh_token, key: 'refresh_token')
                            .is_required(true))
               .form_param(new_parameter(scope, key: 'scope'))
               .header_param(new_parameter('application/x-www-form-urlencoded', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .additional_form_params(_field_parameters))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(OauthToken.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'OAuth 2 provider returned an error.',
                             OauthProviderException)
                .local_error('401',
                             'OAuth 2 provider says client authentication failed.',
                             OauthProviderException))
    .execute
end

#request_token_oauth_authorization_code(authorization, code, redirect_uri, _field_parameters: nil) ⇒ ApiResponse

Create a new OAuth 2 token. Basic auth format supported by this endpoint.

Parameters:

  • authorization (String)

    Required parameter: Authorization header in

  • code (String)

    Required parameter: Authorization Code

  • redirect_uri (String)

    Required parameter: Redirect Uri

  • _field_parameters (Hash) (defaults to: nil)

    Additional optional form parameters are

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/usps_api/apis/oauth_authorization_api.rb', line 17

def request_token_oauth_authorization_code(authorization,
                                           code,
                                           redirect_uri,
                                           _field_parameters: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/token',
                                 Server::AUTH_SERVER)
               .form_param(new_parameter('authorization_code', key: 'grant_type'))
               .header_param(new_parameter(authorization, key: 'Authorization')
                              .is_required(true))
               .form_param(new_parameter(code, key: 'code')
                            .is_required(true))
               .form_param(new_parameter(redirect_uri, key: 'redirect_uri')
                            .is_required(true))
               .header_param(new_parameter('application/x-www-form-urlencoded', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .additional_form_params(_field_parameters))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(OauthToken.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'OAuth 2 provider returned an error.',
                             OauthProviderException)
                .local_error('401',
                             'OAuth 2 provider says client authentication failed.',
                             OauthProviderException))
    .execute
end

#request_token_oauth_client_credentials(authorization, scope: nil, _field_parameters: nil) ⇒ ApiResponse

Create a new OAuth 2 token. Basic auth format space-delimited list. supported by this endpoint.

Parameters:

  • authorization (String)

    Required parameter: Authorization header in

  • scope (String) (defaults to: nil)

    Optional parameter: Requested scopes as a

  • _field_parameters (Hash) (defaults to: nil)

    Additional optional form parameters are

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/usps_api/apis/oauth_authorization_api.rb', line 95

def request_token_oauth_client_credentials(authorization,
                                           scope: nil,
                                           _field_parameters: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/token',
                                 Server::AUTH_SERVER)
               .form_param(new_parameter('client_credentials', key: 'grant_type'))
               .header_param(new_parameter(authorization, key: 'Authorization')
                              .is_required(true))
               .form_param(new_parameter(scope, key: 'scope'))
               .header_param(new_parameter('application/x-www-form-urlencoded', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .additional_form_params(_field_parameters))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(OauthToken.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'OAuth 2 provider returned an error.',
                             OauthProviderException)
                .local_error('401',
                             'OAuth 2 provider says client authentication failed.',
                             OauthProviderException))
    .execute
end