Class: UspsApi::OneTimeAppointment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/one_time_appointment.rb

Overview

Must have either oneTimeAppointment or recurringAppointment

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(preferred_appointment: SKIP, optional_appointment: SKIP, additional_properties: nil) ⇒ OneTimeAppointment

Returns a new instance of OneTimeAppointment.



43
44
45
46
47
48
49
50
51
# File 'lib/usps_api/models/one_time_appointment.rb', line 43

def initialize(preferred_appointment: SKIP, optional_appointment: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @preferred_appointment = preferred_appointment unless preferred_appointment == SKIP
  @optional_appointment = optional_appointment unless optional_appointment == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#optional_appointmentOptionalAppointment

Details of the optional appointment start and end time.

Returns:



20
21
22
# File 'lib/usps_api/models/one_time_appointment.rb', line 20

def optional_appointment
  @optional_appointment
end

#preferred_appointmentDateTime

Preferred appointment date and time in ISO 8601 format. Required for Create actions.

Returns:

  • (DateTime)


16
17
18
# File 'lib/usps_api/models/one_time_appointment.rb', line 16

def preferred_appointment
  @preferred_appointment
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/usps_api/models/one_time_appointment.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  preferred_appointment = if hash.key?('preferredAppointment')
                            (DateTimeHelper.from_rfc3339(hash['preferredAppointment']) if hash['preferredAppointment'])
                          else
                            SKIP
                          end
  optional_appointment = OptionalAppointment.from_hash(hash['optionalAppointment']) if
    hash['optionalAppointment']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OneTimeAppointment.new(preferred_appointment: preferred_appointment,
                         optional_appointment: optional_appointment,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/usps_api/models/one_time_appointment.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['preferred_appointment'] = 'preferredAppointment'
  @_hash['optional_appointment'] = 'optionalAppointment'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/usps_api/models/one_time_appointment.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/usps_api/models/one_time_appointment.rb', line 31

def self.optionals
  %w[
    preferred_appointment
    optional_appointment
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
96
# File 'lib/usps_api/models/one_time_appointment.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} preferred_appointment: #{@preferred_appointment.inspect},"\
  " optional_appointment: #{@optional_appointment.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_preferred_appointmentObject



79
80
81
# File 'lib/usps_api/models/one_time_appointment.rb', line 79

def to_custom_preferred_appointment
  DateTimeHelper.to_rfc3339(preferred_appointment)
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/usps_api/models/one_time_appointment.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} preferred_appointment: #{@preferred_appointment}, optional_appointment:"\
  " #{@optional_appointment}, additional_properties: #{@additional_properties}>"
end