Class: UspsApi::PalletPreSortLevel
- Defined in:
- lib/usps_api/models/pallet_pre_sort_level.rb
Overview
PalletPreSortLevel Model.
Instance Attribute Summary collapse
-
#container_level ⇒ ContainerLevel
Presort content level information.
-
#count ⇒ Integer
Count for the palletPreSortLevel.
-
#usps_container_info ⇒ UspsContainerInfo
Details of the container and its contents.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(usps_container_info: SKIP, container_level: SKIP, count: SKIP, additional_properties: nil) ⇒ PalletPreSortLevel
constructor
A new instance of PalletPreSortLevel.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(usps_container_info: SKIP, container_level: SKIP, count: SKIP, additional_properties: nil) ⇒ PalletPreSortLevel
Returns a new instance of PalletPreSortLevel.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 47 def initialize(usps_container_info: SKIP, container_level: SKIP, count: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @usps_container_info = usps_container_info unless usps_container_info == SKIP @container_level = container_level unless container_level == SKIP @count = count unless count == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#container_level ⇒ ContainerLevel
Presort content level information. Required for Create actions.
18 19 20 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 18 def container_level @container_level end |
#count ⇒ Integer
Count for the palletPreSortLevel. Required for Create actions.
22 23 24 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 22 def count @count end |
#usps_container_info ⇒ UspsContainerInfo
Details of the container and its contents.
14 15 16 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 14 def usps_container_info @usps_container_info end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. usps_container_info = UspsContainerInfo.from_hash(hash['uspsContainerInfo']) if hash['uspsContainerInfo'] container_level = hash.key?('containerLevel') ? hash['containerLevel'] : SKIP count = hash.key?('count') ? hash['count'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PalletPreSortLevel.new(usps_container_info: usps_container_info, container_level: container_level, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['usps_container_info'] = 'uspsContainerInfo' @_hash['container_level'] = 'containerLevel' @_hash['count'] = 'count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 34 def self.optionals %w[ usps_container_info container_level count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 96 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} usps_container_info: #{@usps_container_info.inspect}, container_level:"\ " #{@container_level.inspect}, count: #{@count.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/usps_api/models/pallet_pre_sort_level.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} usps_container_info: #{@usps_container_info}, container_level:"\ " #{@container_level}, count: #{@count}, additional_properties: #{@additional_properties}>" end |