Class: UspsApi::Parcel
- Defined in:
- lib/usps_api/models/parcel.rb
Overview
Parcel Model.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Count for parcels.
-
#pre_sort_level ⇒ Array[PreSortLevel2]
Array for the preSortLevel objects.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(pre_sort_level: SKIP, count: SKIP, additional_properties: nil) ⇒ Parcel
constructor
A new instance of Parcel.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(pre_sort_level: SKIP, count: SKIP, additional_properties: nil) ⇒ Parcel
Returns a new instance of Parcel.
41 42 43 44 45 46 47 48 49 |
# File 'lib/usps_api/models/parcel.rb', line 41 def initialize(pre_sort_level: SKIP, count: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @pre_sort_level = pre_sort_level unless pre_sort_level == SKIP @count = count unless count == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#count ⇒ Integer
Count for parcels
18 19 20 |
# File 'lib/usps_api/models/parcel.rb', line 18 def count @count end |
#pre_sort_level ⇒ Array[PreSortLevel2]
Array for the preSortLevel objects
14 15 16 |
# File 'lib/usps_api/models/parcel.rb', line 14 def pre_sort_level @pre_sort_level end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/usps_api/models/parcel.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it pre_sort_level = nil unless hash['preSortLevel'].nil? pre_sort_level = [] hash['preSortLevel'].each do |structure| pre_sort_level << (PreSortLevel2.from_hash(structure) if structure) end end pre_sort_level = SKIP unless hash.key?('preSortLevel') count = hash.key?('count') ? hash['count'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Parcel.new(pre_sort_level: pre_sort_level, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/parcel.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['pre_sort_level'] = 'preSortLevel' @_hash['count'] = 'count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/parcel.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/parcel.rb', line 29 def self.optionals %w[ pre_sort_level count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/usps_api/models/parcel.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} pre_sort_level: #{@pre_sort_level.inspect}, count: #{@count.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/usps_api/models/parcel.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} pre_sort_level: #{@pre_sort_level}, count: #{@count},"\ " additional_properties: #{@additional_properties}>" end |