Class: UspsApi::PermitNumber
- Defined in:
- lib/usps_api/models/permit_number.rb
Overview
PermitNumber Model.
Instance Attribute Summary collapse
-
#permit_number ⇒ String
A permit number.
-
#permit_zip ⇒ String
The ZIP code to which the permit is assigned.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(permit_number: SKIP, permit_zip: SKIP) ⇒ PermitNumber
constructor
A new instance of PermitNumber.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(permit_number: SKIP, permit_zip: SKIP) ⇒ PermitNumber
Returns a new instance of PermitNumber.
41 42 43 44 |
# File 'lib/usps_api/models/permit_number.rb', line 41 def initialize(permit_number: SKIP, permit_zip: SKIP) @permit_number = permit_number unless permit_number == SKIP @permit_zip = permit_zip unless permit_zip == SKIP end |
Instance Attribute Details
#permit_number ⇒ String
A permit number.
14 15 16 |
# File 'lib/usps_api/models/permit_number.rb', line 14 def permit_number @permit_number end |
#permit_zip ⇒ String
The ZIP code to which the permit is assigned.
18 19 20 |
# File 'lib/usps_api/models/permit_number.rb', line 18 def permit_zip @permit_zip end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/usps_api/models/permit_number.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. permit_number = hash.key?('permitNumber') ? hash['permitNumber'] : SKIP permit_zip = hash.key?('permitZIP') ? hash['permitZIP'] : SKIP # Create object from extracted values. PermitNumber.new(permit_number: permit_number, permit_zip: permit_zip) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/permit_number.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['permit_number'] = 'permitNumber' @_hash['permit_zip'] = 'permitZIP' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/permit_number.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/permit_number.rb', line 29 def self.optionals %w[ permit_number permit_zip ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/usps_api/models/permit_number.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} permit_number: #{@permit_number.inspect}, permit_zip:"\ " #{@permit_zip.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/usps_api/models/permit_number.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} permit_number: #{@permit_number}, permit_zip: #{@permit_zip}>" end |