Class: UspsApi::PhoneNumbers

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/phone_numbers.rb

Overview

Post office contact information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(phone: SKIP, fax: SKIP, additional_properties: nil) ⇒ PhoneNumbers

Returns a new instance of PhoneNumbers.



43
44
45
46
47
48
49
50
# File 'lib/usps_api/models/phone_numbers.rb', line 43

def initialize(phone: SKIP, fax: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @phone = phone unless phone == SKIP
  @fax = fax unless fax == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#faxString

The phone number, including the country extension and area code, with no punctuation.

Returns:

  • (String)


20
21
22
# File 'lib/usps_api/models/phone_numbers.rb', line 20

def fax
  @fax
end

#phoneString

The phone number, including the country extension and area code, with no punctuation.

Returns:

  • (String)


15
16
17
# File 'lib/usps_api/models/phone_numbers.rb', line 15

def phone
  @phone
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/usps_api/models/phone_numbers.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  phone = hash.key?('phone') ? hash['phone'] : SKIP
  fax = hash.key?('fax') ? hash['fax'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PhoneNumbers.new(phone: phone,
                   fax: fax,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/usps_api/models/phone_numbers.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['phone'] = 'phone'
  @_hash['fax'] = 'fax'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/usps_api/models/phone_numbers.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/usps_api/models/phone_numbers.rb', line 31

def self.optionals
  %w[
    phone
    fax
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/usps_api/models/phone_numbers.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} phone: #{@phone.inspect}, fax: #{@fax.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/usps_api/models/phone_numbers.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} phone: #{@phone}, fax: #{@fax}, additional_properties:"\
  " #{@additional_properties}>"
end