Class: UspsApi::PickupEmailNotification
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::PickupEmailNotification
- Defined in:
- lib/usps_api/models/pickup_email_notification.rb
Overview
Email notification recipient details.
Instance Attribute Summary collapse
-
#email ⇒ String
E-mail address of recipient.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(email: SKIP, additional_properties: nil) ⇒ PickupEmailNotification
constructor
A new instance of PickupEmailNotification.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(email: SKIP, additional_properties: nil) ⇒ PickupEmailNotification
Returns a new instance of PickupEmailNotification.
36 37 38 39 40 41 42 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 36 def initialize(email: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @email = email unless email == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#email ⇒ String
E-mail address of recipient. Valid e-mail addresses must be used used for notifications via email.
15 16 17 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 15 def email @email end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. email = hash.key?('email') ? hash['email'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PickupEmailNotification.new(email: email, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['email'] = 'email' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 25 def self.optionals %w[ email ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
65 66 67 68 69 70 71 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 65 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} email: #{@email.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 |
# File 'lib/usps_api/models/pickup_email_notification.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} email: #{@email}, additional_properties: #{@additional_properties}>" end |