Class: UspsApi::PmodDomesticLabelAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/pmod_domestic_label_address.rb

Overview

Uses for: The address where the package is being mailed from. The destination ZIP Code is used for calculating pricing. The destination address of the recipient. The origin ZIP Code is used for calculating pricing. The address of the business. The address where the package should be returned to if it is deemed undeliverable or returned to sender. This address will be printed in the return address block of the label.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(street_address:, city:, state:, zip_code:, secondary_address: SKIP, zip_plus4: SKIP, urbanization: SKIP, first_name: SKIP, last_name: SKIP, firm: SKIP, phone: SKIP, email: SKIP, ignore_bad_address: SKIP, additional_properties: nil) ⇒ PmodDomesticLabelAddress

Returns a new instance of PmodDomesticLabelAddress.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 125

def initialize(street_address:, city:, state:, zip_code:,
               secondary_address: SKIP, zip_plus4: SKIP, urbanization: SKIP,
               first_name: SKIP, last_name: SKIP, firm: SKIP, phone: SKIP,
               email: SKIP, ignore_bad_address: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @street_address = street_address
  @secondary_address = secondary_address unless secondary_address == SKIP
  @city = city
  @state = state
  @zip_code = zip_code
  @zip_plus4 = zip_plus4 unless zip_plus4 == SKIP
  @urbanization = urbanization unless urbanization == SKIP
  @first_name = first_name unless first_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @firm = firm unless firm == SKIP
  @phone = phone unless phone == SKIP
  @email = email unless email == SKIP
  @ignore_bad_address = ignore_bad_address unless ignore_bad_address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

This is the city name of the address.

Returns:

  • (String)


31
32
33
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 31

def city
  @city
end

#emailString

Email address used for redirect notification via email.

Returns:

  • (String)


71
72
73
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 71

def email
  @email
end

#firmString

This is the firm corresponding to the address. Firm is required for all domestic addresses in international label requests due to customs form requirements.

Returns:

  • (String)


62
63
64
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 62

def firm
  @firm
end

#first_nameString

This is the first name corresponding to the address.

Returns:

  • (String)


52
53
54
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 52

def first_name
  @first_name
end

#ignore_bad_addressTrueClass | FalseClass

Allows Non-Validated Origin Street Address. Enter “true” to bypass street address validation failures/errors or “false” if only validated addresses should be allowed. Note: Integrators are recommended to always use “false” to ensure no delivery issues. In the event USPS cannot validate the street address, this tag will “bypass” address validation error when “true” is indicated to allow label creation which could impact delivery.

Returns:

  • (TrueClass | FalseClass)


82
83
84
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 82

def ignore_bad_address
  @ignore_bad_address
end

#last_nameString

This is the last name corresponding to the address.

Returns:

  • (String)


56
57
58
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 56

def last_name
  @last_name
end

#phoneString

The phone number, including the country extension and area code, with no punctuation.

Returns:

  • (String)


67
68
69
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 67

def phone
  @phone
end

#secondary_addressString

The secondary unit designator, such as apartment(APT) or suite(STE) number, defining the exact location of the address within a building. For more information please see [Postal Explorer](pe.usps.com/text/pub28/28c2_003.htm).

Returns:

  • (String)


27
28
29
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 27

def secondary_address
  @secondary_address
end

#stateString

This is two-character state code of the address.

Returns:

  • (String)


35
36
37
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 35

def state
  @state
end

#street_addressString

The number of a building along with the name of the road or street on which it is located.

Returns:

  • (String)


20
21
22
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 20

def street_address
  @street_address
end

#urbanizationString

An area, sector, or residential development within a geographic area (typically used for addresses in Puerto Rico)

Returns:

  • (String)


48
49
50
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 48

def urbanization
  @urbanization
end

#zip_codeString

This is the 5-digit ZIP code.

Returns:

  • (String)


39
40
41
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 39

def zip_code
  @zip_code
end

#zip_plus4String

This is the ZIP+4 extension.

Returns:

  • (String)


43
44
45
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 43

def zip_plus4
  @zip_plus4
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 150

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  street_address = hash.key?('streetAddress') ? hash['streetAddress'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  state = hash.key?('state') ? hash['state'] : nil
  zip_code = hash.key?('ZIPCode') ? hash['ZIPCode'] : nil
  secondary_address =
    hash.key?('secondaryAddress') ? hash['secondaryAddress'] : SKIP
  zip_plus4 = hash.key?('ZIPPlus4') ? hash['ZIPPlus4'] : SKIP
  urbanization = hash.key?('urbanization') ? hash['urbanization'] : SKIP
  first_name = hash.key?('firstName') ? hash['firstName'] : SKIP
  last_name = hash.key?('lastName') ? hash['lastName'] : SKIP
  firm = hash.key?('firm') ? hash['firm'] : SKIP
  phone = hash.key?('phone') ? hash['phone'] : SKIP
  email = hash.key?('email') ? hash['email'] : SKIP
  ignore_bad_address =
    hash.key?('ignoreBadAddress') ? hash['ignoreBadAddress'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PmodDomesticLabelAddress.new(street_address: street_address,
                               city: city,
                               state: state,
                               zip_code: zip_code,
                               secondary_address: secondary_address,
                               zip_plus4: zip_plus4,
                               urbanization: urbanization,
                               first_name: first_name,
                               last_name: last_name,
                               firm: firm,
                               phone: phone,
                               email: email,
                               ignore_bad_address: ignore_bad_address,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 85

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['street_address'] = 'streetAddress'
  @_hash['secondary_address'] = 'secondaryAddress'
  @_hash['city'] = 'city'
  @_hash['state'] = 'state'
  @_hash['zip_code'] = 'ZIPCode'
  @_hash['zip_plus4'] = 'ZIPPlus4'
  @_hash['urbanization'] = 'urbanization'
  @_hash['first_name'] = 'firstName'
  @_hash['last_name'] = 'lastName'
  @_hash['firm'] = 'firm'
  @_hash['phone'] = 'phone'
  @_hash['email'] = 'email'
  @_hash['ignore_bad_address'] = 'ignoreBadAddress'
  @_hash
end

.nullablesObject

An array for nullable fields



119
120
121
122
123
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 119

def self.nullables
  %w[
    zip_plus4
  ]
end

.optionalsObject

An array for optional fields



104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 104

def self.optionals
  %w[
    secondary_address
    zip_plus4
    urbanization
    first_name
    last_name
    firm
    phone
    email
    ignore_bad_address
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 196

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.street_address,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.city,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.state,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.zip_code,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['streetAddress'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['city'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['state'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['ZIPCode'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



236
237
238
239
240
241
242
243
244
245
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 236

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} street_address: #{@street_address.inspect}, secondary_address:"\
  " #{@secondary_address.inspect}, city: #{@city.inspect}, state: #{@state.inspect}, zip_code:"\
  " #{@zip_code.inspect}, zip_plus4: #{@zip_plus4.inspect}, urbanization:"\
  " #{@urbanization.inspect}, first_name: #{@first_name.inspect}, last_name:"\
  " #{@last_name.inspect}, firm: #{@firm.inspect}, phone: #{@phone.inspect}, email:"\
  " #{@email.inspect}, ignore_bad_address: #{@ignore_bad_address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



225
226
227
228
229
230
231
232
233
# File 'lib/usps_api/models/pmod_domestic_label_address.rb', line 225

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} street_address: #{@street_address}, secondary_address:"\
  " #{@secondary_address}, city: #{@city}, state: #{@state}, zip_code: #{@zip_code},"\
  " zip_plus4: #{@zip_plus4}, urbanization: #{@urbanization}, first_name: #{@first_name},"\
  " last_name: #{@last_name}, firm: #{@firm}, phone: #{@phone}, email: #{@email},"\
  " ignore_bad_address: #{@ignore_bad_address}, additional_properties:"\
  " #{@additional_properties}>"
end