Class: UspsApi::PrepaidDutiesTaxesFees

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/prepaid_duties_taxes_fees.rb

Overview

The total landed cost package and item details. Included if ‘prepayDutiesTaxesFees` is `true`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(package_fee: SKIP, item_costs: SKIP, additional_properties: nil) ⇒ PrepaidDutiesTaxesFees

Returns a new instance of PrepaidDutiesTaxesFees.



42
43
44
45
46
47
48
49
50
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 42

def initialize(package_fee: SKIP, item_costs: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @package_fee = package_fee unless package_fee == SKIP
  @item_costs = item_costs unless item_costs == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#item_costsArray[ItemCost]

The prices for taxes and duties on each item.

Returns:



19
20
21
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 19

def item_costs
  @item_costs
end

#package_feeFloat

The value of the delivery fees associated with the package.

Returns:

  • (Float)


15
16
17
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 15

def package_fee
  @package_fee
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  package_fee = hash.key?('packageFee') ? hash['packageFee'] : SKIP
  # Parameter is an array, so we need to iterate through it
  item_costs = nil
  unless hash['itemCosts'].nil?
    item_costs = []
    hash['itemCosts'].each do |structure|
      item_costs << (ItemCost.from_hash(structure) if structure)
    end
  end

  item_costs = SKIP unless hash.key?('itemCosts')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PrepaidDutiesTaxesFees.new(package_fee: package_fee,
                             item_costs: item_costs,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['package_fee'] = 'packageFee'
  @_hash['item_costs'] = 'itemCosts'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 30

def self.optionals
  %w[
    package_fee
    item_costs
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} package_fee: #{@package_fee.inspect}, item_costs: #{@item_costs.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/usps_api/models/prepaid_duties_taxes_fees.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} package_fee: #{@package_fee}, item_costs: #{@item_costs},"\
  " additional_properties: #{@additional_properties}>"
end