Class: UspsApi::PricesBaseRatesQueryResult1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::PricesBaseRatesQueryResult1
- Defined in:
- lib/usps_api/models/prices_base_rates_query_result1.rb
Overview
The prices that match the search criteria.
Instance Attribute Summary collapse
-
#rates ⇒ Array[PricesTotalRatesQuery1]
List of base rate details associated with the shipment.
-
#total_base_price ⇒ Float
The total price, including the rate, fees and pound postage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total_base_price: SKIP, rates: SKIP) ⇒ PricesBaseRatesQueryResult1
constructor
A new instance of PricesBaseRatesQueryResult1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total_base_price: SKIP, rates: SKIP) ⇒ PricesBaseRatesQueryResult1
Returns a new instance of PricesBaseRatesQueryResult1.
41 42 43 44 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 41 def initialize(total_base_price: SKIP, rates: SKIP) @total_base_price = total_base_price unless total_base_price == SKIP @rates = rates unless rates == SKIP end |
Instance Attribute Details
#rates ⇒ Array[PricesTotalRatesQuery1]
List of base rate details associated with the shipment.
18 19 20 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 18 def rates @rates end |
#total_base_price ⇒ Float
The total price, including the rate, fees and pound postage.
14 15 16 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 14 def total_base_price @total_base_price end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total_base_price = hash.key?('totalBasePrice') ? hash['totalBasePrice'] : SKIP # Parameter is an array, so we need to iterate through it rates = nil unless hash['rates'].nil? rates = [] hash['rates'].each do |structure| rates << (PricesTotalRatesQuery1.from_hash(structure) if structure) end end rates = SKIP unless hash.key?('rates') # Create object from extracted values. PricesBaseRatesQueryResult1.new(total_base_price: total_base_price, rates: rates) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['total_base_price'] = 'totalBasePrice' @_hash['rates'] = 'rates' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 29 def self.optionals %w[ total_base_price rates ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} total_base_price: #{@total_base_price.inspect}, rates: #{@rates.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/usps_api/models/prices_base_rates_query_result1.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} total_base_price: #{@total_base_price}, rates: #{@rates}>" end |