Class: UspsApi::ProofOfDeliveryResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/proof_of_delivery_response.rb

Overview

Proof of Delivery API response details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(result_text: SKIP, return_code: SKIP) ⇒ ProofOfDeliveryResponse

Returns a new instance of ProofOfDeliveryResponse.



41
42
43
44
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 41

def initialize(result_text: SKIP, return_code: SKIP)
  @result_text = result_text unless result_text == SKIP
  @return_code = return_code unless return_code == SKIP
end

Instance Attribute Details

#result_textString

A human-readable status of the proof of delivery request.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 14

def result_text
  @result_text
end

#return_codeString

The status code of the proof of delivery request.

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 18

def return_code
  @return_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  result_text = hash.key?('resultText') ? hash['resultText'] : SKIP
  return_code = hash.key?('returnCode') ? hash['returnCode'] : SKIP

  # Create object from extracted values.
  ProofOfDeliveryResponse.new(result_text: result_text,
                              return_code: return_code)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['result_text'] = 'resultText'
  @_hash['return_code'] = 'returnCode'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 29

def self.optionals
  %w[
    result_text
    return_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



66
67
68
69
70
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 66

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} result_text: #{@result_text.inspect}, return_code:"\
  " #{@return_code.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
# File 'lib/usps_api/models/proof_of_delivery_response.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} result_text: #{@result_text}, return_code: #{@return_code}>"
end