Class: UspsApi::QueryString
- Defined in:
- lib/usps_api/models/query_string.rb
Overview
QueryString Model.
Instance Attribute Summary collapse
-
#campaigns ⇒ Array[Campaign1]
TODO: Write general description for this method.
-
#metadata ⇒ Metadata
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(campaigns: SKIP, metadata: SKIP, additional_properties: nil) ⇒ QueryString
constructor
A new instance of QueryString.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(campaigns: SKIP, metadata: SKIP, additional_properties: nil) ⇒ QueryString
Returns a new instance of QueryString.
41 42 43 44 45 46 47 48 |
# File 'lib/usps_api/models/query_string.rb', line 41 def initialize(campaigns: SKIP, metadata: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @campaigns = campaigns unless campaigns == SKIP @metadata = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#campaigns ⇒ Array[Campaign1]
TODO: Write general description for this method
14 15 16 |
# File 'lib/usps_api/models/query_string.rb', line 14 def campaigns @campaigns end |
#metadata ⇒ Metadata
TODO: Write general description for this method
18 19 20 |
# File 'lib/usps_api/models/query_string.rb', line 18 def @metadata end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/usps_api/models/query_string.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it campaigns = nil unless hash['campaigns'].nil? campaigns = [] hash['campaigns'].each do |structure| campaigns << (Campaign1.from_hash(structure) if structure) end end campaigns = SKIP unless hash.key?('campaigns') = Metadata.from_hash(hash['metadata']) if hash['metadata'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. QueryString.new(campaigns: campaigns, metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/query_string.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['campaigns'] = 'campaigns' @_hash['metadata'] = 'metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/query_string.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/query_string.rb', line 29 def self.optionals %w[ campaigns metadata ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/usps_api/models/query_string.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} campaigns: #{@campaigns.inspect}, metadata: #{@metadata.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/usps_api/models/query_string.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} campaigns: #{@campaigns}, metadata: #{@metadata}, additional_properties:"\ " #{@additional_properties}>" end |