Class: UspsApi::ScanFormsScanForm
- Defined in:
- lib/usps_api/models/scan_forms_scan_form.rb
Overview
scan form
Instance Attribute Summary collapse
-
#scan_form_image ⇒ String
Image of the scan form.
-
#scan_form_meta_data ⇒ ScanFormMetaData
Metadata for the scan form.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(scan_form_meta_data: SKIP, scan_form_image: SKIP) ⇒ ScanFormsScanForm
constructor
A new instance of ScanFormsScanForm.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(scan_form_meta_data: SKIP, scan_form_image: SKIP) ⇒ ScanFormsScanForm
Returns a new instance of ScanFormsScanForm.
41 42 43 44 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 41 def initialize(scan_form_meta_data: SKIP, scan_form_image: SKIP) @scan_form_meta_data = unless == SKIP @scan_form_image = scan_form_image unless scan_form_image == SKIP end |
Instance Attribute Details
#scan_form_image ⇒ String
Image of the scan form
18 19 20 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 18 def scan_form_image @scan_form_image end |
#scan_form_meta_data ⇒ ScanFormMetaData
Metadata for the scan form
14 15 16 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 14 def @scan_form_meta_data end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = ScanFormMetaData.from_hash(hash['SCANFormMetaData']) if hash['SCANFormMetaData'] scan_form_image = hash.key?('SCANFormImage') ? hash['SCANFormImage'] : SKIP # Create object from extracted values. ScanFormsScanForm.new(scan_form_meta_data: , scan_form_image: scan_form_image) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['scan_form_meta_data'] = 'SCANFormMetaData' @_hash['scan_form_image'] = 'SCANFormImage' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 29 def self.optionals %w[ scan_form_meta_data scan_form_image ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} scan_form_meta_data: #{@scan_form_meta_data.inspect}, scan_form_image:"\ " #{@scan_form_image.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/usps_api/models/scan_forms_scan_form.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} scan_form_meta_data: #{@scan_form_meta_data}, scan_form_image:"\ " #{@scan_form_image}>" end |