Class: UspsApi::SchedulePickupRequestPackages
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::SchedulePickupRequestPackages
- Defined in:
- lib/usps_api/models/schedule_pickup_request_packages.rb
Overview
SchedulePickupRequestPackages Model.
Instance Attribute Summary collapse
-
#package_count ⇒ Integer
Number of packages ready for pick-up for the associated Mail Class.
-
#package_type ⇒ PackageType
This is the type of package ready for pick-up.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(package_type:, package_count:) ⇒ SchedulePickupRequestPackages
constructor
A new instance of SchedulePickupRequestPackages.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_type:, package_count:) ⇒ SchedulePickupRequestPackages
Returns a new instance of SchedulePickupRequestPackages.
38 39 40 41 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 38 def initialize(package_type:, package_count:) @package_type = package_type @package_count = package_count end |
Instance Attribute Details
#package_count ⇒ Integer
Number of packages ready for pick-up for the associated Mail Class.
18 19 20 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 18 def package_count @package_count end |
#package_type ⇒ PackageType
This is the type of package ready for pick-up
14 15 16 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 14 def package_type @package_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. package_type = hash.key?('packageType') ? hash['packageType'] : nil package_count = hash.key?('packageCount') ? hash['packageCount'] : nil # Create object from extracted values. SchedulePickupRequestPackages.new(package_type: package_type, package_count: package_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['package_type'] = 'packageType' @_hash['package_count'] = 'packageCount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 67 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_type: #{@package_type.inspect}, package_count:"\ " #{@package_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/usps_api/models/schedule_pickup_request_packages.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_type: #{@package_type}, package_count: #{@package_count}>" end |