Class: UspsApi::Slots
- Defined in:
- lib/usps_api/models/slots.rb
Overview
Available Slots
Instance Attribute Summary collapse
-
#appointment_slots ⇒ Array[AppointmentSlot]
Details of the available slots at the requested facility.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(appointment_slots: SKIP) ⇒ Slots
constructor
A new instance of Slots.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(appointment_slots: SKIP) ⇒ Slots
Returns a new instance of Slots.
35 36 37 |
# File 'lib/usps_api/models/slots.rb', line 35 def initialize(appointment_slots: SKIP) @appointment_slots = appointment_slots unless appointment_slots == SKIP end |
Instance Attribute Details
#appointment_slots ⇒ Array[AppointmentSlot]
Details of the available slots at the requested facility.
14 15 16 |
# File 'lib/usps_api/models/slots.rb', line 14 def appointment_slots @appointment_slots end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/usps_api/models/slots.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it appointment_slots = nil unless hash['appointmentSlots'].nil? appointment_slots = [] hash['appointmentSlots'].each do |structure| appointment_slots << (AppointmentSlot.from_hash(structure) if structure) end end appointment_slots = SKIP unless hash.key?('appointmentSlots') # Create object from extracted values. Slots.new(appointment_slots: appointment_slots) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/usps_api/models/slots.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['appointment_slots'] = 'appointmentSlots' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/usps_api/models/slots.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/usps_api/models/slots.rb', line 24 def self.optionals %w[ appointment_slots ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/usps_api/models/slots.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} appointment_slots: #{@appointment_slots.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/usps_api/models/slots.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} appointment_slots: #{@appointment_slots}>" end |