Class: UspsApi::Source

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/source.rb

Overview

The element that is suspected of originating the error. Helps to pinpoint the problem.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(parameter: SKIP, example: SKIP, additional_properties: nil) ⇒ Source

Returns a new instance of Source.



42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/source.rb', line 42

def initialize(parameter: SKIP, example: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @parameter = parameter unless parameter == SKIP
  @example = example unless example == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#exampleString

An example of a valid value for the input parameter.

Returns:

  • (String)


19
20
21
# File 'lib/usps_api/models/source.rb', line 19

def example
  @example
end

#parameterString

The input in the request which caused an error.

Returns:

  • (String)


15
16
17
# File 'lib/usps_api/models/source.rb', line 15

def parameter
  @parameter
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/usps_api/models/source.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  parameter = hash.key?('parameter') ? hash['parameter'] : SKIP
  example = hash.key?('example') ? hash['example'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Source.new(parameter: parameter,
             example: example,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/usps_api/models/source.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['parameter'] = 'parameter'
  @_hash['example'] = 'example'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/usps_api/models/source.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/usps_api/models/source.rb', line 30

def self.optionals
  %w[
    parameter
    example
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/usps_api/models/source.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} parameter: #{@parameter.inspect}, example: #{@example.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/usps_api/models/source.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} parameter: #{@parameter}, example: #{@example}, additional_properties:"\
  " #{@additional_properties}>"
end