Class: UspsApi::SpecialHoursOfOperation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/special_hours_of_operation.rb

Overview

SpecialHoursOfOperation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(date: SKIP, open: SKIP, times: SKIP, additional_properties: nil) ⇒ SpecialHoursOfOperation

Returns a new instance of SpecialHoursOfOperation.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 47

def initialize(date: SKIP, open: SKIP, times: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @date = date unless date == SKIP
  @open = open unless open == SKIP
  @times = times unless times == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dateDate

The day of the week for the set of hours.

Returns:

  • (Date)


14
15
16
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 14

def date
  @date
end

#openTrueClass | FalseClass

Indicates if the facility is open.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 18

def open
  @open
end

#timesArray[Time]

Holiday Hours

Returns:



22
23
24
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 22

def times
  @times
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  date = hash.key?('date') ? hash['date'] : SKIP
  open = hash.key?('open') ? hash['open'] : SKIP
  # Parameter is an array, so we need to iterate through it
  times = nil
  unless hash['times'].nil?
    times = []
    hash['times'].each do |structure|
      times << (Time.from_hash(structure) if structure)
    end
  end

  times = SKIP unless hash.key?('times')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SpecialHoursOfOperation.new(date: date,
                              open: open,
                              times: times,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['date'] = 'date'
  @_hash['open'] = 'open'
  @_hash['times'] = 'times'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 34

def self.optionals
  %w[
    date
    open
    times
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date.inspect}, open: #{@open.inspect}, times: #{@times.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/usps_api/models/special_hours_of_operation.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date}, open: #{@open}, times: #{@times}, additional_properties:"\
  " #{@additional_properties}>"
end