Class: UspsApi::TokenRevocationRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::TokenRevocationRequest
- Defined in:
- lib/usps_api/models/token_revocation_request.rb
Overview
The token revocation request.
Instance Attribute Summary collapse
-
#token ⇒ String
The token (a hash value).
-
#token_type_hint ⇒ TokenTypeHint
A hint to the type of the given token.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(token:, token_type_hint: TokenTypeHint::REFRESH_TOKEN) ⇒ TokenRevocationRequest
constructor
A new instance of TokenRevocationRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(token:, token_type_hint: TokenTypeHint::REFRESH_TOKEN) ⇒ TokenRevocationRequest
Returns a new instance of TokenRevocationRequest.
41 42 43 44 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 41 def initialize(token:, token_type_hint: TokenTypeHint::REFRESH_TOKEN) @token = token @token_type_hint = token_type_hint unless token_type_hint == SKIP end |
Instance Attribute Details
#token ⇒ String
The token (a hash value).
14 15 16 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 14 def token @token end |
#token_type_hint ⇒ TokenTypeHint
A hint to the type of the given token. See OAuth Token Types Hint registry, www.rfc-editor.org/rfc/rfc7009#section-4.1.2.1
19 20 21 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 19 def token_type_hint @token_type_hint end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. token = hash.key?('token') ? hash['token'] : nil token_type_hint = hash['token_type_hint'] ||= TokenTypeHint::REFRESH_TOKEN # Create object from extracted values. TokenRevocationRequest.new(token: token, token_type_hint: token_type_hint) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['token'] = 'token' @_hash['token_type_hint'] = 'token_type_hint' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 30 def self.optionals %w[ token_type_hint ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} token: #{@token.inspect}, token_type_hint: #{@token_type_hint.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/usps_api/models/token_revocation_request.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} token: #{@token}, token_type_hint: #{@token_type_hint}>" end |