Class: UspsApi::TrackingCurrentEvent
- Defined in:
- lib/usps_api/models/tracking_current_event.rb
Overview
The current event type for the shipment.
Instance Attribute Summary collapse
-
#event_type ⇒ EventType1
The type of event.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(event_type:) ⇒ TrackingCurrentEvent
constructor
A new instance of TrackingCurrentEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(event_type:) ⇒ TrackingCurrentEvent
Returns a new instance of TrackingCurrentEvent.
33 34 35 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 33 def initialize(event_type:) @event_type = event_type end |
Instance Attribute Details
#event_type ⇒ EventType1
The type of event.
14 15 16 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 14 def event_type @event_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. event_type = hash.key?('eventType') ? hash['eventType'] : nil # Create object from extracted values. TrackingCurrentEvent.new(event_type: event_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['event_type'] = 'eventType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} event_type: #{@event_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/usps_api/models/tracking_current_event.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} event_type: #{@event_type}>" end |