Class: UspsApi::TrackingNumber

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/tracking_number.rb

Overview

TrackingNumber Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tracking_number: SKIP, piece_id: SKIP, additional_properties: nil) ⇒ TrackingNumber

Returns a new instance of TrackingNumber.



44
45
46
47
48
49
50
51
52
# File 'lib/usps_api/models/tracking_number.rb', line 44

def initialize(tracking_number: SKIP, piece_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tracking_number = tracking_number unless tracking_number == SKIP
  @piece_id = piece_id unless piece_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#piece_idInteger

The unique pieceID of the tracking number for the campaign. This pieceID will be unique if a tracking number is added to multiple campaigns. The pieceID will be non-null if the tracking number was successfully added to the package campaign.

Returns:

  • (Integer)


21
22
23
# File 'lib/usps_api/models/tracking_number.rb', line 21

def piece_id
  @piece_id
end

#tracking_numberString

The tracking number successfully added to the campaign.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/tracking_number.rb', line 14

def tracking_number
  @tracking_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/usps_api/models/tracking_number.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tracking_number =
    hash.key?('trackingNumber') ? hash['trackingNumber'] : SKIP
  piece_id = hash.key?('pieceID') ? hash['pieceID'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TrackingNumber.new(tracking_number: tracking_number,
                     piece_id: piece_id,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/usps_api/models/tracking_number.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tracking_number'] = 'trackingNumber'
  @_hash['piece_id'] = 'pieceID'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/usps_api/models/tracking_number.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/usps_api/models/tracking_number.rb', line 32

def self.optionals
  %w[
    tracking_number
    piece_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/usps_api/models/tracking_number.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_number: #{@tracking_number.inspect}, piece_id:"\
  " #{@piece_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/usps_api/models/tracking_number.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_number: #{@tracking_number}, piece_id: #{@piece_id},"\
  " additional_properties: #{@additional_properties}>"
end