Class: UspsApi::TrackingNumberRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/tracking_number_request.rb

Overview

TrackingNumberRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tracking_numbers: SKIP, additional_properties: nil) ⇒ TrackingNumberRequest

Returns a new instance of TrackingNumberRequest.



35
36
37
38
39
40
41
# File 'lib/usps_api/models/tracking_number_request.rb', line 35

def initialize(tracking_numbers: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tracking_numbers = tracking_numbers unless tracking_numbers == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#tracking_numbersString

A string containing tracking numbers to be added to the campaign.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/tracking_number_request.rb', line 14

def tracking_numbers
  @tracking_numbers
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/usps_api/models/tracking_number_request.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tracking_numbers =
    hash.key?('trackingNumbers') ? hash['trackingNumbers'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TrackingNumberRequest.new(tracking_numbers: tracking_numbers,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/usps_api/models/tracking_number_request.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tracking_numbers'] = 'trackingNumbers'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/usps_api/models/tracking_number_request.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/usps_api/models/tracking_number_request.rb', line 24

def self.optionals
  %w[
    tracking_numbers
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/usps_api/models/tracking_number_request.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_numbers: #{@tracking_numbers.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
68
# File 'lib/usps_api/models/tracking_number_request.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_numbers: #{@tracking_numbers}, additional_properties:"\
  " #{@additional_properties}>"
end