Class: UspsApi::UnusedLabelDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/unused_label_details.rb

Overview

UnusedLabelDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_type: SKIP, request_status: SKIP, crid: SKIP, record_type: SKIP, mid: SKIP, usage_indicator: SKIP, pic: SKIP, customer_reference_number: SKIP, efn: SKIP, date_of_mailing: SKIP, package_scan_date: SKIP, manifest_destination_zip_code: SKIP, scan_zip_code: SKIP, manifest_mail_class: SKIP, manifest_processing_category: SKIP, manifest_routing_bar_code: SKIP, manifest_weight: SKIP, manifest_rate_indicator: SKIP, unused_label_refund_amount: SKIP, extra_service_code1: SKIP, extra_service1_amount: SKIP, extra_service_code2: SKIP, extra_service2_amount: SKIP, extra_service_code3: SKIP, extra_service3_amount: SKIP, extra_service_code4: SKIP, extra_service4_amount: SKIP, extra_service_code5: SKIP, extra_service5_amount: SKIP, rejection_reason: SKIP, transaction_id: SKIP, ach_withdrawal_id: SKIP, mr_dispute_id: SKIP, additional_properties: nil) ⇒ UnusedLabelDetails

Returns a new instance of UnusedLabelDetails.



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/usps_api/models/unused_label_details.rb', line 228

def initialize(request_type: SKIP, request_status: SKIP, crid: SKIP,
               record_type: SKIP, mid: SKIP, usage_indicator: SKIP,
               pic: SKIP, customer_reference_number: SKIP, efn: SKIP,
               date_of_mailing: SKIP, package_scan_date: SKIP,
               manifest_destination_zip_code: SKIP, scan_zip_code: SKIP,
               manifest_mail_class: SKIP,
               manifest_processing_category: SKIP,
               manifest_routing_bar_code: SKIP, manifest_weight: SKIP,
               manifest_rate_indicator: SKIP,
               unused_label_refund_amount: SKIP, extra_service_code1: SKIP,
               extra_service1_amount: SKIP, extra_service_code2: SKIP,
               extra_service2_amount: SKIP, extra_service_code3: SKIP,
               extra_service3_amount: SKIP, extra_service_code4: SKIP,
               extra_service4_amount: SKIP, extra_service_code5: SKIP,
               extra_service5_amount: SKIP, rejection_reason: SKIP,
               transaction_id: SKIP, ach_withdrawal_id: SKIP,
               mr_dispute_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_type = request_type unless request_type == SKIP
  @request_status = request_status unless request_status == SKIP
  @crid = crid unless crid == SKIP
  @record_type = record_type unless record_type == SKIP
  @mid = mid unless mid == SKIP
  @usage_indicator = usage_indicator unless usage_indicator == SKIP
  @pic = pic unless pic == SKIP
  unless customer_reference_number == SKIP
    @customer_reference_number =
      customer_reference_number
  end
  @efn = efn unless efn == SKIP
  @date_of_mailing = date_of_mailing unless date_of_mailing == SKIP
  @package_scan_date = package_scan_date unless package_scan_date == SKIP
  unless manifest_destination_zip_code == SKIP
    @manifest_destination_zip_code =
      manifest_destination_zip_code
  end
  @scan_zip_code = scan_zip_code unless scan_zip_code == SKIP
  @manifest_mail_class = manifest_mail_class unless manifest_mail_class == SKIP
  unless manifest_processing_category == SKIP
    @manifest_processing_category =
      manifest_processing_category
  end
  unless manifest_routing_bar_code == SKIP
    @manifest_routing_bar_code =
      manifest_routing_bar_code
  end
  @manifest_weight = manifest_weight unless manifest_weight == SKIP
  @manifest_rate_indicator = manifest_rate_indicator unless manifest_rate_indicator == SKIP
  unless unused_label_refund_amount == SKIP
    @unused_label_refund_amount =
      unused_label_refund_amount
  end
  @extra_service_code1 = extra_service_code1 unless extra_service_code1 == SKIP
  @extra_service1_amount = extra_service1_amount unless extra_service1_amount == SKIP
  @extra_service_code2 = extra_service_code2 unless extra_service_code2 == SKIP
  @extra_service2_amount = extra_service2_amount unless extra_service2_amount == SKIP
  @extra_service_code3 = extra_service_code3 unless extra_service_code3 == SKIP
  @extra_service3_amount = extra_service3_amount unless extra_service3_amount == SKIP
  @extra_service_code4 = extra_service_code4 unless extra_service_code4 == SKIP
  @extra_service4_amount = extra_service4_amount unless extra_service4_amount == SKIP
  @extra_service_code5 = extra_service_code5 unless extra_service_code5 == SKIP
  @extra_service5_amount = extra_service5_amount unless extra_service5_amount == SKIP
  @rejection_reason = rejection_reason unless rejection_reason == SKIP
  @transaction_id = transaction_id unless transaction_id == SKIP
  @ach_withdrawal_id = ach_withdrawal_id unless ach_withdrawal_id == SKIP
  @mr_dispute_id = mr_dispute_id unless mr_dispute_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#ach_withdrawal_idFloat

ACH Withdrawal ID

Returns:

  • (Float)


139
140
141
# File 'lib/usps_api/models/unused_label_details.rb', line 139

def ach_withdrawal_id
  @ach_withdrawal_id
end

#cridFloat

Customer Registration ID.

Returns:

  • (Float)


23
24
25
# File 'lib/usps_api/models/unused_label_details.rb', line 23

def crid
  @crid
end

#customer_reference_numberString

Customer Reference Number.

Returns:

  • (String)


43
44
45
# File 'lib/usps_api/models/unused_label_details.rb', line 43

def customer_reference_number
  @customer_reference_number
end

#date_of_mailingDateTime

Date of Mailing.

Returns:

  • (DateTime)


51
52
53
# File 'lib/usps_api/models/unused_label_details.rb', line 51

def date_of_mailing
  @date_of_mailing
end

#efnString

Electronic File Number (EFN).

Returns:

  • (String)


47
48
49
# File 'lib/usps_api/models/unused_label_details.rb', line 47

def efn
  @efn
end

#extra_service1_amountFloat

Extra Service1 Amount

Returns:

  • (Float)


95
96
97
# File 'lib/usps_api/models/unused_label_details.rb', line 95

def extra_service1_amount
  @extra_service1_amount
end

#extra_service2_amountFloat

Extra Service2 Amount

Returns:

  • (Float)


103
104
105
# File 'lib/usps_api/models/unused_label_details.rb', line 103

def extra_service2_amount
  @extra_service2_amount
end

#extra_service3_amountFloat

Extra Service3 Amount

Returns:

  • (Float)


111
112
113
# File 'lib/usps_api/models/unused_label_details.rb', line 111

def extra_service3_amount
  @extra_service3_amount
end

#extra_service4_amountFloat

Extra Service4 Amount

Returns:

  • (Float)


119
120
121
# File 'lib/usps_api/models/unused_label_details.rb', line 119

def extra_service4_amount
  @extra_service4_amount
end

#extra_service5_amountFloat

Extra Service5 Amount

Returns:

  • (Float)


127
128
129
# File 'lib/usps_api/models/unused_label_details.rb', line 127

def extra_service5_amount
  @extra_service5_amount
end

#extra_service_code1String

Extra Service Code – 1st Service.

Returns:

  • (String)


91
92
93
# File 'lib/usps_api/models/unused_label_details.rb', line 91

def extra_service_code1
  @extra_service_code1
end

#extra_service_code2String

Extra Service Code – 2nd Service.

Returns:

  • (String)


99
100
101
# File 'lib/usps_api/models/unused_label_details.rb', line 99

def extra_service_code2
  @extra_service_code2
end

#extra_service_code3String

Extra Service Code – 3rd Service.

Returns:

  • (String)


107
108
109
# File 'lib/usps_api/models/unused_label_details.rb', line 107

def extra_service_code3
  @extra_service_code3
end

#extra_service_code4String

Extra Service Code – 4th Service.

Returns:

  • (String)


115
116
117
# File 'lib/usps_api/models/unused_label_details.rb', line 115

def extra_service_code4
  @extra_service_code4
end

#extra_service_code5String

Extra Service Code – 5th Service.

Returns:

  • (String)


123
124
125
# File 'lib/usps_api/models/unused_label_details.rb', line 123

def extra_service_code5
  @extra_service_code5
end

#manifest_destination_zip_codeFloat

Manifest Destination ZIP Code.

Returns:

  • (Float)


59
60
61
# File 'lib/usps_api/models/unused_label_details.rb', line 59

def manifest_destination_zip_code
  @manifest_destination_zip_code
end

#manifest_mail_classString

Manifest Mail Class.

Returns:

  • (String)


67
68
69
# File 'lib/usps_api/models/unused_label_details.rb', line 67

def manifest_mail_class
  @manifest_mail_class
end

#manifest_processing_categoryString

Manifest Processing Category.

Returns:

  • (String)


71
72
73
# File 'lib/usps_api/models/unused_label_details.rb', line 71

def manifest_processing_category
  @manifest_processing_category
end

#manifest_rate_indicatorString

Manifest Rate Indicator.

Returns:

  • (String)


83
84
85
# File 'lib/usps_api/models/unused_label_details.rb', line 83

def manifest_rate_indicator
  @manifest_rate_indicator
end

#manifest_routing_bar_codeString

Manifest Routing Bar Code.

Returns:

  • (String)


75
76
77
# File 'lib/usps_api/models/unused_label_details.rb', line 75

def manifest_routing_bar_code
  @manifest_routing_bar_code
end

#manifest_weightFloat

Manifest Weight.

Returns:

  • (Float)


79
80
81
# File 'lib/usps_api/models/unused_label_details.rb', line 79

def manifest_weight
  @manifest_weight
end

#midFloat

Mailer ID (MID).

Returns:

  • (Float)


31
32
33
# File 'lib/usps_api/models/unused_label_details.rb', line 31

def mid
  @mid
end

#mr_dispute_idString

Mailer Review Dispute ID

Returns:

  • (String)


143
144
145
# File 'lib/usps_api/models/unused_label_details.rb', line 143

def mr_dispute_id
  @mr_dispute_id
end

#package_scan_dateDateTime

Package Scan Date.

Returns:

  • (DateTime)


55
56
57
# File 'lib/usps_api/models/unused_label_details.rb', line 55

def package_scan_date
  @package_scan_date
end

#picString

Package Identification Code (PIC).

Returns:

  • (String)


39
40
41
# File 'lib/usps_api/models/unused_label_details.rb', line 39

def pic
  @pic
end

#record_typeString

Record Type- D1 for manifest detail record.

Returns:

  • (String)


27
28
29
# File 'lib/usps_api/models/unused_label_details.rb', line 27

def record_type
  @record_type
end

#rejection_reasonString

Reject Reason

Returns:

  • (String)


131
132
133
# File 'lib/usps_api/models/unused_label_details.rb', line 131

def rejection_reason
  @rejection_reason
end

#request_statusRequestStatus1

Current status of the Request.

Returns:



19
20
21
# File 'lib/usps_api/models/unused_label_details.rb', line 19

def request_status
  @request_status
end

#request_typeRequestType2

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/usps_api/models/unused_label_details.rb', line 15

def request_type
  @request_type
end

#scan_zip_codeFloat

Scan ZIP Code.

Returns:

  • (Float)


63
64
65
# File 'lib/usps_api/models/unused_label_details.rb', line 63

def scan_zip_code
  @scan_zip_code
end

#transaction_idFloat

Enterprise Payment System (EPS) Transaction ID.

Returns:

  • (Float)


135
136
137
# File 'lib/usps_api/models/unused_label_details.rb', line 135

def transaction_id
  @transaction_id
end

#unused_label_refund_amountFloat

Unused label refund amount

Returns:

  • (Float)


87
88
89
# File 'lib/usps_api/models/unused_label_details.rb', line 87

def unused_label_refund_amount
  @unused_label_refund_amount
end

#usage_indicatorString

UL - Unused Labels.

Returns:

  • (String)


35
36
37
# File 'lib/usps_api/models/unused_label_details.rb', line 35

def usage_indicator
  @usage_indicator
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/usps_api/models/unused_label_details.rb', line 300

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_type = hash.key?('requestType') ? hash['requestType'] : SKIP
  request_status = hash.key?('requestStatus') ? hash['requestStatus'] : SKIP
  crid = hash.key?('CRID') ? hash['CRID'] : SKIP
  record_type = hash.key?('recordType') ? hash['recordType'] : SKIP
  mid = hash.key?('MID') ? hash['MID'] : SKIP
  usage_indicator =
    hash.key?('usageIndicator') ? hash['usageIndicator'] : SKIP
  pic = hash.key?('PIC') ? hash['PIC'] : SKIP
  customer_reference_number =
    hash.key?('customerReferenceNumber') ? hash['customerReferenceNumber'] : SKIP
  efn = hash.key?('EFN') ? hash['EFN'] : SKIP
  date_of_mailing = if hash.key?('dateOfMailing')
                      (DateTimeHelper.from_rfc3339(hash['dateOfMailing']) if hash['dateOfMailing'])
                    else
                      SKIP
                    end
  package_scan_date = if hash.key?('packageScanDate')
                        (DateTimeHelper.from_rfc3339(hash['packageScanDate']) if hash['packageScanDate'])
                      else
                        SKIP
                      end
  manifest_destination_zip_code =
    hash.key?('manifestDestinationZIPCode') ? hash['manifestDestinationZIPCode'] : SKIP
  scan_zip_code = hash.key?('scanZIPCode') ? hash['scanZIPCode'] : SKIP
  manifest_mail_class =
    hash.key?('manifestMailClass') ? hash['manifestMailClass'] : SKIP
  manifest_processing_category =
    hash.key?('manifestProcessingCategory') ? hash['manifestProcessingCategory'] : SKIP
  manifest_routing_bar_code =
    hash.key?('manifestRoutingBarCode') ? hash['manifestRoutingBarCode'] : SKIP
  manifest_weight =
    hash.key?('manifestWeight') ? hash['manifestWeight'] : SKIP
  manifest_rate_indicator =
    hash.key?('manifestRateIndicator') ? hash['manifestRateIndicator'] : SKIP
  unused_label_refund_amount =
    hash.key?('unusedLabelRefundAmount') ? hash['unusedLabelRefundAmount'] : SKIP
  extra_service_code1 =
    hash.key?('extraServiceCode1') ? hash['extraServiceCode1'] : SKIP
  extra_service1_amount =
    hash.key?('extraService1Amount') ? hash['extraService1Amount'] : SKIP
  extra_service_code2 =
    hash.key?('extraServiceCode2') ? hash['extraServiceCode2'] : SKIP
  extra_service2_amount =
    hash.key?('extraService2Amount') ? hash['extraService2Amount'] : SKIP
  extra_service_code3 =
    hash.key?('extraServiceCode3') ? hash['extraServiceCode3'] : SKIP
  extra_service3_amount =
    hash.key?('extraService3Amount') ? hash['extraService3Amount'] : SKIP
  extra_service_code4 =
    hash.key?('extraServiceCode4') ? hash['extraServiceCode4'] : SKIP
  extra_service4_amount =
    hash.key?('extraService4Amount') ? hash['extraService4Amount'] : SKIP
  extra_service_code5 =
    hash.key?('extraServiceCode5') ? hash['extraServiceCode5'] : SKIP
  extra_service5_amount =
    hash.key?('extraService5Amount') ? hash['extraService5Amount'] : SKIP
  rejection_reason =
    hash.key?('rejectionReason') ? hash['rejectionReason'] : SKIP
  transaction_id = hash.key?('transactionID') ? hash['transactionID'] : SKIP
  ach_withdrawal_id =
    hash.key?('ACHWithdrawalID') ? hash['ACHWithdrawalID'] : SKIP
  mr_dispute_id = hash.key?('MRDisputeID') ? hash['MRDisputeID'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UnusedLabelDetails.new(request_type: request_type,
                         request_status: request_status,
                         crid: crid,
                         record_type: record_type,
                         mid: mid,
                         usage_indicator: usage_indicator,
                         pic: pic,
                         customer_reference_number: customer_reference_number,
                         efn: efn,
                         date_of_mailing: date_of_mailing,
                         package_scan_date: package_scan_date,
                         manifest_destination_zip_code: manifest_destination_zip_code,
                         scan_zip_code: scan_zip_code,
                         manifest_mail_class: manifest_mail_class,
                         manifest_processing_category: manifest_processing_category,
                         manifest_routing_bar_code: manifest_routing_bar_code,
                         manifest_weight: manifest_weight,
                         manifest_rate_indicator: manifest_rate_indicator,
                         unused_label_refund_amount: unused_label_refund_amount,
                         extra_service_code1: extra_service_code1,
                         extra_service1_amount: extra_service1_amount,
                         extra_service_code2: extra_service_code2,
                         extra_service2_amount: extra_service2_amount,
                         extra_service_code3: extra_service_code3,
                         extra_service3_amount: extra_service3_amount,
                         extra_service_code4: extra_service_code4,
                         extra_service4_amount: extra_service4_amount,
                         extra_service_code5: extra_service_code5,
                         extra_service5_amount: extra_service5_amount,
                         rejection_reason: rejection_reason,
                         transaction_id: transaction_id,
                         ach_withdrawal_id: ach_withdrawal_id,
                         mr_dispute_id: mr_dispute_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/usps_api/models/unused_label_details.rb', line 146

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_type'] = 'requestType'
  @_hash['request_status'] = 'requestStatus'
  @_hash['crid'] = 'CRID'
  @_hash['record_type'] = 'recordType'
  @_hash['mid'] = 'MID'
  @_hash['usage_indicator'] = 'usageIndicator'
  @_hash['pic'] = 'PIC'
  @_hash['customer_reference_number'] = 'customerReferenceNumber'
  @_hash['efn'] = 'EFN'
  @_hash['date_of_mailing'] = 'dateOfMailing'
  @_hash['package_scan_date'] = 'packageScanDate'
  @_hash['manifest_destination_zip_code'] = 'manifestDestinationZIPCode'
  @_hash['scan_zip_code'] = 'scanZIPCode'
  @_hash['manifest_mail_class'] = 'manifestMailClass'
  @_hash['manifest_processing_category'] = 'manifestProcessingCategory'
  @_hash['manifest_routing_bar_code'] = 'manifestRoutingBarCode'
  @_hash['manifest_weight'] = 'manifestWeight'
  @_hash['manifest_rate_indicator'] = 'manifestRateIndicator'
  @_hash['unused_label_refund_amount'] = 'unusedLabelRefundAmount'
  @_hash['extra_service_code1'] = 'extraServiceCode1'
  @_hash['extra_service1_amount'] = 'extraService1Amount'
  @_hash['extra_service_code2'] = 'extraServiceCode2'
  @_hash['extra_service2_amount'] = 'extraService2Amount'
  @_hash['extra_service_code3'] = 'extraServiceCode3'
  @_hash['extra_service3_amount'] = 'extraService3Amount'
  @_hash['extra_service_code4'] = 'extraServiceCode4'
  @_hash['extra_service4_amount'] = 'extraService4Amount'
  @_hash['extra_service_code5'] = 'extraServiceCode5'
  @_hash['extra_service5_amount'] = 'extraService5Amount'
  @_hash['rejection_reason'] = 'rejectionReason'
  @_hash['transaction_id'] = 'transactionID'
  @_hash['ach_withdrawal_id'] = 'ACHWithdrawalID'
  @_hash['mr_dispute_id'] = 'MRDisputeID'
  @_hash
end

.nullablesObject

An array for nullable fields



224
225
226
# File 'lib/usps_api/models/unused_label_details.rb', line 224

def self.nullables
  []
end

.optionalsObject

An array for optional fields



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/usps_api/models/unused_label_details.rb', line 185

def self.optionals
  %w[
    request_type
    request_status
    crid
    record_type
    mid
    usage_indicator
    pic
    customer_reference_number
    efn
    date_of_mailing
    package_scan_date
    manifest_destination_zip_code
    scan_zip_code
    manifest_mail_class
    manifest_processing_category
    manifest_routing_bar_code
    manifest_weight
    manifest_rate_indicator
    unused_label_refund_amount
    extra_service_code1
    extra_service1_amount
    extra_service_code2
    extra_service2_amount
    extra_service_code3
    extra_service3_amount
    extra_service_code4
    extra_service4_amount
    extra_service_code5
    extra_service5_amount
    rejection_reason
    transaction_id
    ach_withdrawal_id
    mr_dispute_id
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



421
422
423
424
425
426
427
# File 'lib/usps_api/models/unused_label_details.rb', line 421

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/usps_api/models/unused_label_details.rb', line 454

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_type: #{@request_type.inspect}, request_status:"\
  " #{@request_status.inspect}, crid: #{@crid.inspect}, record_type: #{@record_type.inspect},"\
  " mid: #{@mid.inspect}, usage_indicator: #{@usage_indicator.inspect}, pic: #{@pic.inspect},"\
  " customer_reference_number: #{@customer_reference_number.inspect}, efn: #{@efn.inspect},"\
  " date_of_mailing: #{@date_of_mailing.inspect}, package_scan_date:"\
  " #{@package_scan_date.inspect}, manifest_destination_zip_code:"\
  " #{@manifest_destination_zip_code.inspect}, scan_zip_code: #{@scan_zip_code.inspect},"\
  " manifest_mail_class: #{@manifest_mail_class.inspect}, manifest_processing_category:"\
  " #{@manifest_processing_category.inspect}, manifest_routing_bar_code:"\
  " #{@manifest_routing_bar_code.inspect}, manifest_weight: #{@manifest_weight.inspect},"\
  " manifest_rate_indicator: #{@manifest_rate_indicator.inspect}, unused_label_refund_amount:"\
  " #{@unused_label_refund_amount.inspect}, extra_service_code1:"\
  " #{@extra_service_code1.inspect}, extra_service1_amount: #{@extra_service1_amount.inspect},"\
  " extra_service_code2: #{@extra_service_code2.inspect}, extra_service2_amount:"\
  " #{@extra_service2_amount.inspect}, extra_service_code3: #{@extra_service_code3.inspect},"\
  " extra_service3_amount: #{@extra_service3_amount.inspect}, extra_service_code4:"\
  " #{@extra_service_code4.inspect}, extra_service4_amount: #{@extra_service4_amount.inspect},"\
  " extra_service_code5: #{@extra_service_code5.inspect}, extra_service5_amount:"\
  " #{@extra_service5_amount.inspect}, rejection_reason: #{@rejection_reason.inspect},"\
  " transaction_id: #{@transaction_id.inspect}, ach_withdrawal_id:"\
  " #{@ach_withdrawal_id.inspect}, mr_dispute_id: #{@mr_dispute_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_date_of_mailingObject



411
412
413
# File 'lib/usps_api/models/unused_label_details.rb', line 411

def to_custom_date_of_mailing
  DateTimeHelper.to_rfc3339(date_of_mailing)
end

#to_custom_package_scan_dateObject



415
416
417
# File 'lib/usps_api/models/unused_label_details.rb', line 415

def to_custom_package_scan_date
  DateTimeHelper.to_rfc3339(package_scan_date)
end

#to_sObject

Provides a human-readable string representation of the object.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/usps_api/models/unused_label_details.rb', line 430

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_type: #{@request_type}, request_status: #{@request_status}, crid:"\
  " #{@crid}, record_type: #{@record_type}, mid: #{@mid}, usage_indicator:"\
  " #{@usage_indicator}, pic: #{@pic}, customer_reference_number:"\
  " #{@customer_reference_number}, efn: #{@efn}, date_of_mailing: #{@date_of_mailing},"\
  " package_scan_date: #{@package_scan_date}, manifest_destination_zip_code:"\
  " #{@manifest_destination_zip_code}, scan_zip_code: #{@scan_zip_code}, manifest_mail_class:"\
  " #{@manifest_mail_class}, manifest_processing_category: #{@manifest_processing_category},"\
  " manifest_routing_bar_code: #{@manifest_routing_bar_code}, manifest_weight:"\
  " #{@manifest_weight}, manifest_rate_indicator: #{@manifest_rate_indicator},"\
  " unused_label_refund_amount: #{@unused_label_refund_amount}, extra_service_code1:"\
  " #{@extra_service_code1}, extra_service1_amount: #{@extra_service1_amount},"\
  " extra_service_code2: #{@extra_service_code2}, extra_service2_amount:"\
  " #{@extra_service2_amount}, extra_service_code3: #{@extra_service_code3},"\
  " extra_service3_amount: #{@extra_service3_amount}, extra_service_code4:"\
  " #{@extra_service_code4}, extra_service4_amount: #{@extra_service4_amount},"\
  " extra_service_code5: #{@extra_service_code5}, extra_service5_amount:"\
  " #{@extra_service5_amount}, rejection_reason: #{@rejection_reason}, transaction_id:"\
  " #{@transaction_id}, ach_withdrawal_id: #{@ach_withdrawal_id}, mr_dispute_id:"\
  " #{@mr_dispute_id}, additional_properties: #{@additional_properties}>"
end