Class: UspsApi::V3CampaignsCallbackResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/v3_campaigns_callback_response.rb

Overview

V3CampaignsCallbackResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(callback_keys: SKIP, metadata: SKIP, additional_properties: nil) ⇒ V3CampaignsCallbackResponse

Returns a new instance of V3CampaignsCallbackResponse.



41
42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 41

def initialize(callback_keys: SKIP, metadata: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @callback_keys = callback_keys unless callback_keys == SKIP
  @metadata =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#callback_keysArray[CallbackKey]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 14

def callback_keys
  @callback_keys
end

#metadataMetadata

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 18

def 
  @metadata
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  callback_keys = nil
  unless hash['callbackKeys'].nil?
    callback_keys = []
    hash['callbackKeys'].each do |structure|
      callback_keys << (CallbackKey.from_hash(structure) if structure)
    end
  end

  callback_keys = SKIP unless hash.key?('callbackKeys')
   = Metadata.from_hash(hash['metadata']) if hash['metadata']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  V3CampaignsCallbackResponse.new(callback_keys: callback_keys,
                                  metadata: ,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['callback_keys'] = 'callbackKeys'
  @_hash['metadata'] = 'metadata'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 29

def self.optionals
  %w[
    callback_keys
    metadata
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} callback_keys: #{@callback_keys.inspect}, metadata: #{@metadata.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/usps_api/models/v3_campaigns_callback_response.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} callback_keys: #{@callback_keys}, metadata: #{@metadata},"\
  " additional_properties: #{@additional_properties}>"
end