Class: UspsApi::V3InternationalServiceStandardResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/v3_international_service_standard_response.rb

Overview

V3InternationalServiceStandardResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(country_code: SKIP, mail_class: SKIP, service_standard_message: SKIP, additional_properties: nil) ⇒ V3InternationalServiceStandardResponse

Returns a new instance of V3InternationalServiceStandardResponse.



49
50
51
52
53
54
55
56
57
58
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 49

def initialize(country_code: SKIP, mail_class: SKIP,
               service_standard_message: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @country_code = country_code unless country_code == SKIP
  @mail_class = mail_class unless mail_class == SKIP
  @service_standard_message = service_standard_message unless service_standard_message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#country_codeString

The ISO 2-char country code.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 14

def country_code
  @country_code
end

#mail_classString

The international mail class can be one of ‘FIRST-CLASS_PACKAGE_INTERNATIONAL_SERVICE`, `PRIORITY_MAIL_INTERNATIONAL`, and `PRIORITY_MAIL_EXPRESS_INTERNATIONAL`.

Returns:

  • (String)


20
21
22
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 20

def mail_class
  @mail_class
end

#service_standard_messageString

The service standard message explaining number of estimated delivery days.

Returns:

  • (String)


24
25
26
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 24

def service_standard_message
  @service_standard_message
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  country_code = hash.key?('countryCode') ? hash['countryCode'] : SKIP
  mail_class = hash.key?('mailClass') ? hash['mailClass'] : SKIP
  service_standard_message =
    hash.key?('serviceStandardMessage') ? hash['serviceStandardMessage'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  V3InternationalServiceStandardResponse.new(country_code: country_code,
                                             mail_class: mail_class,
                                             service_standard_message: service_standard_message,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['country_code'] = 'countryCode'
  @_hash['mail_class'] = 'mailClass'
  @_hash['service_standard_message'] = 'serviceStandardMessage'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 36

def self.optionals
  %w[
    country_code
    mail_class
    service_standard_message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} country_code: #{@country_code.inspect}, mail_class: #{@mail_class.inspect},"\
  " service_standard_message: #{@service_standard_message.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
90
# File 'lib/usps_api/models/v3_international_service_standard_response.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} country_code: #{@country_code}, mail_class: #{@mail_class},"\
  " service_standard_message: #{@service_standard_message}, additional_properties:"\
  " #{@additional_properties}>"
end