Class: UspsApi::V3PostOfficeLocationsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/v3_post_office_locations_response.rb

Overview

V3PostOfficeLocationsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(locations: SKIP, warnings: SKIP, metadata: SKIP, additional_properties: nil) ⇒ V3PostOfficeLocationsResponse

Returns a new instance of V3PostOfficeLocationsResponse.



49
50
51
52
53
54
55
56
57
58
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 49

def initialize(locations: SKIP, warnings: SKIP, metadata: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @locations = locations unless locations == SKIP
  @warnings = warnings unless warnings == SKIP
  @metadata =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#locationsArray[PostOfficeLocation]

A list of Post Office locations that match the search criteria, sorted by distance (closest first).

Returns:



15
16
17
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 15

def locations
  @locations
end

#metadataLocationsPaginationMetadata

Standard error message response.



24
25
26
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 24

def 
  @metadata
end

#warningsArray[ContainersContainerWarnings]

A list of Post Office locations that match the search criteria, sorted by distance (closest first).

Returns:



20
21
22
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 20

def warnings
  @warnings
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  locations = nil
  unless hash['locations'].nil?
    locations = []
    hash['locations'].each do |structure|
      locations << (PostOfficeLocation.from_hash(structure) if structure)
    end
  end

  locations = SKIP unless hash.key?('locations')
  # Parameter is an array, so we need to iterate through it
  warnings = nil
  unless hash['warnings'].nil?
    warnings = []
    hash['warnings'].each do |structure|
      warnings << (ContainersContainerWarnings.from_hash(structure) if structure)
    end
  end

  warnings = SKIP unless hash.key?('warnings')
   = LocationsPaginationMetadata.from_hash(hash['metadata']) if hash['metadata']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  V3PostOfficeLocationsResponse.new(locations: locations,
                                    warnings: warnings,
                                    metadata: ,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['locations'] = 'locations'
  @_hash['warnings'] = 'warnings'
  @_hash['metadata'] = 'metadata'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 36

def self.optionals
  %w[
    locations
    warnings
    metadata
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} locations: #{@locations.inspect}, warnings: #{@warnings.inspect}, metadata:"\
  " #{@metadata.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



102
103
104
105
106
# File 'lib/usps_api/models/v3_post_office_locations_response.rb', line 102

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} locations: #{@locations}, warnings: #{@warnings}, metadata: #{@metadata},"\
  " additional_properties: #{@additional_properties}>"
end