Class: UspsApi::V3SubscriptionsResponse3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::V3SubscriptionsResponse3
- Defined in:
- lib/usps_api/models/v3_subscriptions_response3.rb
Overview
V3SubscriptionsResponse3 Model.
Instance Attribute Summary collapse
-
#metadata ⇒ SubscriptionsTrackingPaginationMetadata
List of subscriptions.
-
#subscriptions ⇒ Array[SubscriptionsTrackingSubscription]
List of subscriptions.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(subscriptions: SKIP, metadata: SKIP) ⇒ V3SubscriptionsResponse3
constructor
A new instance of V3SubscriptionsResponse3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(subscriptions: SKIP, metadata: SKIP) ⇒ V3SubscriptionsResponse3
Returns a new instance of V3SubscriptionsResponse3.
41 42 43 44 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 41 def initialize(subscriptions: SKIP, metadata: SKIP) @subscriptions = subscriptions unless subscriptions == SKIP @metadata = unless == SKIP end |
Instance Attribute Details
#metadata ⇒ SubscriptionsTrackingPaginationMetadata
List of subscriptions.
18 19 20 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 18 def @metadata end |
#subscriptions ⇒ Array[SubscriptionsTrackingSubscription]
List of subscriptions.
14 15 16 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 14 def subscriptions @subscriptions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it subscriptions = nil unless hash['subscriptions'].nil? subscriptions = [] hash['subscriptions'].each do |structure| subscriptions << (SubscriptionsTrackingSubscription.from_hash(structure) if structure) end end subscriptions = SKIP unless hash.key?('subscriptions') = SubscriptionsTrackingPaginationMetadata.from_hash(hash['metadata']) if hash['metadata'] # Create object from extracted values. V3SubscriptionsResponse3.new(subscriptions: subscriptions, metadata: ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['subscriptions'] = 'subscriptions' @_hash['metadata'] = 'metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 29 def self.optionals %w[ subscriptions metadata ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} subscriptions: #{@subscriptions.inspect}, metadata: #{@metadata.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/usps_api/models/v3_subscriptions_response3.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} subscriptions: #{@subscriptions}, metadata: #{@metadata}>" end |