Class: UspsApi::Zip5CodesResponse
- Defined in:
- lib/usps_api/models/zip5_codes_response.rb
Overview
Zip5CodesResponse Model.
Instance Attribute Summary collapse
-
#destination_zip_codes ⇒ Array[String]
destination ZIPCodes.
-
#origin_zip_codes ⇒ Array[String]
origin ZIPCodes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(origin_zip_codes: SKIP, destination_zip_codes: SKIP, additional_properties: nil) ⇒ Zip5CodesResponse
constructor
A new instance of Zip5CodesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(origin_zip_codes: SKIP, destination_zip_codes: SKIP, additional_properties: nil) ⇒ Zip5CodesResponse
Returns a new instance of Zip5CodesResponse.
41 42 43 44 45 46 47 48 49 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 41 def initialize(origin_zip_codes: SKIP, destination_zip_codes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @origin_zip_codes = origin_zip_codes unless origin_zip_codes == SKIP @destination_zip_codes = destination_zip_codes unless destination_zip_codes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#destination_zip_codes ⇒ Array[String]
destination ZIPCodes
18 19 20 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 18 def destination_zip_codes @destination_zip_codes end |
#origin_zip_codes ⇒ Array[String]
origin ZIPCodes
14 15 16 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 14 def origin_zip_codes @origin_zip_codes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. origin_zip_codes = hash.key?('originZIPCodes') ? hash['originZIPCodes'] : SKIP destination_zip_codes = hash.key?('destinationZIPCodes') ? hash['destinationZIPCodes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Zip5CodesResponse.new(origin_zip_codes: origin_zip_codes, destination_zip_codes: destination_zip_codes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['origin_zip_codes'] = 'originZIPCodes' @_hash['destination_zip_codes'] = 'destinationZIPCodes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 29 def self.optionals %w[ origin_zip_codes destination_zip_codes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} origin_zip_codes: #{@origin_zip_codes.inspect}, destination_zip_codes:"\ " #{@destination_zip_codes.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/usps_api/models/zip5_codes_response.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} origin_zip_codes: #{@origin_zip_codes}, destination_zip_codes:"\ " #{@destination_zip_codes}, additional_properties: #{@additional_properties}>" end |