Class: UspsApi::AddressInformation
- Defined in:
- lib/usps_api/models/address_information.rb
Overview
The Address Information of the request user.
Instance Attribute Summary collapse
-
#address ⇒ NcoaDataServicesDomesticAddress
Contains the address.
-
#carrier_route ⇒ String
Carrier Route ID.
-
#dpv_business ⇒ String
Address is a business (Y/N).
-
#dpv_central_box_delivery ⇒ String
Address is Central Box type of delivery (Y/N).
-
#dpv_confirmation ⇒ String
Delivery Point Verification (DPV®) Return Code confirmation for address (Y/S/D/N).
-
#dpv_curb_delivery ⇒ String
Address is Curb type of delivery (Y/N).
-
#dpv_delivery_type ⇒ String
Address Delivery Type of 1 - 4.
-
#dpv_drop ⇒ String
Address is a drop - mail is dropped by USPS for further distribution (Y/N).
-
#dpv_drop_count ⇒ String
Drop Count - number of customers serviced where mail is dropped by USPS (001-999).
-
#dpv_educational ⇒ String
Address is an Educational location (Y/N).
-
#dpv_enhanced_confirmation ⇒ String
Enhanced DPV Confirmation Code - Indicates whether all the information needed to deliver to this address is present.
-
#dpv_footnotes ⇒ String
DPV Footnotes.
-
#dpv_no_door_delivery ⇒ String
No door delivery flag - for situations where door is not accessible (Y/N).
-
#dpv_no_secure_location ⇒ String
No secure Location flag - address has been flagged as such.
-
#dpv_no_stat ⇒ String
Nostat Flag - Not counted for statistical purposes (Y/N).
-
#dpv_no_stat_reason_code ⇒ String
Nostat reason code - 01-06 reasons that a delivery point is not counted for statistical purposes.
-
#dpv_non_delivery_days_flag ⇒ String
Non-delivery days flag - If ‘Y’ there are day(s) that mail is not delivered.
-
#dpv_non_delivery_days_values ⇒ String
Non-delivery days values - comma-delimited days that mail is not delivered.
-
#dpv_other_delivery ⇒ String
Address is Other type of delivery (Y/N).
-
#dpv_seasonal ⇒ String
Address is seasonal - aka snowbird (Y/N).
-
#dpv_throwback ⇒ String
Throwback Flag - mail is delivered to a PO Box instead of this address (Y/N).
-
#dpv_vacant ⇒ String
Address is vacant (Y/N).
-
#dpvcmra ⇒ String
Address is a Commercial Mail Receiving Agency (CMRA) (Y/N).
-
#dpvlacs ⇒ String
Address is an old side LACS address (Y/N).
-
#dpvndcbu_delivery ⇒ String
Address is NDCBU type of delivery (Y/N).
-
#dpvpbsa ⇒ String
Indicates a PO Box Street Address (Y/N).
-
#footnotes ⇒ String
The Address Matching Engine (AME) footnotes.
-
#foreign1 ⇒ String
International Freeform addresses - only valid for new addresses.
-
#foreign2 ⇒ String
International Freeform addresses - only valid for new addresses.
-
#foreign3 ⇒ String
International Freeform addresses - only valid for new addresses.
-
#lacs_link_indicator ⇒ String
LACSLink Indicator - Y/N flag to indicate whether a match is made in LACSLink®.
-
#lacs_link_return_code ⇒ String
LACSLink Return Code - Flag to indicate if we matched in LACSLink.
-
#record_type ⇒ String
Record Type.
-
#return_code ⇒ String
Address Matching Engine (AME) Return Code.
-
#suite_link_indicator ⇒ String
SuiteLink Indicator - Flag to indicate if we matched in SuiteLink.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(return_code:, address:, footnotes: SKIP, carrier_route: SKIP, record_type: SKIP, dpv_confirmation: SKIP, dpv_business: SKIP, dpvcmra: SKIP, dpv_drop: SKIP, dpv_educational: SKIP, dpv_drop_count: SKIP, dpvlacs: SKIP, dpv_no_door_delivery: SKIP, dpv_no_stat_reason_code: SKIP, dpv_seasonal: SKIP, dpv_throwback: SKIP, dpv_no_secure_location: SKIP, dpv_vacant: SKIP, dpv_no_stat: SKIP, dpv_non_delivery_days_flag: SKIP, dpv_non_delivery_days_values: SKIP, dpv_curb_delivery: SKIP, dpvndcbu_delivery: SKIP, dpv_central_box_delivery: SKIP, dpv_other_delivery: SKIP, dpv_delivery_type: SKIP, dpv_enhanced_confirmation: SKIP, dpv_footnotes: SKIP, dpvpbsa: SKIP, foreign1: SKIP, foreign2: SKIP, foreign3: SKIP, suite_link_indicator: SKIP, lacs_link_indicator: SKIP, lacs_link_return_code: SKIP, additional_properties: nil) ⇒ AddressInformation
constructor
A new instance of AddressInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(return_code:, address:, footnotes: SKIP, carrier_route: SKIP, record_type: SKIP, dpv_confirmation: SKIP, dpv_business: SKIP, dpvcmra: SKIP, dpv_drop: SKIP, dpv_educational: SKIP, dpv_drop_count: SKIP, dpvlacs: SKIP, dpv_no_door_delivery: SKIP, dpv_no_stat_reason_code: SKIP, dpv_seasonal: SKIP, dpv_throwback: SKIP, dpv_no_secure_location: SKIP, dpv_vacant: SKIP, dpv_no_stat: SKIP, dpv_non_delivery_days_flag: SKIP, dpv_non_delivery_days_values: SKIP, dpv_curb_delivery: SKIP, dpvndcbu_delivery: SKIP, dpv_central_box_delivery: SKIP, dpv_other_delivery: SKIP, dpv_delivery_type: SKIP, dpv_enhanced_confirmation: SKIP, dpv_footnotes: SKIP, dpvpbsa: SKIP, foreign1: SKIP, foreign2: SKIP, foreign3: SKIP, suite_link_indicator: SKIP, lacs_link_indicator: SKIP, lacs_link_return_code: SKIP, additional_properties: nil) ⇒ AddressInformation
Returns a new instance of AddressInformation.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/usps_api/models/address_information.rb', line 280 def initialize(return_code:, address:, footnotes: SKIP, carrier_route: SKIP, record_type: SKIP, dpv_confirmation: SKIP, dpv_business: SKIP, dpvcmra: SKIP, dpv_drop: SKIP, dpv_educational: SKIP, dpv_drop_count: SKIP, dpvlacs: SKIP, dpv_no_door_delivery: SKIP, dpv_no_stat_reason_code: SKIP, dpv_seasonal: SKIP, dpv_throwback: SKIP, dpv_no_secure_location: SKIP, dpv_vacant: SKIP, dpv_no_stat: SKIP, dpv_non_delivery_days_flag: SKIP, dpv_non_delivery_days_values: SKIP, dpv_curb_delivery: SKIP, dpvndcbu_delivery: SKIP, dpv_central_box_delivery: SKIP, dpv_other_delivery: SKIP, dpv_delivery_type: SKIP, dpv_enhanced_confirmation: SKIP, dpv_footnotes: SKIP, dpvpbsa: SKIP, foreign1: SKIP, foreign2: SKIP, foreign3: SKIP, suite_link_indicator: SKIP, lacs_link_indicator: SKIP, lacs_link_return_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @return_code = return_code @footnotes = footnotes unless footnotes == SKIP @address = address @carrier_route = carrier_route unless carrier_route == SKIP @record_type = record_type unless record_type == SKIP @dpv_confirmation = dpv_confirmation unless dpv_confirmation == SKIP @dpv_business = dpv_business unless dpv_business == SKIP @dpvcmra = dpvcmra unless dpvcmra == SKIP @dpv_drop = dpv_drop unless dpv_drop == SKIP @dpv_educational = dpv_educational unless dpv_educational == SKIP @dpv_drop_count = dpv_drop_count unless dpv_drop_count == SKIP @dpvlacs = dpvlacs unless dpvlacs == SKIP @dpv_no_door_delivery = dpv_no_door_delivery unless dpv_no_door_delivery == SKIP @dpv_no_stat_reason_code = dpv_no_stat_reason_code unless dpv_no_stat_reason_code == SKIP @dpv_seasonal = dpv_seasonal unless dpv_seasonal == SKIP @dpv_throwback = dpv_throwback unless dpv_throwback == SKIP @dpv_no_secure_location = dpv_no_secure_location unless dpv_no_secure_location == SKIP @dpv_vacant = dpv_vacant unless dpv_vacant == SKIP @dpv_no_stat = dpv_no_stat unless dpv_no_stat == SKIP unless dpv_non_delivery_days_flag == SKIP @dpv_non_delivery_days_flag = dpv_non_delivery_days_flag end unless dpv_non_delivery_days_values == SKIP @dpv_non_delivery_days_values = dpv_non_delivery_days_values end @dpv_curb_delivery = dpv_curb_delivery unless dpv_curb_delivery == SKIP @dpvndcbu_delivery = dpvndcbu_delivery unless dpvndcbu_delivery == SKIP @dpv_central_box_delivery = dpv_central_box_delivery unless dpv_central_box_delivery == SKIP @dpv_other_delivery = dpv_other_delivery unless dpv_other_delivery == SKIP @dpv_delivery_type = dpv_delivery_type unless dpv_delivery_type == SKIP unless dpv_enhanced_confirmation == SKIP @dpv_enhanced_confirmation = dpv_enhanced_confirmation end @dpv_footnotes = dpv_footnotes unless dpv_footnotes == SKIP @dpvpbsa = dpvpbsa unless dpvpbsa == SKIP @foreign1 = foreign1 unless foreign1 == SKIP @foreign2 = foreign2 unless foreign2 == SKIP @foreign3 = foreign3 unless foreign3 == SKIP @suite_link_indicator = suite_link_indicator unless suite_link_indicator == SKIP @lacs_link_indicator = lacs_link_indicator unless lacs_link_indicator == SKIP @lacs_link_return_code = lacs_link_return_code unless lacs_link_return_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ NcoaDataServicesDomesticAddress
Contains the address
22 23 24 |
# File 'lib/usps_api/models/address_information.rb', line 22 def address @address end |
#carrier_route ⇒ String
Carrier Route ID
26 27 28 |
# File 'lib/usps_api/models/address_information.rb', line 26 def carrier_route @carrier_route end |
#dpv_business ⇒ String
Address is a business (Y/N)
39 40 41 |
# File 'lib/usps_api/models/address_information.rb', line 39 def dpv_business @dpv_business end |
#dpv_central_box_delivery ⇒ String
Address is Central Box type of delivery (Y/N)
112 113 114 |
# File 'lib/usps_api/models/address_information.rb', line 112 def dpv_central_box_delivery @dpv_central_box_delivery end |
#dpv_confirmation ⇒ String
Delivery Point Verification (DPV®) Return Code confirmation for address (Y/S/D/N)
35 36 37 |
# File 'lib/usps_api/models/address_information.rb', line 35 def dpv_confirmation @dpv_confirmation end |
#dpv_curb_delivery ⇒ String
Address is Curb type of delivery (Y/N)
104 105 106 |
# File 'lib/usps_api/models/address_information.rb', line 104 def dpv_curb_delivery @dpv_curb_delivery end |
#dpv_delivery_type ⇒ String
Address Delivery Type of 1 - 4
120 121 122 |
# File 'lib/usps_api/models/address_information.rb', line 120 def dpv_delivery_type @dpv_delivery_type end |
#dpv_drop ⇒ String
Address is a drop - mail is dropped by USPS for further distribution (Y/N)
47 48 49 |
# File 'lib/usps_api/models/address_information.rb', line 47 def dpv_drop @dpv_drop end |
#dpv_drop_count ⇒ String
Drop Count - number of customers serviced where mail is dropped by USPS (001-999)
56 57 58 |
# File 'lib/usps_api/models/address_information.rb', line 56 def dpv_drop_count @dpv_drop_count end |
#dpv_educational ⇒ String
Address is an Educational location (Y/N)
51 52 53 |
# File 'lib/usps_api/models/address_information.rb', line 51 def dpv_educational @dpv_educational end |
#dpv_enhanced_confirmation ⇒ String
Enhanced DPV Confirmation Code - Indicates whether all the information needed to deliver to this address is present.
125 126 127 |
# File 'lib/usps_api/models/address_information.rb', line 125 def dpv_enhanced_confirmation @dpv_enhanced_confirmation end |
#dpv_footnotes ⇒ String
DPV Footnotes
129 130 131 |
# File 'lib/usps_api/models/address_information.rb', line 129 def dpv_footnotes @dpv_footnotes end |
#dpv_no_door_delivery ⇒ String
No door delivery flag - for situations where door is not accessible (Y/N)
64 65 66 |
# File 'lib/usps_api/models/address_information.rb', line 64 def dpv_no_door_delivery @dpv_no_door_delivery end |
#dpv_no_secure_location ⇒ String
No secure Location flag - address has been flagged as such
82 83 84 |
# File 'lib/usps_api/models/address_information.rb', line 82 def dpv_no_secure_location @dpv_no_secure_location end |
#dpv_no_stat ⇒ String
Nostat Flag - Not counted for statistical purposes (Y/N)
90 91 92 |
# File 'lib/usps_api/models/address_information.rb', line 90 def dpv_no_stat @dpv_no_stat end |
#dpv_no_stat_reason_code ⇒ String
Nostat reason code - 01-06 reasons that a delivery point is not counted for statistical purposes
69 70 71 |
# File 'lib/usps_api/models/address_information.rb', line 69 def dpv_no_stat_reason_code @dpv_no_stat_reason_code end |
#dpv_non_delivery_days_flag ⇒ String
Non-delivery days flag - If ‘Y’ there are day(s) that mail is not delivered.
95 96 97 |
# File 'lib/usps_api/models/address_information.rb', line 95 def dpv_non_delivery_days_flag @dpv_non_delivery_days_flag end |
#dpv_non_delivery_days_values ⇒ String
Non-delivery days values - comma-delimited days that mail is not delivered.
100 101 102 |
# File 'lib/usps_api/models/address_information.rb', line 100 def dpv_non_delivery_days_values @dpv_non_delivery_days_values end |
#dpv_other_delivery ⇒ String
Address is Other type of delivery (Y/N)
116 117 118 |
# File 'lib/usps_api/models/address_information.rb', line 116 def dpv_other_delivery @dpv_other_delivery end |
#dpv_seasonal ⇒ String
Address is seasonal - aka snowbird (Y/N)
73 74 75 |
# File 'lib/usps_api/models/address_information.rb', line 73 def dpv_seasonal @dpv_seasonal end |
#dpv_throwback ⇒ String
Throwback Flag - mail is delivered to a PO Box instead of this address (Y/N)
78 79 80 |
# File 'lib/usps_api/models/address_information.rb', line 78 def dpv_throwback @dpv_throwback end |
#dpv_vacant ⇒ String
Address is vacant (Y/N)
86 87 88 |
# File 'lib/usps_api/models/address_information.rb', line 86 def dpv_vacant @dpv_vacant end |
#dpvcmra ⇒ String
Address is a Commercial Mail Receiving Agency (CMRA) (Y/N)
43 44 45 |
# File 'lib/usps_api/models/address_information.rb', line 43 def dpvcmra @dpvcmra end |
#dpvlacs ⇒ String
Address is an old side LACS address (Y/N)
60 61 62 |
# File 'lib/usps_api/models/address_information.rb', line 60 def dpvlacs @dpvlacs end |
#dpvndcbu_delivery ⇒ String
Address is NDCBU type of delivery (Y/N)
108 109 110 |
# File 'lib/usps_api/models/address_information.rb', line 108 def dpvndcbu_delivery @dpvndcbu_delivery end |
#dpvpbsa ⇒ String
Indicates a PO Box Street Address (Y/N)
133 134 135 |
# File 'lib/usps_api/models/address_information.rb', line 133 def dpvpbsa @dpvpbsa end |
#footnotes ⇒ String
The Address Matching Engine (AME) footnotes.
18 19 20 |
# File 'lib/usps_api/models/address_information.rb', line 18 def footnotes @footnotes end |
#foreign1 ⇒ String
International Freeform addresses - only valid for new addresses
137 138 139 |
# File 'lib/usps_api/models/address_information.rb', line 137 def foreign1 @foreign1 end |
#foreign2 ⇒ String
International Freeform addresses - only valid for new addresses
141 142 143 |
# File 'lib/usps_api/models/address_information.rb', line 141 def foreign2 @foreign2 end |
#foreign3 ⇒ String
International Freeform addresses - only valid for new addresses
145 146 147 |
# File 'lib/usps_api/models/address_information.rb', line 145 def foreign3 @foreign3 end |
#lacs_link_indicator ⇒ String
LACSLink Indicator - Y/N flag to indicate whether a match is made in LACSLink®.
154 155 156 |
# File 'lib/usps_api/models/address_information.rb', line 154 def lacs_link_indicator @lacs_link_indicator end |
#lacs_link_return_code ⇒ String
LACSLink Return Code - Flag to indicate if we matched in LACSLink.
158 159 160 |
# File 'lib/usps_api/models/address_information.rb', line 158 def lacs_link_return_code @lacs_link_return_code end |
#record_type ⇒ String
Record Type
30 31 32 |
# File 'lib/usps_api/models/address_information.rb', line 30 def record_type @record_type end |
#return_code ⇒ String
Address Matching Engine (AME) Return Code
14 15 16 |
# File 'lib/usps_api/models/address_information.rb', line 14 def return_code @return_code end |
#suite_link_indicator ⇒ String
SuiteLink Indicator - Flag to indicate if we matched in SuiteLink.
149 150 151 |
# File 'lib/usps_api/models/address_information.rb', line 149 def suite_link_indicator @suite_link_indicator end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/usps_api/models/address_information.rb', line 347 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. return_code = hash.key?('returnCode') ? hash['returnCode'] : nil address = NcoaDataServicesDomesticAddress.from_hash(hash['address']) if hash['address'] footnotes = hash.key?('footnotes') ? hash['footnotes'] : SKIP carrier_route = hash.key?('carrierRoute') ? hash['carrierRoute'] : SKIP record_type = hash.key?('recordType') ? hash['recordType'] : SKIP dpv_confirmation = hash.key?('DPVConfirmation') ? hash['DPVConfirmation'] : SKIP dpv_business = hash.key?('DPVBusiness') ? hash['DPVBusiness'] : SKIP dpvcmra = hash.key?('DPVCMRA') ? hash['DPVCMRA'] : SKIP dpv_drop = hash.key?('DPVDrop') ? hash['DPVDrop'] : SKIP dpv_educational = hash.key?('DPVEducational') ? hash['DPVEducational'] : SKIP dpv_drop_count = hash.key?('DPVDropCount') ? hash['DPVDropCount'] : SKIP dpvlacs = hash.key?('DPVLACS') ? hash['DPVLACS'] : SKIP dpv_no_door_delivery = hash.key?('DPVNoDoorDelivery') ? hash['DPVNoDoorDelivery'] : SKIP dpv_no_stat_reason_code = hash.key?('DPVNoStatReasonCode') ? hash['DPVNoStatReasonCode'] : SKIP dpv_seasonal = hash.key?('DPVSeasonal') ? hash['DPVSeasonal'] : SKIP dpv_throwback = hash.key?('DPVThrowback') ? hash['DPVThrowback'] : SKIP dpv_no_secure_location = hash.key?('DPVNoSecureLocation') ? hash['DPVNoSecureLocation'] : SKIP dpv_vacant = hash.key?('DPVVacant') ? hash['DPVVacant'] : SKIP dpv_no_stat = hash.key?('DPVNoStat') ? hash['DPVNoStat'] : SKIP dpv_non_delivery_days_flag = hash.key?('DPVNonDeliveryDaysFlag') ? hash['DPVNonDeliveryDaysFlag'] : SKIP dpv_non_delivery_days_values = hash.key?('DPVNonDeliveryDaysValues') ? hash['DPVNonDeliveryDaysValues'] : SKIP dpv_curb_delivery = hash.key?('DPVCurbDelivery') ? hash['DPVCurbDelivery'] : SKIP dpvndcbu_delivery = hash.key?('DPVNDCBUDelivery') ? hash['DPVNDCBUDelivery'] : SKIP dpv_central_box_delivery = hash.key?('DPVCentralBoxDelivery') ? hash['DPVCentralBoxDelivery'] : SKIP dpv_other_delivery = hash.key?('DPVOtherDelivery') ? hash['DPVOtherDelivery'] : SKIP dpv_delivery_type = hash.key?('DPVDeliveryType') ? hash['DPVDeliveryType'] : SKIP dpv_enhanced_confirmation = hash.key?('DPVEnhancedConfirmation') ? hash['DPVEnhancedConfirmation'] : SKIP dpv_footnotes = hash.key?('DPVFootnotes') ? hash['DPVFootnotes'] : SKIP dpvpbsa = hash.key?('DPVPBSA') ? hash['DPVPBSA'] : SKIP foreign1 = hash.key?('foreign1') ? hash['foreign1'] : SKIP foreign2 = hash.key?('foreign2') ? hash['foreign2'] : SKIP foreign3 = hash.key?('foreign3') ? hash['foreign3'] : SKIP suite_link_indicator = hash.key?('suiteLinkIndicator') ? hash['suiteLinkIndicator'] : SKIP lacs_link_indicator = hash.key?('LACSLinkIndicator') ? hash['LACSLinkIndicator'] : SKIP lacs_link_return_code = hash.key?('LACSLinkReturnCode') ? hash['LACSLinkReturnCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AddressInformation.new(return_code: return_code, address: address, footnotes: footnotes, carrier_route: carrier_route, record_type: record_type, dpv_confirmation: dpv_confirmation, dpv_business: dpv_business, dpvcmra: dpvcmra, dpv_drop: dpv_drop, dpv_educational: dpv_educational, dpv_drop_count: dpv_drop_count, dpvlacs: dpvlacs, dpv_no_door_delivery: dpv_no_door_delivery, dpv_no_stat_reason_code: dpv_no_stat_reason_code, dpv_seasonal: dpv_seasonal, dpv_throwback: dpv_throwback, dpv_no_secure_location: dpv_no_secure_location, dpv_vacant: dpv_vacant, dpv_no_stat: dpv_no_stat, dpv_non_delivery_days_flag: dpv_non_delivery_days_flag, dpv_non_delivery_days_values: dpv_non_delivery_days_values, dpv_curb_delivery: dpv_curb_delivery, dpvndcbu_delivery: dpvndcbu_delivery, dpv_central_box_delivery: dpv_central_box_delivery, dpv_other_delivery: dpv_other_delivery, dpv_delivery_type: dpv_delivery_type, dpv_enhanced_confirmation: dpv_enhanced_confirmation, dpv_footnotes: dpv_footnotes, dpvpbsa: dpvpbsa, foreign1: foreign1, foreign2: foreign2, foreign3: foreign3, suite_link_indicator: suite_link_indicator, lacs_link_indicator: lacs_link_indicator, lacs_link_return_code: lacs_link_return_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/usps_api/models/address_information.rb', line 161 def self.names @_hash = {} if @_hash.nil? @_hash['return_code'] = 'returnCode' @_hash['footnotes'] = 'footnotes' @_hash['address'] = 'address' @_hash['carrier_route'] = 'carrierRoute' @_hash['record_type'] = 'recordType' @_hash['dpv_confirmation'] = 'DPVConfirmation' @_hash['dpv_business'] = 'DPVBusiness' @_hash['dpvcmra'] = 'DPVCMRA' @_hash['dpv_drop'] = 'DPVDrop' @_hash['dpv_educational'] = 'DPVEducational' @_hash['dpv_drop_count'] = 'DPVDropCount' @_hash['dpvlacs'] = 'DPVLACS' @_hash['dpv_no_door_delivery'] = 'DPVNoDoorDelivery' @_hash['dpv_no_stat_reason_code'] = 'DPVNoStatReasonCode' @_hash['dpv_seasonal'] = 'DPVSeasonal' @_hash['dpv_throwback'] = 'DPVThrowback' @_hash['dpv_no_secure_location'] = 'DPVNoSecureLocation' @_hash['dpv_vacant'] = 'DPVVacant' @_hash['dpv_no_stat'] = 'DPVNoStat' @_hash['dpv_non_delivery_days_flag'] = 'DPVNonDeliveryDaysFlag' @_hash['dpv_non_delivery_days_values'] = 'DPVNonDeliveryDaysValues' @_hash['dpv_curb_delivery'] = 'DPVCurbDelivery' @_hash['dpvndcbu_delivery'] = 'DPVNDCBUDelivery' @_hash['dpv_central_box_delivery'] = 'DPVCentralBoxDelivery' @_hash['dpv_other_delivery'] = 'DPVOtherDelivery' @_hash['dpv_delivery_type'] = 'DPVDeliveryType' @_hash['dpv_enhanced_confirmation'] = 'DPVEnhancedConfirmation' @_hash['dpv_footnotes'] = 'DPVFootnotes' @_hash['dpvpbsa'] = 'DPVPBSA' @_hash['foreign1'] = 'foreign1' @_hash['foreign2'] = 'foreign2' @_hash['foreign3'] = 'foreign3' @_hash['suite_link_indicator'] = 'suiteLinkIndicator' @_hash['lacs_link_indicator'] = 'LACSLinkIndicator' @_hash['lacs_link_return_code'] = 'LACSLinkReturnCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/usps_api/models/address_information.rb', line 241 def self.nullables %w[ return_code footnotes carrier_route record_type dpv_confirmation dpv_business dpvcmra dpv_drop dpv_educational dpv_drop_count dpvlacs dpv_no_door_delivery dpv_no_stat_reason_code dpv_seasonal dpv_throwback dpv_no_secure_location dpv_vacant dpv_no_stat dpv_non_delivery_days_flag dpv_non_delivery_days_values dpv_curb_delivery dpvndcbu_delivery dpv_central_box_delivery dpv_other_delivery dpv_delivery_type dpv_enhanced_confirmation dpv_footnotes dpvpbsa foreign1 foreign2 foreign3 suite_link_indicator lacs_link_indicator lacs_link_return_code ] end |
.optionals ⇒ Object
An array for optional fields
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/usps_api/models/address_information.rb', line 202 def self.optionals %w[ footnotes carrier_route record_type dpv_confirmation dpv_business dpvcmra dpv_drop dpv_educational dpv_drop_count dpvlacs dpv_no_door_delivery dpv_no_stat_reason_code dpv_seasonal dpv_throwback dpv_no_secure_location dpv_vacant dpv_no_stat dpv_non_delivery_days_flag dpv_non_delivery_days_values dpv_curb_delivery dpvndcbu_delivery dpv_central_box_delivery dpv_other_delivery dpv_delivery_type dpv_enhanced_confirmation dpv_footnotes dpvpbsa foreign1 foreign2 foreign3 suite_link_indicator lacs_link_indicator lacs_link_return_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/usps_api/models/address_information.rb', line 473 def inspect class_name = self.class.name.split('::').last "<#{class_name} return_code: #{@return_code.inspect}, footnotes: #{@footnotes.inspect},"\ " address: #{@address.inspect}, carrier_route: #{@carrier_route.inspect}, record_type:"\ " #{@record_type.inspect}, dpv_confirmation: #{@dpv_confirmation.inspect}, dpv_business:"\ " #{@dpv_business.inspect}, dpvcmra: #{@dpvcmra.inspect}, dpv_drop: #{@dpv_drop.inspect},"\ " dpv_educational: #{@dpv_educational.inspect}, dpv_drop_count: #{@dpv_drop_count.inspect},"\ " dpvlacs: #{@dpvlacs.inspect}, dpv_no_door_delivery: #{@dpv_no_door_delivery.inspect},"\ " dpv_no_stat_reason_code: #{@dpv_no_stat_reason_code.inspect}, dpv_seasonal:"\ " #{@dpv_seasonal.inspect}, dpv_throwback: #{@dpv_throwback.inspect},"\ " dpv_no_secure_location: #{@dpv_no_secure_location.inspect}, dpv_vacant:"\ " #{@dpv_vacant.inspect}, dpv_no_stat: #{@dpv_no_stat.inspect}, dpv_non_delivery_days_flag:"\ " #{@dpv_non_delivery_days_flag.inspect}, dpv_non_delivery_days_values:"\ " #{@dpv_non_delivery_days_values.inspect}, dpv_curb_delivery:"\ " #{@dpv_curb_delivery.inspect}, dpvndcbu_delivery: #{@dpvndcbu_delivery.inspect},"\ " dpv_central_box_delivery: #{@dpv_central_box_delivery.inspect}, dpv_other_delivery:"\ " #{@dpv_other_delivery.inspect}, dpv_delivery_type: #{@dpv_delivery_type.inspect},"\ " dpv_enhanced_confirmation: #{@dpv_enhanced_confirmation.inspect}, dpv_footnotes:"\ " #{@dpv_footnotes.inspect}, dpvpbsa: #{@dpvpbsa.inspect}, foreign1: #{@foreign1.inspect},"\ " foreign2: #{@foreign2.inspect}, foreign3: #{@foreign3.inspect}, suite_link_indicator:"\ " #{@suite_link_indicator.inspect}, lacs_link_indicator: #{@lacs_link_indicator.inspect},"\ " lacs_link_return_code: #{@lacs_link_return_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/usps_api/models/address_information.rb', line 450 def to_s class_name = self.class.name.split('::').last "<#{class_name} return_code: #{@return_code}, footnotes: #{@footnotes}, address:"\ " #{@address}, carrier_route: #{@carrier_route}, record_type: #{@record_type},"\ " dpv_confirmation: #{@dpv_confirmation}, dpv_business: #{@dpv_business}, dpvcmra:"\ " #{@dpvcmra}, dpv_drop: #{@dpv_drop}, dpv_educational: #{@dpv_educational}, dpv_drop_count:"\ " #{@dpv_drop_count}, dpvlacs: #{@dpvlacs}, dpv_no_door_delivery: #{@dpv_no_door_delivery},"\ " dpv_no_stat_reason_code: #{@dpv_no_stat_reason_code}, dpv_seasonal: #{@dpv_seasonal},"\ " dpv_throwback: #{@dpv_throwback}, dpv_no_secure_location: #{@dpv_no_secure_location},"\ " dpv_vacant: #{@dpv_vacant}, dpv_no_stat: #{@dpv_no_stat}, dpv_non_delivery_days_flag:"\ " #{@dpv_non_delivery_days_flag}, dpv_non_delivery_days_values:"\ " #{@dpv_non_delivery_days_values}, dpv_curb_delivery: #{@dpv_curb_delivery},"\ " dpvndcbu_delivery: #{@dpvndcbu_delivery}, dpv_central_box_delivery:"\ " #{@dpv_central_box_delivery}, dpv_other_delivery: #{@dpv_other_delivery},"\ " dpv_delivery_type: #{@dpv_delivery_type}, dpv_enhanced_confirmation:"\ " #{@dpv_enhanced_confirmation}, dpv_footnotes: #{@dpv_footnotes}, dpvpbsa: #{@dpvpbsa},"\ " foreign1: #{@foreign1}, foreign2: #{@foreign2}, foreign3: #{@foreign3},"\ " suite_link_indicator: #{@suite_link_indicator}, lacs_link_indicator:"\ " #{@lacs_link_indicator}, lacs_link_return_code: #{@lacs_link_return_code},"\ " additional_properties: #{@additional_properties}>" end |