Class: UspsApi::CentralDeliveryPoint
- Inherits:
-
Object
- Object
- UspsApi::CentralDeliveryPoint
- Defined in:
- lib/usps_api/models/central_delivery_point.rb
Overview
Central Delivery is for all business office buildings and/or industrial/professional parks. This may include call windows, horizontal locked mail receptacles, and cluster box units. * ‘Y` - The address is a central delivery point. * `N` - The address is not a central delivery point.
Constant Summary collapse
- CENTRAL_DELIVERY_POINT =
[ # TODO: Write general description for Y Y = 'Y'.freeze, # TODO: Write general description for N N = 'N'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = Y) ⇒ Object
26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/usps_api/models/central_delivery_point.rb', line 26 def self.from_value(value, default_value = Y) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'y' then Y when 'n' then N else default_value end end |
.validate(value) ⇒ Object
20 21 22 23 24 |
# File 'lib/usps_api/models/central_delivery_point.rb', line 20 def self.validate(value) return false if value.nil? CENTRAL_DELIVERY_POINT.include?(value) end |