Class: UspsApi::CridFilter
- Defined in:
- lib/usps_api/models/crid_filter.rb
Overview
Create a subscription for all unpaid packages related to the specified Customer Registration ID (CRID).
Instance Attribute Summary collapse
-
#crid ⇒ String
Specify the Customer Registration ID that should be included in the subscription.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(crid:, additional_properties: nil) ⇒ CridFilter
constructor
A new instance of CridFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(crid:, additional_properties: nil) ⇒ CridFilter
Returns a new instance of CridFilter.
37 38 39 40 41 42 43 |
# File 'lib/usps_api/models/crid_filter.rb', line 37 def initialize(crid:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @crid = crid @additional_properties = additional_properties end |
Instance Attribute Details
#crid ⇒ String
Specify the Customer Registration ID that should be included in the subscription. Once a subscription is created this field cannot be changed through a future edit, instead the subscription should be deleted and a new subscription should be created.
18 19 20 |
# File 'lib/usps_api/models/crid_filter.rb', line 18 def crid @crid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/usps_api/models/crid_filter.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. crid = hash.key?('CRID') ? hash['CRID'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CridFilter.new(crid: crid, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/usps_api/models/crid_filter.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['crid'] = 'CRID' @_hash end |
.nullables ⇒ Object
An array for nullable fields
33 34 35 |
# File 'lib/usps_api/models/crid_filter.rb', line 33 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 |
# File 'lib/usps_api/models/crid_filter.rb', line 28 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 |
# File 'lib/usps_api/models/crid_filter.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} crid: #{@crid.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/usps_api/models/crid_filter.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} crid: #{@crid}, additional_properties: #{@additional_properties}>" end |