Class: UspsApi::DestinationAddress
- Defined in:
- lib/usps_api/models/destination_address.rb
Overview
Manifest package details used to determine the refund amount.
Instance Attribute Summary collapse
-
#city ⇒ String
City of the destination of the package.
-
#country_code ⇒ String
Country Code.
-
#state ⇒ String
State of the destination of the package.
-
#street_address ⇒ String
Street address of the destination of the package.
-
#zip_code ⇒ String
Zip code of the destination of the package.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(street_address: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, country_code: SKIP, additional_properties: nil) ⇒ DestinationAddress
constructor
A new instance of DestinationAddress.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(street_address: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, country_code: SKIP, additional_properties: nil) ⇒ DestinationAddress
Returns a new instance of DestinationAddress.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/usps_api/models/destination_address.rb', line 59 def initialize(street_address: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, country_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @street_address = street_address unless street_address == SKIP @city = city unless city == SKIP @state = state unless state == SKIP @zip_code = zip_code unless zip_code == SKIP @country_code = country_code unless country_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
City of the destination of the package.
18 19 20 |
# File 'lib/usps_api/models/destination_address.rb', line 18 def city @city end |
#country_code ⇒ String
Country Code
30 31 32 |
# File 'lib/usps_api/models/destination_address.rb', line 30 def country_code @country_code end |
#state ⇒ String
State of the destination of the package.
22 23 24 |
# File 'lib/usps_api/models/destination_address.rb', line 22 def state @state end |
#street_address ⇒ String
Street address of the destination of the package.
14 15 16 |
# File 'lib/usps_api/models/destination_address.rb', line 14 def street_address @street_address end |
#zip_code ⇒ String
Zip code of the destination of the package.
26 27 28 |
# File 'lib/usps_api/models/destination_address.rb', line 26 def zip_code @zip_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/usps_api/models/destination_address.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. street_address = hash.key?('streetAddress') ? hash['streetAddress'] : SKIP city = hash.key?('city') ? hash['city'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP zip_code = hash.key?('zipCode') ? hash['zipCode'] : SKIP country_code = hash.key?('countryCode') ? hash['countryCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DestinationAddress.new(street_address: street_address, city: city, state: state, zip_code: zip_code, country_code: country_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/destination_address.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['street_address'] = 'streetAddress' @_hash['city'] = 'city' @_hash['state'] = 'state' @_hash['zip_code'] = 'zipCode' @_hash['country_code'] = 'countryCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/usps_api/models/destination_address.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/usps_api/models/destination_address.rb', line 44 def self.optionals %w[ street_address city state zip_code country_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
109 110 111 112 113 114 |
# File 'lib/usps_api/models/destination_address.rb', line 109 def inspect class_name = self.class.name.split('::').last "<#{class_name} street_address: #{@street_address.inspect}, city: #{@city.inspect}, state:"\ " #{@state.inspect}, zip_code: #{@zip_code.inspect}, country_code: #{@country_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 106 |
# File 'lib/usps_api/models/destination_address.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} street_address: #{@street_address}, city: #{@city}, state: #{@state},"\ " zip_code: #{@zip_code}, country_code: #{@country_code}, additional_properties:"\ " #{@additional_properties}>" end |