Class: UspsApi::DetailInfo
- Defined in:
- lib/usps_api/models/detail_info.rb
Overview
Details of the appointment request.
Instance Attribute Summary collapse
-
#consignee_content_id ⇒ String
Consignee Content ID to stand in for above USPSSummary object.
-
#usps_summary ⇒ Array[UspsSummary]
Additional details of the Appointment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(usps_summary: SKIP, consignee_content_id: SKIP, additional_properties: nil) ⇒ DetailInfo
constructor
A new instance of DetailInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(usps_summary: SKIP, consignee_content_id: SKIP, additional_properties: nil) ⇒ DetailInfo
Returns a new instance of DetailInfo.
41 42 43 44 45 46 47 48 49 |
# File 'lib/usps_api/models/detail_info.rb', line 41 def initialize(usps_summary: SKIP, consignee_content_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @usps_summary = usps_summary unless usps_summary == SKIP @consignee_content_id = consignee_content_id unless consignee_content_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#consignee_content_id ⇒ String
Consignee Content ID to stand in for above USPSSummary object
18 19 20 |
# File 'lib/usps_api/models/detail_info.rb', line 18 def consignee_content_id @consignee_content_id end |
#usps_summary ⇒ Array[UspsSummary]
Additional details of the Appointment.
14 15 16 |
# File 'lib/usps_api/models/detail_info.rb', line 14 def usps_summary @usps_summary end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/usps_api/models/detail_info.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it usps_summary = nil unless hash['uspsSummary'].nil? usps_summary = [] hash['uspsSummary'].each do |structure| usps_summary << (UspsSummary.from_hash(structure) if structure) end end usps_summary = SKIP unless hash.key?('uspsSummary') consignee_content_id = hash.key?('consigneeContentID') ? hash['consigneeContentID'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DetailInfo.new(usps_summary: usps_summary, consignee_content_id: consignee_content_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/detail_info.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['usps_summary'] = 'uspsSummary' @_hash['consignee_content_id'] = 'consigneeContentID' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/detail_info.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/detail_info.rb', line 29 def self.optionals %w[ usps_summary consignee_content_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/usps_api/models/detail_info.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} usps_summary: #{@usps_summary.inspect}, consignee_content_id:"\ " #{@consignee_content_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/usps_api/models/detail_info.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} usps_summary: #{@usps_summary}, consignee_content_id:"\ " #{@consignee_content_id}, additional_properties: #{@additional_properties}>" end |