Class: UspsApi::DomesticOptions
- Defined in:
- lib/usps_api/models/domestic_options.rb
Overview
TBD
Instance Attribute Summary collapse
-
#mail_class ⇒ DomesticMailClass
The domestic mail service requested.
-
#rate_options ⇒ Array[DomesticRateOptions]
List of domestic rate options.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(mail_class: SKIP, rate_options: SKIP) ⇒ DomesticOptions
constructor
A new instance of DomesticOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mail_class: SKIP, rate_options: SKIP) ⇒ DomesticOptions
Returns a new instance of DomesticOptions.
41 42 43 44 |
# File 'lib/usps_api/models/domestic_options.rb', line 41 def initialize(mail_class: SKIP, rate_options: SKIP) @mail_class = mail_class unless mail_class == SKIP @rate_options = unless == SKIP end |
Instance Attribute Details
#mail_class ⇒ DomesticMailClass
The domestic mail service requested.
14 15 16 |
# File 'lib/usps_api/models/domestic_options.rb', line 14 def mail_class @mail_class end |
#rate_options ⇒ Array[DomesticRateOptions]
List of domestic rate options
18 19 20 |
# File 'lib/usps_api/models/domestic_options.rb', line 18 def @rate_options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/usps_api/models/domestic_options.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mail_class = hash.key?('mailClass') ? hash['mailClass'] : SKIP # Parameter is an array, so we need to iterate through it = nil unless hash['rateOptions'].nil? = [] hash['rateOptions'].each do |structure| << (DomesticRateOptions.from_hash(structure) if structure) end end = SKIP unless hash.key?('rateOptions') # Create object from extracted values. DomesticOptions.new(mail_class: mail_class, rate_options: ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/domestic_options.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['mail_class'] = 'mailClass' @_hash['rate_options'] = 'rateOptions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/domestic_options.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/domestic_options.rb', line 29 def self.optionals %w[ mail_class rate_options ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 |
# File 'lib/usps_api/models/domestic_options.rb', line 70 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/usps_api/models/domestic_options.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} mail_class: #{@mail_class.inspect}, rate_options:"\ " #{@rate_options.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 |
# File 'lib/usps_api/models/domestic_options.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} mail_class: #{@mail_class}, rate_options: #{@rate_options}>" end |