Class: UspsApi::DoorDetails
- Defined in:
- lib/usps_api/models/door_details.rb
Overview
Information regarding the dock door size and yard surface distance to the loading dock door.
Instance Attribute Summary collapse
-
#height ⇒ Integer
The height of the tallest dock door (in feet).
-
#number_of_steps ⇒ Integer
The number of steps between the yard surface and the loading dock door.
-
#width ⇒ Integer
The width of the largest dock door (in feet).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(height: SKIP, width: SKIP, number_of_steps: SKIP, additional_properties: nil) ⇒ DoorDetails
constructor
A new instance of DoorDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(height: SKIP, width: SKIP, number_of_steps: SKIP, additional_properties: nil) ⇒ DoorDetails
Returns a new instance of DoorDetails.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/usps_api/models/door_details.rb', line 48 def initialize(height: SKIP, width: SKIP, number_of_steps: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @height = height unless height == SKIP @width = width unless width == SKIP @number_of_steps = number_of_steps unless number_of_steps == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#height ⇒ Integer
The height of the tallest dock door (in feet).
15 16 17 |
# File 'lib/usps_api/models/door_details.rb', line 15 def height @height end |
#number_of_steps ⇒ Integer
The number of steps between the yard surface and the loading dock door.
23 24 25 |
# File 'lib/usps_api/models/door_details.rb', line 23 def number_of_steps @number_of_steps end |
#width ⇒ Integer
The width of the largest dock door (in feet).
19 20 21 |
# File 'lib/usps_api/models/door_details.rb', line 19 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/usps_api/models/door_details.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. height = hash.key?('height') ? hash['height'] : SKIP width = hash.key?('width') ? hash['width'] : SKIP number_of_steps = hash.key?('numberOfSteps') ? hash['numberOfSteps'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DoorDetails.new(height: height, width: width, number_of_steps: number_of_steps, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/usps_api/models/door_details.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['height'] = 'height' @_hash['width'] = 'width' @_hash['number_of_steps'] = 'numberOfSteps' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/usps_api/models/door_details.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/door_details.rb', line 35 def self.optionals %w[ height width number_of_steps ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/usps_api/models/door_details.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} height: #{@height.inspect}, width: #{@width.inspect}, number_of_steps:"\ " #{@number_of_steps.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/usps_api/models/door_details.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} height: #{@height}, width: #{@width}, number_of_steps: #{@number_of_steps},"\ " additional_properties: #{@additional_properties}>" end |