Class: UspsApi::EnrollmentRequest
- Defined in:
- lib/usps_api/models/enrollment_request.rb
Overview
EnrollmentRequest Model.
Instance Attribute Summary collapse
-
#mi_ds ⇒ Array[String]
The Mailer IDs (MIDs) whose enrollment is being checked.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mi_ds:, additional_properties: nil) ⇒ EnrollmentRequest
constructor
A new instance of EnrollmentRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mi_ds:, additional_properties: nil) ⇒ EnrollmentRequest
Returns a new instance of EnrollmentRequest.
35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/enrollment_request.rb', line 35 def initialize(mi_ds:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mi_ds = mi_ds @additional_properties = additional_properties end |
Instance Attribute Details
#mi_ds ⇒ Array[String]
The Mailer IDs (MIDs) whose enrollment is being checked. Currently only one MID is allowed per request. Multiple MIDs will be supported in a future version.
16 17 18 |
# File 'lib/usps_api/models/enrollment_request.rb', line 16 def mi_ds @mi_ds end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/usps_api/models/enrollment_request.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mi_ds = hash.key?('MIDs') ? hash['MIDs'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EnrollmentRequest.new(mi_ds: mi_ds, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/usps_api/models/enrollment_request.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['mi_ds'] = 'MIDs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/usps_api/models/enrollment_request.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/usps_api/models/enrollment_request.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/usps_api/models/enrollment_request.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} mi_ds: #{@mi_ds.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/usps_api/models/enrollment_request.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} mi_ds: #{@mi_ds}, additional_properties: #{@additional_properties}>" end |