Class: UspsApi::Error3
- Defined in:
- lib/usps_api/models/error3.rb
Overview
Error3 Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
Details on IMB-level error associated with the request.
-
#title ⇒ String
Title of IMB-level error associated with the request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(title: SKIP, detail: SKIP, additional_properties: nil) ⇒ Error3
constructor
A new instance of Error3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(title: SKIP, detail: SKIP, additional_properties: nil) ⇒ Error3
Returns a new instance of Error3.
43 44 45 46 47 48 49 50 |
# File 'lib/usps_api/models/error3.rb', line 43 def initialize(title: SKIP, detail: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @title = title unless title == SKIP @detail = detail unless detail == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ String
Details on IMB-level error associated with the request. If there is an IMB-level error, that IMB will not be added to the campaign.
20 21 22 |
# File 'lib/usps_api/models/error3.rb', line 20 def detail @detail end |
#title ⇒ String
Title of IMB-level error associated with the request. If there is an IMB-level error, that IMB will not be added to the campaign.
15 16 17 |
# File 'lib/usps_api/models/error3.rb', line 15 def title @title end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/usps_api/models/error3.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. title = hash.key?('title') ? hash['title'] : SKIP detail = hash.key?('detail') ? hash['detail'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Error3.new(title: title, detail: detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/usps_api/models/error3.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['title'] = 'title' @_hash['detail'] = 'detail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/usps_api/models/error3.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/usps_api/models/error3.rb', line 31 def self.optionals %w[ title detail ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/usps_api/models/error3.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} title: #{@title.inspect}, detail: #{@detail.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/usps_api/models/error3.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} title: #{@title}, detail: #{@detail}, additional_properties:"\ " #{@additional_properties}>" end |