Class: UspsApi::Error5
- Defined in:
- lib/usps_api/models/error5.rb
Overview
Error5 Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
Detailed description of the error.
-
#imb ⇒ String
The IMB associated with the error.
-
#title ⇒ String
Title of the error.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imb: SKIP, title: SKIP, detail: SKIP, additional_properties: nil) ⇒ Error5
constructor
A new instance of Error5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imb: SKIP, title: SKIP, detail: SKIP, additional_properties: nil) ⇒ Error5
Returns a new instance of Error5.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/error5.rb', line 47 def initialize(imb: SKIP, title: SKIP, detail: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @imb = imb unless imb == SKIP @title = title unless title == SKIP @detail = detail unless detail == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ String
Detailed description of the error.
22 23 24 |
# File 'lib/usps_api/models/error5.rb', line 22 def detail @detail end |
#imb ⇒ String
The IMB associated with the error.
14 15 16 |
# File 'lib/usps_api/models/error5.rb', line 14 def imb @imb end |
#title ⇒ String
Title of the error.
18 19 20 |
# File 'lib/usps_api/models/error5.rb', line 18 def title @title end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/usps_api/models/error5.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imb = hash.key?('IMB') ? hash['IMB'] : SKIP title = hash.key?('title') ? hash['title'] : SKIP detail = hash.key?('detail') ? hash['detail'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Error5.new(imb: imb, title: title, detail: detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/error5.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['imb'] = 'IMB' @_hash['title'] = 'title' @_hash['detail'] = 'detail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/error5.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/error5.rb', line 34 def self.optionals %w[ imb title detail ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/usps_api/models/error5.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} imb: #{@imb.inspect}, title: #{@title.inspect}, detail: #{@detail.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/usps_api/models/error5.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} imb: #{@imb}, title: #{@title}, detail: #{@detail}, additional_properties:"\ " #{@additional_properties}>" end |