Class: UspsApi::ImBsResponseMoreThan25Success
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::ImBsResponseMoreThan25Success
- Defined in:
- lib/usps_api/models/im_bs_response_more_than25_success.rb
Overview
ImBsResponseMoreThan25Success Model.
Instance Attribute Summary collapse
-
#callback_key ⇒ String
The callback key generated by Informed Delivery for a successful request with more than 25 IMBs.
-
#status ⇒ String
Status message giving user more information on the request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(callback_key: SKIP, status: SKIP, additional_properties: nil) ⇒ ImBsResponseMoreThan25Success
constructor
A new instance of ImBsResponseMoreThan25Success.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(callback_key: SKIP, status: SKIP, additional_properties: nil) ⇒ ImBsResponseMoreThan25Success
Returns a new instance of ImBsResponseMoreThan25Success.
44 45 46 47 48 49 50 51 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 44 def initialize(callback_key: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @callback_key = callback_key unless callback_key == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#callback_key ⇒ String
The callback key generated by Informed Delivery for a successful request with more than 25 IMBs. This can be used in subsequent requests against the callback key endpoints to get more information on the successes and errors for individual IMBs in the request.
17 18 19 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 17 def callback_key @callback_key end |
#status ⇒ String
Status message giving user more information on the request.
21 22 23 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 21 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. callback_key = hash.key?('callbackKey') ? hash['callbackKey'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ImBsResponseMoreThan25Success.new(callback_key: callback_key, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['callback_key'] = 'callbackKey' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 32 def self.optionals %w[ callback_key status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} callback_key: #{@callback_key.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/usps_api/models/im_bs_response_more_than25_success.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} callback_key: #{@callback_key}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |