Class: UspsApi::IndiciaImbDomesticLabelAddress
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::IndiciaImbDomesticLabelAddress
- Defined in:
- lib/usps_api/models/indicia_imb_domestic_label_address.rb
Overview
The address where the letter, flat, or card is being mailed to. Address elements streetAddress, city, state, ZIPCode are required. First and Last Name or Firm are also required.
Instance Attribute Summary collapse
-
#city ⇒ String
This is the city name of the address.
-
#city_abbreviation ⇒ String
This is the abbreviation of city name for the address.
-
#firm ⇒ String
Firm/business name corresponding to the address.
-
#first_name ⇒ String
First Name corresponding to the address.
-
#ignore_bad_address ⇒ TrueClass | FalseClass
Allows Non-Validated Street Address.
-
#last_name ⇒ String
Last Name corresponding to the address.
-
#secondary_address ⇒ String
The secondary unit designator, such as apartment(APT) or suite(STE) number, defining the exact location of the address within a building.
-
#state ⇒ String
This is the two-character state code of the address.
-
#street_address ⇒ String
The number of a building along with the name of the road or street on which it is located.
-
#street_address_abbreviation ⇒ String
This is the abbreviation of street address line for the address.
-
#urbanization ⇒ String
An area, sector, or residential development within a geographic area (typically used for addresses in Puerto Rico).
-
#zip_code ⇒ String
This is the 5-digit ZIP code.
-
#zip_plus4 ⇒ String
This is the 4-digit component of the ZIP+4 code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(street_address:, city:, state:, zip_code:, street_address_abbreviation: SKIP, secondary_address: SKIP, city_abbreviation: SKIP, zip_plus4: SKIP, urbanization: SKIP, first_name: SKIP, last_name: SKIP, firm: SKIP, ignore_bad_address: SKIP, additional_properties: nil) ⇒ IndiciaImbDomesticLabelAddress
constructor
A new instance of IndiciaImbDomesticLabelAddress.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(street_address:, city:, state:, zip_code:, street_address_abbreviation: SKIP, secondary_address: SKIP, city_abbreviation: SKIP, zip_plus4: SKIP, urbanization: SKIP, first_name: SKIP, last_name: SKIP, firm: SKIP, ignore_bad_address: SKIP, additional_properties: nil) ⇒ IndiciaImbDomesticLabelAddress
Returns a new instance of IndiciaImbDomesticLabelAddress.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 121 def initialize(street_address:, city:, state:, zip_code:, street_address_abbreviation: SKIP, secondary_address: SKIP, city_abbreviation: SKIP, zip_plus4: SKIP, urbanization: SKIP, first_name: SKIP, last_name: SKIP, firm: SKIP, ignore_bad_address: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @street_address = street_address unless street_address_abbreviation == SKIP @street_address_abbreviation = street_address_abbreviation end @secondary_address = secondary_address unless secondary_address == SKIP @city_abbreviation = city_abbreviation unless city_abbreviation == SKIP @city = city @state = state @zip_code = zip_code @zip_plus4 = zip_plus4 unless zip_plus4 == SKIP @urbanization = urbanization unless urbanization == SKIP @first_name = first_name unless first_name == SKIP @last_name = last_name unless last_name == SKIP @firm = firm unless firm == SKIP @ignore_bad_address = ignore_bad_address unless ignore_bad_address == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
This is the city name of the address.
36 37 38 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 36 def city @city end |
#city_abbreviation ⇒ String
This is the abbreviation of city name for the address.
32 33 34 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 32 def city_abbreviation @city_abbreviation end |
#firm ⇒ String
Firm/business name corresponding to the address.
67 68 69 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 67 def firm @firm end |
#first_name ⇒ String
First Name corresponding to the address.
59 60 61 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 59 def first_name @first_name end |
#ignore_bad_address ⇒ TrueClass | FalseClass
Allows Non-Validated Street Address. Enter ‘true` to bypass street address validation failures/errors or `false` if only validated addresses should be allowed. Note: Integrators are recommended to always use `false` to ensure no delivery issues. In the event USPS cannot validate the street address, this tag will “bypass” address validation error when `true` is indicated to allow IMB indicia creation which could impact delivery.
78 79 80 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 78 def ignore_bad_address @ignore_bad_address end |
#last_name ⇒ String
Last Name corresponding to the address.
63 64 65 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 63 def last_name @last_name end |
#secondary_address ⇒ String
The secondary unit designator, such as apartment(APT) or suite(STE) number, defining the exact location of the address within a building. For more information please see [Postal Explorer](pe.usps.com/text/pub28/28c2_003.htm).
28 29 30 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 28 def secondary_address @secondary_address end |
#state ⇒ String
This is the two-character state code of the address.
40 41 42 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 40 def state @state end |
#street_address ⇒ String
The number of a building along with the name of the road or street on which it is located.
17 18 19 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 17 def street_address @street_address end |
#street_address_abbreviation ⇒ String
This is the abbreviation of street address line for the address.
21 22 23 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 21 def street_address_abbreviation @street_address_abbreviation end |
#urbanization ⇒ String
An area, sector, or residential development within a geographic area (typically used for addresses in Puerto Rico).
55 56 57 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 55 def urbanization @urbanization end |
#zip_code ⇒ String
This is the 5-digit ZIP code.
44 45 46 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 44 def zip_code @zip_code end |
#zip_plus4 ⇒ String
This is the 4-digit component of the ZIP+4 code. Using the correct Zip+4 reduces the number of times your mail is handled and can decrease the chance of a misdelivery or error.
50 51 52 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 50 def zip_plus4 @zip_plus4 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 149 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. street_address = hash.key?('streetAddress') ? hash['streetAddress'] : nil city = hash.key?('city') ? hash['city'] : nil state = hash.key?('state') ? hash['state'] : nil zip_code = hash.key?('ZIPCode') ? hash['ZIPCode'] : nil street_address_abbreviation = hash.key?('streetAddressAbbreviation') ? hash['streetAddressAbbreviation'] : SKIP secondary_address = hash.key?('secondaryAddress') ? hash['secondaryAddress'] : SKIP city_abbreviation = hash.key?('cityAbbreviation') ? hash['cityAbbreviation'] : SKIP zip_plus4 = hash.key?('ZIPPlus4') ? hash['ZIPPlus4'] : SKIP urbanization = hash.key?('urbanization') ? hash['urbanization'] : SKIP first_name = hash.key?('firstName') ? hash['firstName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP firm = hash.key?('firm') ? hash['firm'] : SKIP ignore_bad_address = hash.key?('ignoreBadAddress') ? hash['ignoreBadAddress'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IndiciaImbDomesticLabelAddress.new(street_address: street_address, city: city, state: state, zip_code: zip_code, street_address_abbreviation: street_address_abbreviation, secondary_address: secondary_address, city_abbreviation: city_abbreviation, zip_plus4: zip_plus4, urbanization: urbanization, first_name: first_name, last_name: last_name, firm: firm, ignore_bad_address: ignore_bad_address, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 81 def self.names @_hash = {} if @_hash.nil? @_hash['street_address'] = 'streetAddress' @_hash['street_address_abbreviation'] = 'streetAddressAbbreviation' @_hash['secondary_address'] = 'secondaryAddress' @_hash['city_abbreviation'] = 'cityAbbreviation' @_hash['city'] = 'city' @_hash['state'] = 'state' @_hash['zip_code'] = 'ZIPCode' @_hash['zip_plus4'] = 'ZIPPlus4' @_hash['urbanization'] = 'urbanization' @_hash['first_name'] = 'firstName' @_hash['last_name'] = 'lastName' @_hash['firm'] = 'firm' @_hash['ignore_bad_address'] = 'ignoreBadAddress' @_hash end |
.nullables ⇒ Object
An array for nullable fields
115 116 117 118 119 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 115 def self.nullables %w[ zip_plus4 ] end |
.optionals ⇒ Object
An array for optional fields
100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 100 def self.optionals %w[ street_address_abbreviation secondary_address city_abbreviation zip_plus4 urbanization first_name last_name firm ignore_bad_address ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
207 208 209 210 211 212 213 214 215 216 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 207 def inspect class_name = self.class.name.split('::').last "<#{class_name} street_address: #{@street_address.inspect}, street_address_abbreviation:"\ " #{@street_address_abbreviation.inspect}, secondary_address: #{@secondary_address.inspect},"\ " city_abbreviation: #{@city_abbreviation.inspect}, city: #{@city.inspect}, state:"\ " #{@state.inspect}, zip_code: #{@zip_code.inspect}, zip_plus4: #{@zip_plus4.inspect},"\ " urbanization: #{@urbanization.inspect}, first_name: #{@first_name.inspect}, last_name:"\ " #{@last_name.inspect}, firm: #{@firm.inspect}, ignore_bad_address:"\ " #{@ignore_bad_address.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
196 197 198 199 200 201 202 203 204 |
# File 'lib/usps_api/models/indicia_imb_domestic_label_address.rb', line 196 def to_s class_name = self.class.name.split('::').last "<#{class_name} street_address: #{@street_address}, street_address_abbreviation:"\ " #{@street_address_abbreviation}, secondary_address: #{@secondary_address},"\ " city_abbreviation: #{@city_abbreviation}, city: #{@city}, state: #{@state}, zip_code:"\ " #{@zip_code}, zip_plus4: #{@zip_plus4}, urbanization: #{@urbanization}, first_name:"\ " #{@first_name}, last_name: #{@last_name}, firm: #{@firm}, ignore_bad_address:"\ " #{@ignore_bad_address}, additional_properties: #{@additional_properties}>" end |