Class: UspsApi::InternationalOptionsResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::InternationalOptionsResponse
- Defined in:
- lib/usps_api/models/international_options_response.rb
Overview
TBD
Instance Attribute Summary collapse
-
#destination_country_code ⇒ String
Country of destination.
-
#foreign_postal_code ⇒ String
This is the Postal Code used in an international addresses.
-
#origin_zip_code ⇒ String
This is the originating ZIP Code™ for the package.
-
#pricing_options ⇒ Array[InternationalPricingOption]
List of international pricing options.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(origin_zip_code: SKIP, foreign_postal_code: SKIP, destination_country_code: SKIP, pricing_options: SKIP, additional_properties: nil) ⇒ InternationalOptionsResponse
constructor
A new instance of InternationalOptionsResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(origin_zip_code: SKIP, foreign_postal_code: SKIP, destination_country_code: SKIP, pricing_options: SKIP, additional_properties: nil) ⇒ InternationalOptionsResponse
Returns a new instance of InternationalOptionsResponse.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/usps_api/models/international_options_response.rb', line 58 def initialize(origin_zip_code: SKIP, foreign_postal_code: SKIP, destination_country_code: SKIP, pricing_options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @origin_zip_code = origin_zip_code unless origin_zip_code == SKIP @foreign_postal_code = foreign_postal_code unless foreign_postal_code == SKIP @destination_country_code = destination_country_code unless destination_country_code == SKIP @pricing_options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#destination_country_code ⇒ String
Country of destination.
27 28 29 |
# File 'lib/usps_api/models/international_options_response.rb', line 27 def destination_country_code @destination_country_code end |
#foreign_postal_code ⇒ String
This is the Postal Code used in an international addresses. Note:
-
Different shipping destinations may require a postal code for shipping.
For more details, review the [Individual Country Listing](pe.usps.com/text/imm/immctry.htm) for your shipping destination
23 24 25 |
# File 'lib/usps_api/models/international_options_response.rb', line 23 def foreign_postal_code @foreign_postal_code end |
#origin_zip_code ⇒ String
This is the originating ZIP Code™ for the package.
14 15 16 |
# File 'lib/usps_api/models/international_options_response.rb', line 14 def origin_zip_code @origin_zip_code end |
#pricing_options ⇒ Array[InternationalPricingOption]
List of international pricing options
31 32 33 |
# File 'lib/usps_api/models/international_options_response.rb', line 31 def @pricing_options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/usps_api/models/international_options_response.rb', line 72 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. origin_zip_code = hash.key?('originZIPCode') ? hash['originZIPCode'] : SKIP foreign_postal_code = hash.key?('foreignPostalCode') ? hash['foreignPostalCode'] : SKIP destination_country_code = hash.key?('destinationCountryCode') ? hash['destinationCountryCode'] : SKIP # Parameter is an array, so we need to iterate through it = nil unless hash['pricingOptions'].nil? = [] hash['pricingOptions'].each do |structure| << (InternationalPricingOption.from_hash(structure) if structure) end end = SKIP unless hash.key?('pricingOptions') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InternationalOptionsResponse.new(origin_zip_code: origin_zip_code, foreign_postal_code: foreign_postal_code, destination_country_code: destination_country_code, pricing_options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/international_options_response.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['origin_zip_code'] = 'originZIPCode' @_hash['foreign_postal_code'] = 'foreignPostalCode' @_hash['destination_country_code'] = 'destinationCountryCode' @_hash['pricing_options'] = 'pricingOptions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/usps_api/models/international_options_response.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 |
# File 'lib/usps_api/models/international_options_response.rb', line 44 def self.optionals %w[ origin_zip_code foreign_postal_code destination_country_code pricing_options ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
110 111 112 113 114 115 116 |
# File 'lib/usps_api/models/international_options_response.rb', line 110 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
127 128 129 130 131 132 133 |
# File 'lib/usps_api/models/international_options_response.rb', line 127 def inspect class_name = self.class.name.split('::').last "<#{class_name} origin_zip_code: #{@origin_zip_code.inspect}, foreign_postal_code:"\ " #{@foreign_postal_code.inspect}, destination_country_code:"\ " #{@destination_country_code.inspect}, pricing_options: #{@pricing_options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
119 120 121 122 123 124 |
# File 'lib/usps_api/models/international_options_response.rb', line 119 def to_s class_name = self.class.name.split('::').last "<#{class_name} origin_zip_code: #{@origin_zip_code}, foreign_postal_code:"\ " #{@foreign_postal_code}, destination_country_code: #{@destination_country_code},"\ " pricing_options: #{@pricing_options}, additional_properties: #{@additional_properties}>" end |