Class: UspsApi::Links
- Defined in:
- lib/usps_api/models/links.rb
Overview
Pagination navigation links.
Instance Attribute Summary collapse
-
#first ⇒ First
Link to the first page of results.
-
#last ⇒ Last
Link to the last page of results.
-
#mnext ⇒ Next
Link to the next page of results.
-
#mself ⇒ Self
Link to the current page of results.
-
#previous ⇒ Previous
Link to the previous page of results.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, mnext: SKIP, previous: SKIP, first: SKIP, last: SKIP, additional_properties: nil) ⇒ Links
constructor
A new instance of Links.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, mnext: SKIP, previous: SKIP, first: SKIP, last: SKIP, additional_properties: nil) ⇒ Links
Returns a new instance of Links.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/usps_api/models/links.rb', line 64 def initialize(mself: SKIP, mnext: SKIP, previous: SKIP, first: SKIP, last: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @mnext = mnext unless mnext == SKIP @previous = previous unless previous == SKIP @first = first unless first == SKIP @last = last unless last == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#first ⇒ First
Link to the first page of results.
26 27 28 |
# File 'lib/usps_api/models/links.rb', line 26 def first @first end |
#last ⇒ Last
Link to the last page of results.
30 31 32 |
# File 'lib/usps_api/models/links.rb', line 30 def last @last end |
#mnext ⇒ Next
Link to the next page of results.
18 19 20 |
# File 'lib/usps_api/models/links.rb', line 18 def mnext @mnext end |
#mself ⇒ Self
Link to the current page of results.
14 15 16 |
# File 'lib/usps_api/models/links.rb', line 14 def mself @mself end |
#previous ⇒ Previous
Link to the previous page of results.
22 23 24 |
# File 'lib/usps_api/models/links.rb', line 22 def previous @previous end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/usps_api/models/links.rb', line 78 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self.from_hash(hash['self']) if hash['self'] mnext = Next.from_hash(hash['next']) if hash['next'] previous = Previous.from_hash(hash['previous']) if hash['previous'] first = First.from_hash(hash['first']) if hash['first'] last = Last.from_hash(hash['last']) if hash['last'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links.new(mself: mself, mnext: mnext, previous: previous, first: first, last: last, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/links.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['mnext'] = 'next' @_hash['previous'] = 'previous' @_hash['first'] = 'first' @_hash['last'] = 'last' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 58 59 60 61 62 |
# File 'lib/usps_api/models/links.rb', line 55 def self.nullables %w[ mnext previous first last ] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/usps_api/models/links.rb', line 44 def self.optionals %w[ mself mnext previous first last ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
112 113 114 115 116 117 |
# File 'lib/usps_api/models/links.rb', line 112 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, mnext: #{@mnext.inspect}, previous:"\ " #{@previous.inspect}, first: #{@first.inspect}, last: #{@last.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 |
# File 'lib/usps_api/models/links.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, mnext: #{@mnext}, previous: #{@previous}, first:"\ " #{@first}, last: #{@last}, additional_properties: #{@additional_properties}>" end |