Class: UspsApi::OriginAddress
- Defined in:
- lib/usps_api/models/origin_address.rb
Overview
Manifest package details used to determine the refund amount.
Instance Attribute Summary collapse
-
#city ⇒ String
City of the origin of the package.
-
#state ⇒ String
State of the origin of the package.
-
#street_address ⇒ String
Street address of the origin of the package.
-
#zip_code ⇒ String
Zip code of the origin of the package.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(street_address: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, additional_properties: nil) ⇒ OriginAddress
constructor
A new instance of OriginAddress.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(street_address: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, additional_properties: nil) ⇒ OriginAddress
Returns a new instance of OriginAddress.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/usps_api/models/origin_address.rb', line 53 def initialize(street_address: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @street_address = street_address unless street_address == SKIP @city = city unless city == SKIP @state = state unless state == SKIP @zip_code = zip_code unless zip_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
City of the origin of the package.
18 19 20 |
# File 'lib/usps_api/models/origin_address.rb', line 18 def city @city end |
#state ⇒ String
State of the origin of the package.
22 23 24 |
# File 'lib/usps_api/models/origin_address.rb', line 22 def state @state end |
#street_address ⇒ String
Street address of the origin of the package.
14 15 16 |
# File 'lib/usps_api/models/origin_address.rb', line 14 def street_address @street_address end |
#zip_code ⇒ String
Zip code of the origin of the package.
26 27 28 |
# File 'lib/usps_api/models/origin_address.rb', line 26 def zip_code @zip_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/usps_api/models/origin_address.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. street_address = hash.key?('streetAddress') ? hash['streetAddress'] : SKIP city = hash.key?('city') ? hash['city'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP zip_code = hash.key?('zipCode') ? hash['zipCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OriginAddress.new(street_address: street_address, city: city, state: state, zip_code: zip_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/usps_api/models/origin_address.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['street_address'] = 'streetAddress' @_hash['city'] = 'city' @_hash['state'] = 'state' @_hash['zip_code'] = 'zipCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/usps_api/models/origin_address.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/usps_api/models/origin_address.rb', line 39 def self.optionals %w[ street_address city state zip_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/usps_api/models/origin_address.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} street_address: #{@street_address.inspect}, city: #{@city.inspect}, state:"\ " #{@state.inspect}, zip_code: #{@zip_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/usps_api/models/origin_address.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} street_address: #{@street_address}, city: #{@city}, state: #{@state},"\ " zip_code: #{@zip_code}, additional_properties: #{@additional_properties}>" end |