Class: UspsApi::Ramps
- Defined in:
- lib/usps_api/models/ramps.rb
Overview
Details on ramps available at the facility.
Instance Attribute Summary collapse
-
#number_of_ramps ⇒ Integer
The number of inclined ramps at the facility.
-
#widest_ramp ⇒ Integer
The widest inclined ramp available at the facility (in feet).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number_of_ramps: SKIP, widest_ramp: SKIP, additional_properties: nil) ⇒ Ramps
constructor
A new instance of Ramps.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number_of_ramps: SKIP, widest_ramp: SKIP, additional_properties: nil) ⇒ Ramps
Returns a new instance of Ramps.
41 42 43 44 45 46 47 48 49 |
# File 'lib/usps_api/models/ramps.rb', line 41 def initialize(number_of_ramps: SKIP, widest_ramp: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number_of_ramps = number_of_ramps unless number_of_ramps == SKIP @widest_ramp = widest_ramp unless widest_ramp == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#number_of_ramps ⇒ Integer
The number of inclined ramps at the facility.
14 15 16 |
# File 'lib/usps_api/models/ramps.rb', line 14 def number_of_ramps @number_of_ramps end |
#widest_ramp ⇒ Integer
The widest inclined ramp available at the facility (in feet).
18 19 20 |
# File 'lib/usps_api/models/ramps.rb', line 18 def widest_ramp @widest_ramp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/usps_api/models/ramps.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number_of_ramps = hash.key?('numberOfRamps') ? hash['numberOfRamps'] : SKIP widest_ramp = hash.key?('widestRamp') ? hash['widestRamp'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Ramps.new(number_of_ramps: number_of_ramps, widest_ramp: widest_ramp, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/usps_api/models/ramps.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['number_of_ramps'] = 'numberOfRamps' @_hash['widest_ramp'] = 'widestRamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/usps_api/models/ramps.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/usps_api/models/ramps.rb', line 29 def self.optionals %w[ number_of_ramps widest_ramp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/usps_api/models/ramps.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} number_of_ramps: #{@number_of_ramps.inspect}, widest_ramp:"\ " #{@widest_ramp.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/usps_api/models/ramps.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} number_of_ramps: #{@number_of_ramps}, widest_ramp: #{@widest_ramp},"\ " additional_properties: #{@additional_properties}>" end |