Class: UspsApi::SubscriptionsUnpaidPackagesSubscription1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::SubscriptionsUnpaidPackagesSubscription1
- Defined in:
- lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb
Overview
Subscription for the tracking event data the consumer is receiving.
Instance Attribute Summary collapse
-
#admin_notification ⇒ Array[SubscriptionsAdjustmentsEmailNotification]
Customer can supply an email address to receive important updates on the status and events related to the subscription.
-
#creation_timestamp ⇒ DateTime
When the subscription was originally created.
-
#expiration_timestamp ⇒ DateTime
When the subscription expires.
-
#listener_url ⇒ String
Customer URL to which subscription data will be sent.
-
#secret ⇒ String
Customer-supplied secret USPS will use to create a hash value.
-
#status ⇒ Status5
Current status of the subscription.
-
#status_change_timestamp ⇒ DateTime
Time when the status was last changed.
-
#status_reason ⇒ String
When status is suspended, the Status Reason will return why it was suspended.
-
#subscription_id ⇒ String
Unique Identifier created for this Subscription.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(listener_url:, secret:, admin_notification:, subscription_id: SKIP, status: SKIP, status_reason: SKIP, creation_timestamp: SKIP, status_change_timestamp: SKIP, expiration_timestamp: SKIP, additional_properties: nil) ⇒ SubscriptionsUnpaidPackagesSubscription1
constructor
A new instance of SubscriptionsUnpaidPackagesSubscription1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_creation_timestamp ⇒ Object
- #to_custom_expiration_timestamp ⇒ Object
- #to_custom_status_change_timestamp ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(listener_url:, secret:, admin_notification:, subscription_id: SKIP, status: SKIP, status_reason: SKIP, creation_timestamp: SKIP, status_change_timestamp: SKIP, expiration_timestamp: SKIP, additional_properties: nil) ⇒ SubscriptionsUnpaidPackagesSubscription1
Returns a new instance of SubscriptionsUnpaidPackagesSubscription1.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 91 def initialize(listener_url:, secret:, admin_notification:, subscription_id: SKIP, status: SKIP, status_reason: SKIP, creation_timestamp: SKIP, status_change_timestamp: SKIP, expiration_timestamp: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @subscription_id = subscription_id unless subscription_id == SKIP @listener_url = listener_url @secret = secret @status = status unless status == SKIP @status_reason = status_reason unless status_reason == SKIP @admin_notification = admin_notification @creation_timestamp = unless == SKIP @status_change_timestamp = unless == SKIP @expiration_timestamp = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#admin_notification ⇒ Array[SubscriptionsAdjustmentsEmailNotification]
Customer can supply an email address to receive important updates on the status and events related to the subscription.
45 46 47 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 45 def admin_notification @admin_notification end |
#creation_timestamp ⇒ DateTime
When the subscription was originally created.
49 50 51 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 49 def @creation_timestamp end |
#expiration_timestamp ⇒ DateTime
When the subscription expires.
57 58 59 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 57 def @expiration_timestamp end |
#listener_url ⇒ String
Customer URL to which subscription data will be sent. You can parse the data received on the server URL.
20 21 22 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 20 def listener_url @listener_url end |
#secret ⇒ String
Customer-supplied secret USPS will use to create a hash value. The hash will be provided in the Notification payload. USPS will use the SHA-256 algorithm to create the hash value.
26 27 28 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 26 def secret @secret end |
#status ⇒ Status5
Current status of the subscription. USPS will post notifications to the supplied listenerURL. If the listenerURL cannot be reached or is invalid, USPS will change the status of the subscription to SUSPENDED. The customer has the option of changing the status to DISABLED. It is recommended the customer change the status to DISABLED if they know their endpoint will not be active, i.e operational maintenance.
35 36 37 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 35 def status @status end |
#status_change_timestamp ⇒ DateTime
Time when the status was last changed
53 54 55 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 53 def @status_change_timestamp end |
#status_reason ⇒ String
When status is suspended, the Status Reason will return why it was suspended.
40 41 42 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 40 def status_reason @status_reason end |
#subscription_id ⇒ String
Unique Identifier created for this Subscription.
15 16 17 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 15 def subscription_id @subscription_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 111 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. listener_url = hash.key?('listenerURL') ? hash['listenerURL'] : nil secret = hash.key?('secret') ? hash['secret'] : nil # Parameter is an array, so we need to iterate through it admin_notification = nil unless hash['adminNotification'].nil? admin_notification = [] hash['adminNotification'].each do |structure| admin_notification << (SubscriptionsAdjustmentsEmailNotification.from_hash(structure) if structure) end end admin_notification = nil unless hash.key?('adminNotification') subscription_id = hash.key?('subscriptionId') ? hash['subscriptionId'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP status_reason = hash.key?('statusReason') ? hash['statusReason'] : SKIP = if hash.key?('creationTimestamp') (DateTimeHelper.from_rfc3339(hash['creationTimestamp']) if hash['creationTimestamp']) else SKIP end = if hash.key?('statusChangeTimestamp') (DateTimeHelper.from_rfc3339(hash['statusChangeTimestamp']) if hash['statusChangeTimestamp']) else SKIP end = if hash.key?('expirationTimestamp') (DateTimeHelper.from_rfc3339(hash['expirationTimestamp']) if hash['expirationTimestamp']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SubscriptionsUnpaidPackagesSubscription1.new(listener_url: listener_url, secret: secret, admin_notification: admin_notification, subscription_id: subscription_id, status: status, status_reason: status_reason, creation_timestamp: , status_change_timestamp: , expiration_timestamp: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 60 def self.names @_hash = {} if @_hash.nil? @_hash['subscription_id'] = 'subscriptionId' @_hash['listener_url'] = 'listenerURL' @_hash['secret'] = 'secret' @_hash['status'] = 'status' @_hash['status_reason'] = 'statusReason' @_hash['admin_notification'] = 'adminNotification' @_hash['creation_timestamp'] = 'creationTimestamp' @_hash['status_change_timestamp'] = 'statusChangeTimestamp' @_hash['expiration_timestamp'] = 'expirationTimestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
87 88 89 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 87 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 75 def self.optionals %w[ subscription_id status status_reason creation_timestamp status_change_timestamp expiration_timestamp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
190 191 192 193 194 195 196 197 198 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 190 def inspect class_name = self.class.name.split('::').last "<#{class_name} subscription_id: #{@subscription_id.inspect}, listener_url:"\ " #{@listener_url.inspect}, secret: #{@secret.inspect}, status: #{@status.inspect},"\ " status_reason: #{@status_reason.inspect}, admin_notification:"\ " #{@admin_notification.inspect}, creation_timestamp: #{@creation_timestamp.inspect},"\ " status_change_timestamp: #{@status_change_timestamp.inspect}, expiration_timestamp:"\ " #{@expiration_timestamp.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_creation_timestamp ⇒ Object
167 168 169 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 167 def DateTimeHelper.to_rfc3339() end |
#to_custom_expiration_timestamp ⇒ Object
175 176 177 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 175 def DateTimeHelper.to_rfc3339() end |
#to_custom_status_change_timestamp ⇒ Object
171 172 173 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 171 def DateTimeHelper.to_rfc3339() end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
180 181 182 183 184 185 186 187 |
# File 'lib/usps_api/models/subscriptions_unpaid_packages_subscription1.rb', line 180 def to_s class_name = self.class.name.split('::').last "<#{class_name} subscription_id: #{@subscription_id}, listener_url: #{@listener_url},"\ " secret: #{@secret}, status: #{@status}, status_reason: #{@status_reason},"\ " admin_notification: #{@admin_notification}, creation_timestamp: #{@creation_timestamp},"\ " status_change_timestamp: #{@status_change_timestamp}, expiration_timestamp:"\ " #{@expiration_timestamp}, additional_properties: #{@additional_properties}>" end |